# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gather_client_ws/events.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgather_client_ws/events.proto\"\xb3\x01\n\x13SpriteDirectionEnum\"\x9b\x01\n\x04\x45NUM\x12\t\n\x05Stand\x10\x00\x12\x08\n\x04\x44own\x10\x01\x12\x0b\n\x07\x44ownAlt\x10\x02\x12\x06\n\x02Up\x10\x03\x12\t\n\x05UpAlt\x10\x04\x12\x08\n\x04Left\x10\x05\x12\x0b\n\x07LeftAlt\x10\x06\x12\t\n\x05Right\x10\x07\x12\x0c\n\x08RightAlt\x10\x08\x12\n\n\x06\x44\x61nce1\x10\t\x12\n\n\x06\x44\x61nce2\x10\n\x12\n\n\x06\x44\x61nce3\x10\x0b\x12\n\n\x06\x44\x61nce4\x10\x0c\"M\n\x11MoveDirectionEnum\"8\n\x04\x45NUM\x12\x08\n\x04Left\x10\x00\x12\t\n\x05Right\x10\x01\x12\x06\n\x02Up\x10\x02\x12\x08\n\x04\x44own\x10\x03\x12\t\n\x05\x44\x61nce\x10\x04\"\xbf\x01\n\x0fInteractionEnum\"\xab\x01\n\x04\x45NUM\x12\x08\n\x04NONE\x10\x00\x12\x14\n\x10\x45MBEDDED_WEBSITE\x10\x01\x12\n\n\x06POSTER\x10\x02\x12\t\n\x05VIDEO\x10\x03\x12\x11\n\rEXTERNAL_CALL\x10\x04\x12\r\n\tEXTENSION\x10\x05\x12\x08\n\x04NOTE\x10\x06\x12\x13\n\x0fMODAL_EXTENSION\x10\x07\x12\x13\n\x0f\x43OMPONENT_MODAL\x10\x08\x12\x16\n\x12SIDE_PANEL_TRIGGER\x10\t\"\xb7\x04\n\x0ePlayerInitInfo\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x0e\n\x01x\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x0e\n\x01y\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x10\n\x03map\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x18\n\x0b\x61\x66\x66iliation\x18\x06 \x01(\tH\x04\x88\x01\x01\x12\x11\n\x04\x62usy\x18\x07 \x01(\x08H\x05\x88\x01\x01\x12\x17\n\ntextStatus\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x18\n\x0b\x65mojiStatus\x18\t \x01(\tH\x07\x88\x01\x01\x12\x32\n\x1a\x63urrentlyEquippedWearables\x18\n \x01(\x0b\x32\t.DBOutfitH\x08\x88\x01\x01\x12\x1d\n\x10\x66ocusModeEndTime\x18\x0b \x01(\tH\t\x88\x01\x01\x12\x18\n\x0b\x63urrentDesk\x18\r \x01(\tH\n\x88\x01\x01\x12\x17\n\nitemString\x18\x0e \x01(\tH\x0b\x88\x01\x01\x12\x12\n\x05isNpc\x18\x0f \x01(\x08H\x0c\x88\x01\x01\x12\x1e\n\x11isRecordingClient\x18\x10 \x01(\x08H\r\x88\x01\x01\x42\x07\n\x05_nameB\x04\n\x02_xB\x04\n\x02_yB\x06\n\x04_mapB\x0e\n\x0c_affiliationB\x07\n\x05_busyB\r\n\x0b_textStatusB\x0e\n\x0c_emojiStatusB\x1d\n\x1b_currentlyEquippedWearablesB\x13\n\x11_focusModeEndTimeB\x0e\n\x0c_currentDeskB\r\n\x0b_itemStringB\x08\n\x06_isNpcB\x14\n\x12_isRecordingClient\"\xfa\x01\n\x08\x44\x42Outfit\x12\x0c\n\x04skin\x18\x01 \x01(\t\x12\x0c\n\x04hair\x18\x02 \x01(\t\x12\x13\n\x0b\x66\x61\x63ial_hair\x18\x03 \x01(\t\x12\x0b\n\x03top\x18\x04 \x01(\t\x12\x0e\n\x06\x62ottom\x18\x05 \x01(\t\x12\r\n\x05shoes\x18\x06 \x01(\t\x12\x0b\n\x03hat\x18\x07 \x01(\t\x12\x0f\n\x07glasses\x18\x08 \x01(\t\x12\r\n\x05other\x18\t \x01(\t\x12\x14\n\x07\x63ostume\x18\n \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08mobility\x18\x0b \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06jacket\x18\x0c \x01(\tH\x02\x88\x01\x01\x42\n\n\x08_costumeB\x0b\n\t_mobilityB\t\n\x07_jacket\"G\n\x1cWireObjectSpritesheetFraming\x12\x12\n\nframeWidth\x18\x01 \x01(\x05\x12\x13\n\x0b\x66rameHeight\x18\x02 \x01(\x05\"\x95\x01\n\x1aWireObjectSpriteAnimConfig\x12\x1f\n\x12useSequenceAsRange\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x10\n\x08sequence\x18\x02 \x03(\r\x12\x11\n\x04loop\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\tframeRate\x18\x04 \x01(\rB\x15\n\x13_useSequenceAsRangeB\x07\n\x05_loop\"\x95\x02\n\x15WireObjectSpritesheet\x12\x16\n\x0espritesheetUrl\x18\x01 \x01(\t\x12.\n\x07\x66raming\x18\x02 \x01(\x0b\x32\x1d.WireObjectSpritesheetFraming\x12:\n\nanimations\x18\x03 \x03(\x0b\x32&.WireObjectSpritesheet.AnimationsEntry\x12\x18\n\x0b\x63urrentAnim\x18\x04 \x01(\tH\x00\x88\x01\x01\x1aN\n\x0f\x41nimationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.WireObjectSpriteAnimConfig:\x02\x38\x01\x42\x0e\n\x0c_currentAnim\"\x94\x08\n\nWireObject\x12\x17\n\ntemplateId\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05_name\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\r\n\x05_tags\x18\x03 \x03(\t\x12\x0e\n\x01x\x18\x04 \x01(\rH\x02\x88\x01\x01\x12\x0e\n\x01y\x18\x05 \x01(\rH\x03\x88\x01\x01\x12\x14\n\x07offsetX\x18\x06 \x01(\x02H\x04\x88\x01\x01\x12\x14\n\x07offsetY\x18\x07 \x01(\x02H\x05\x88\x01\x01\x12\x12\n\x05\x63olor\x18\x08 \x01(\tH\x06\x88\x01\x01\x12\x18\n\x0borientation\x18\t \x01(\rH\x07\x88\x01\x01\x12\x13\n\x06normal\x18\n \x01(\tH\x08\x88\x01\x01\x12\x18\n\x0bhighlighted\x18\x0b \x01(\tH\t\x88\x01\x01\x12(\n\x04type\x18\x0c \x01(\x0e\x32\x15.InteractionEnum.ENUMH\n\x88\x01\x01\x12\x12\n\x05width\x18\r \x01(\rH\x0b\x88\x01\x01\x12\x13\n\x06height\x18\x0e \x01(\rH\x0c\x88\x01\x01\x12\x1b\n\x0e\x65xtensionClass\x18\x0f \x01(\tH\r\x88\x01\x01\x12\x1b\n\x0epreviewMessage\x18\x10 \x01(\tH\x0e\x88\x01\x01\x12\x1a\n\rdistThreshold\x18\x11 \x01(\rH\x0f\x88\x01\x01\x12\x1b\n\x0epropertiesJson\x18\x12 \x01(\tH\x10\x88\x01\x01\x12\x1a\n\x05sound\x18\x13 \x01(\x0b\x32\x06.SoundH\x11\x88\x01\x01\x12)\n\x0fobjectStartTime\x18\x14 \x01(\x0b\x32\x0b.ObjectTimeH\x12\x88\x01\x01\x12*\n\x10objectExpireTime\x18\x15 \x01(\x0b\x32\x0b.ObjectTimeH\x13\x88\x01\x01\x12\x0f\n\x02id\x18\x16 \x01(\tH\x14\x88\x01\x01\x12\x18\n\x0b\x63ustomState\x18\x17 \x01(\tH\x15\x88\x01\x01\x12\x1b\n\x0eobjectPlacerId\x18\x18 \x01(\tH\x16\x88\x01\x01\x12\x17\n\nnumGoKarts\x18\x19 \x01(\rH\x17\x88\x01\x01\x12\x30\n\x0bspritesheet\x18\x1a \x01(\x0b\x32\x16.WireObjectSpritesheetH\x18\x88\x01\x01\x42\r\n\x0b_templateIdB\x08\n\x06X_nameB\x04\n\x02_xB\x04\n\x02_yB\n\n\x08_offsetXB\n\n\x08_offsetYB\x08\n\x06_colorB\x0e\n\x0c_orientationB\t\n\x07_normalB\x0e\n\x0c_highlightedB\x07\n\x05_typeB\x08\n\x06_widthB\t\n\x07_heightB\x11\n\x0f_extensionClassB\x11\n\x0f_previewMessageB\x10\n\x0e_distThresholdB\x11\n\x0f_propertiesJsonB\x08\n\x06_soundB\x12\n\x10_objectStartTimeB\x13\n\x11_objectExpireTimeB\x05\n\x03_idB\x0e\n\x0c_customStateB\x11\n\x0f_objectPlacerIdB\r\n\x0b_numGoKartsB\x0e\n\x0c_spritesheet\"\xc1\x02\n\x0fSpaceMemberInfo\x12*\n\x05roles\x18\x01 \x03(\x0b\x32\x1b.SpaceMemberInfo.RolesEntry\x12\x11\n\x04name\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x32\n\x1a\x63urrentlyEquippedWearables\x18\x04 \x01(\x0b\x32\t.DBOutfitH\x01\x88\x01\x01\x12 \n\x08\x64\x65skInfo\x18\x05 \x01(\x0b\x32\t.DeskInfoH\x02\x88\x01\x01\x12\x1f\n\x12\x61llowScreenPointer\x18\x06 \x01(\x08H\x03\x88\x01\x01\x1a,\n\nRolesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x42\x07\n\x05_nameB\x1d\n\x1b_currentlyEquippedWearablesB\x0b\n\t_deskInfoB\x15\n\x13_allowScreenPointer\"P\n\x12\x42\x61\x63kedUpDeskObject\x12\x18\n\x03obj\x18\x01 \x01(\x0b\x32\x0b.WireObject\x12\x0f\n\x07offsetX\x18\x02 \x01(\r\x12\x0f\n\x07offsetY\x18\x03 \x01(\r\"~\n\x0b\x44\x65skObjects\x12*\n\x07objects\x18\x01 \x03(\x0b\x32\x19.DeskObjects.ObjectsEntry\x1a\x43\n\x0cObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\"\n\x05value\x18\x02 \x01(\x0b\x32\x13.BackedUpDeskObject:\x02\x38\x01\"d\n\x08\x44\x65skInfo\x12\x0e\n\x06\x64\x65skId\x18\x01 \x01(\t\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06locked\x18\x03 \x01(\x08H\x01\x88\x01\x01\x42\x0e\n\x0c_descriptionB\t\n\x07_locked\"\xd4\x01\n\nDeskInfoV2\x12\x13\n\x06\x64\x65skId\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06locked\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12*\n\x0flastDeskObjects\x18\x04 \x01(\x0b\x32\x0c.DeskObjectsH\x03\x88\x01\x01\x12\x12\n\x05mapId\x18\x05 \x01(\tH\x04\x88\x01\x01\x42\t\n\x07_deskIdB\x0e\n\x0c_descriptionB\t\n\x07_lockedB\x12\n\x10_lastDeskObjectsB\x08\n\x06_mapId\"s\n\x05Sound\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\x0e\n\x06volume\x18\x02 \x01(\x02\x12\x0c\n\x04loop\x18\x03 \x01(\x08\x12\x13\n\x0bmaxDistance\x18\x04 \x01(\r\x12\x19\n\x0cisPositional\x18\x05 \x01(\x08H\x00\x88\x01\x01\x42\x0f\n\r_isPositional\"D\n\nObjectTime\x12\x10\n\x08_seconds\x18\x01 \x01(\r\x12\x16\n\t_timezone\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0c\n\nX_timezone\"P\n\x05Space\x12\x0f\n\x07spaceId\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\x12\x14\n\x07\x63olored\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\n\n\x08_colored\"(\n\nNookCoords\x12\x1a\n\x06\x63oords\x18\x01 \x03(\x0b\x32\n.WirePoint\"\x1d\n\x0c\x41llowedUsers\x12\r\n\x05users\x18\x01 \x03(\t\")\n\x0bRequestUser\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"w\n\x0eRequestedUsers\x12)\n\x05users\x18\x01 \x03(\x0b\x32\x1a.RequestedUsers.UsersEntry\x1a:\n\nUsersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.RequestUser:\x02\x38\x01\"w\n\rRecordingInfo\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x12\x1d\n\x10initiatingPlayer\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x65gressId\x18\x04 \x01(\tH\x01\x88\x01\x01\x42\x13\n\x11_initiatingPlayerB\x0b\n\t_egressId\"\xf1\x03\n\x08NookDiff\x12$\n\nnookCoords\x18\x01 \x01(\x0b\x32\x0b.NookCoordsH\x00\x88\x01\x01\x12\x14\n\x07\x63olored\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x11\n\x04name\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x15\n\x08\x62ookable\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x15\n\x08\x63\x61pacity\x18\x05 \x01(\rH\x04\x88\x01\x01\x12\x17\n\nrestricted\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12(\n\x0c\x61llowedUsers\x18\x07 \x01(\x0b\x32\r.AllowedUsersH\x06\x88\x01\x01\x12,\n\x0erequestedUsers\x18\x08 \x01(\x0b\x32\x0f.RequestedUsersH\x07\x88\x01\x01\x12\x18\n\x0bisInMeeting\x18\t \x01(\x08H\x08\x88\x01\x01\x12\x13\n\x06isDesk\x18\n \x01(\x08H\t\x88\x01\x01\x12*\n\rrecordingInfo\x18\x0b \x01(\x0b\x32\x0e.RecordingInfoH\n\x88\x01\x01\x42\r\n\x0b_nookCoordsB\n\n\x08_coloredB\x07\n\x05_nameB\x0b\n\t_bookableB\x0b\n\t_capacityB\r\n\x0b_restrictedB\x0f\n\r_allowedUsersB\x11\n\x0f_requestedUsersB\x0e\n\x0c_isInMeetingB\t\n\x07_isDeskB\x10\n\x0e_recordingInfo\"!\n\tWirePoint\x12\t\n\x01x\x18\x01 \x01(\r\x12\t\n\x01y\x18\x02 \x01(\r\"D\n\nSpawnPoint\x12\t\n\x01x\x18\x01 \x01(\r\x12\t\n\x01y\x18\x02 \x01(\r\x12\x14\n\x07spawnId\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\n\n\x08_spawnId\"\xae\x01\n\x06Portal\x12\t\n\x01x\x18\x01 \x01(\r\x12\t\n\x01y\x18\x02 \x01(\r\x12\x16\n\ttargetMap\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x16\n\ttargetUrl\x18\x04 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07targetX\x18\x05 \x01(\rH\x02\x88\x01\x01\x12\x14\n\x07targetY\x18\x06 \x01(\rH\x03\x88\x01\x01\x42\x0c\n\n_targetMapB\x0c\n\n_targetUrlB\n\n\x08_targetXB\n\n\x08_targetY\"!\n\tAnnouncer\x12\t\n\x01x\x18\x01 \x01(\r\x12\t\n\x01y\x18\x02 \x01(\r\"\x8a\x01\n\x05\x41sset\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\x0b\n\x03src\x18\x03 \x01(\t\x12\x12\n\x05width\x18\x04 \x01(\rH\x00\x88\x01\x01\x12\x13\n\x06height\x18\x05 \x01(\rH\x01\x88\x01\x01\x12\x14\n\x07inFront\x18\x06 \x01(\x08H\x02\x88\x01\x01\x42\x08\n\x06_widthB\t\n\x07_heightB\n\n\x08_inFront\">\n\x0c\x41reaPosition\x12\n\n\x02x1\x18\x01 \x01(\r\x12\n\n\x02y1\x18\x02 \x01(\r\x12\n\n\x02x2\x18\x03 \x01(\r\x12\n\n\x02y2\x18\x04 \x01(\r\"M\n\x08WireArea\x12\x15\n\x08\x63\x61tegory\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x1d\n\x06\x63oords\x18\x02 \x03(\x0b\x32\r.AreaPositionB\x0b\n\t_category\"\'\n\x06\x44\x42\x44\x65sk\x12\x1d\n\x06\x63oords\x18\x01 \x03(\x0b\x32\r.AreaPosition\"@\n\x10MapSetDimensions\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\r\n\x05width\x18\x02 \x01(\r\x12\x0e\n\x06height\x18\x03 \x01(\r\"[\n\x10MapSetCollisions\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\x12\t\n\x01w\x18\x04 \x01(\r\x12\t\n\x01h\x18\x05 \x01(\r\x12\x0c\n\x04mask\x18\x06 \x01(\t\"r\n\x14MapSetCollisionsBits\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x11\n\toverwrite\x18\x02 \x01(\x08\x12\t\n\x01x\x18\x03 \x01(\r\x12\t\n\x01y\x18\x04 \x01(\r\x12\t\n\x01w\x18\x05 \x01(\r\x12\t\n\x01h\x18\x06 \x01(\r\x12\x0c\n\x04mask\x18\x07 \x01(\x0c\"G\n\x19MapSetBackgroundImagePath\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x1b\n\x13\x62\x61\x63kgroundImagePath\x18\x02 \x01(\t\"g\n\x19MapSetForegroundImagePath\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x1b\n\x13\x66oregroundImagePath\x18\x02 \x01(\t\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"O\n\rMapSetSprites\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x0f\n\x07sprites\x18\x02 \x03(\r\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"5\n\x0cMapSetSpaces\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x16\n\x06spaces\x18\x02 \x03(\x0b\x32\x06.Space\"\xa3\x01\n\x0bMapSetNooks\x12\r\n\x05mapId\x18\x01 \x01(\t\x12&\n\x05nooks\x18\x02 \x03(\x0b\x32\x17.MapSetNooks.NooksEntry\x12\x16\n\toverwrite\x18\x03 \x01(\x08H\x00\x88\x01\x01\x1a\x37\n\nNooksEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.NookDiff:\x02\x38\x01\x42\x0c\n\n_overwrite\"W\n\x0bMapSetSpawn\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x19\n\x05spawn\x18\x02 \x01(\x0b\x32\n.WirePoint\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\":\n\x0cMapSetSpawns\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x1b\n\x06spawns\x18\x02 \x03(\x0b\x32\x0b.SpawnPoint\"8\n\rMapSetPortals\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x18\n\x07portals\x18\x02 \x03(\x0b\x32\x07.Portal\"?\n\x0fMapSetAnnouncer\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x1d\n\tannouncer\x18\x02 \x03(\x0b\x32\n.Announcer\"U\n\x0cMapSetAssets\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x16\n\x06\x61ssets\x18\x02 \x03(\x0b\x32\x06.Asset\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"\xc5\x01\n\rMapSetObjects\x12\r\n\x05mapId\x18\x01 \x01(\t\x12,\n\x07objects\x18\x02 \x03(\x0b\x32\x1b.MapSetObjects.ObjectsEntry\x12!\n\x14updatesAreOverwrites\x18\x03 \x01(\x08H\x00\x88\x01\x01\x1a;\n\x0cObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\r\x12\x1a\n\x05value\x18\x02 \x01(\x0b\x32\x0b.WireObject:\x02\x38\x01\x42\x17\n\x15_updatesAreOverwrites\"I\n\nMapSetName\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"W\n\x11MapSetMuteOnEntry\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x13\n\x0bmuteOnEntry\x18\x02 \x01(\x08\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"U\n\x10MapSetUseDrawnBG\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x12\n\nuseDrawnBG\x18\x02 \x01(\x08\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"\x92\x01\n\x0bMapSetWalls\x12\r\n\x05mapId\x18\x01 \x01(\t\x12&\n\x05walls\x18\x02 \x03(\x0b\x32\x17.MapSetWalls.WallsEntry\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x1a,\n\nWallsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07_delete\"\x97\x01\n\x0cMapSetFloors\x12\r\n\x05mapId\x18\x01 \x01(\t\x12)\n\x06\x66loors\x18\x02 \x03(\x0b\x32\x19.MapSetFloors.FloorsEntry\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x1a-\n\x0b\x46loorsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07_delete\"\x9d\x01\n\x0bMapSetAreas\x12\r\n\x05mapId\x18\x01 \x01(\t\x12&\n\x05\x61reas\x18\x02 \x03(\x0b\x32\x17.MapSetAreas.AreasEntry\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x1a\x37\n\nAreasEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x18\n\x05value\x18\x02 \x01(\x0b\x32\t.WireArea:\x02\x38\x01\x42\t\n\x07_delete\"-\n\x0fMapDeleteObject\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x0b\n\x03key\x18\x02 \x01(\r\"0\n\x13MapDeleteObjectById\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\"a\n\x16MapSetMiniMapImagePath\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x18\n\x10miniMapImagePath\x18\x02 \x01(\t\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"Y\n\x12MapSetEnabledChats\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x14\n\x0c\x65nabledChats\x18\x02 \x03(\t\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"W\n\x11MapSetDescription\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"U\n\x10MapSetDecoration\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x12\n\ndecoration\x18\x02 \x01(\t\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"o\n\x13MapSetTutorialTasks\x12\r\n\x05mapId\x18\x01 \x01(\t\x12)\n\rtutorialTasks\x18\x02 \x01(\x0b\x32\x12.WireTutorialTasks\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"r\n\x11WireTutorialTasks\x12\x12\n\ngroupSetId\x18\x01 \x01(\t\x12#\n\x05\x61reas\x18\x02 \x03(\x0b\x32\x14.TutorialTaskMapArea\x12\x16\n\tautoStart\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_autoStart\"Z\n\x13TutorialTaskMapArea\x12\x0e\n\x06\x61reaId\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\x12\x0e\n\x06height\x18\x04 \x01(\r\x12\r\n\x05width\x18\x05 \x01(\r\"M\n\x0cMapSetScript\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x0e\n\x06script\x18\x02 \x01(\t\x12\x13\n\x06\x64\x65lete\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_delete\"\xc3\x01\n\tInventory\x12$\n\x05items\x18\x01 \x03(\x0b\x32\x15.Inventory.ItemsEntry\x12$\n\x05order\x18\x02 \x03(\x0b\x32\x15.Inventory.OrderEntry\x1a<\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.InventoryItem:\x02\x38\x01\x1a,\n\nOrderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x1e\n\rInventoryItem\x12\r\n\x05\x63ount\x18\x01 \x01(\r\"\xba\x02\n\tSpaceItem\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\x08\x63\x61tegory\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tH\x01\x88\x01\x01\x12\x12\n\npreviewUrl\x18\x04 \x01(\t\x12\"\n\x04meta\x18\x05 \x03(\x0b\x32\x14.SpaceItem.MetaEntry\x12,\n\tabilities\x18\x06 \x03(\x0b\x32\x19.SpaceItem.AbilitiesEntry\x1a+\n\tMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a>\n\x0e\x41\x62ilitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1b\n\x05value\x18\x02 \x01(\x0b\x32\x0c.ItemAbility:\x02\x38\x01\x42\x0b\n\t_categoryB\x0e\n\x0c_description\"\x1b\n\x0bItemAbility\x12\x0c\n\x04name\x18\x01 \x01(\t\"0\n\x0bMapLocation\x12\x0b\n\x03map\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\"7\n\x11ServerClientBatch\x12\"\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x12.ServerClientEvent\"\xff/\n\x11ServerClientEvent\x12\x15\n\x04info\x18\x64 \x01(\x0b\x32\x05.InfoH\x00\x12\x15\n\x04warn\x18\x65 \x01(\x0b\x32\x05.WarnH\x00\x12\x1c\n\x05\x65rror\x18\x66 \x01(\x0b\x32\x0b.ErrorEventH\x00\x12\x17\n\x05ready\x18g \x01(\x0b\x32\x06.ReadyH\x00\x12+\n\x0fserverHeartbeat\x18i \x01(\x0b\x32\x10.ServerHeartbeatH\x00\x12/\n\x11transactionStatus\x18k \x01(\x0b\x32\x12.TransactionStatusH\x00\x12#\n\x0bplayerMoves\x18\x01 \x01(\x0b\x32\x0c.PlayerMovesH\x00\x12-\n\x10playerSetsStatus\x18\x05 \x01(\x0b\x32\x11.PlayerSetsStatusH\x00\x12-\n\x10playerSpotlights\x18\x06 \x01(\x0b\x32\x11.PlayerSpotlightsH\x00\x12#\n\x0bplayerRings\x18\x07 \x01(\x0b\x32\x0c.PlayerRingsH\x00\x12#\n\x0bplayerChats\x18\t \x01(\x0b\x32\x0c.PlayerChatsH\x00\x12+\n\x0fplayerInteracts\x18\n \x01(\x0b\x32\x10.PlayerInteractsH\x00\x12%\n\x0cplayerGhosts\x18\x0b \x01(\x0b\x32\r.PlayerGhostsH\x00\x12\x33\n\x13playerEntersWhisper\x18\x0c \x01(\x0b\x32\x14.PlayerEntersWhisperH\x00\x12\x33\n\x13playerLeavesWhisper\x18\r \x01(\x0b\x32\x14.PlayerLeavesWhisperH\x00\x12\x35\n\x14playerActivelySpeaks\x18\x0e \x01(\x0b\x32\x15.PlayerActivelySpeaksH\x00\x12;\n\x17playerSetsWorkCondition\x18\x10 \x01(\x0b\x32\x18.PlayerSetsWorkConditionH\x00\x12)\n\x0eplayerSetsName\x18\x11 \x01(\x0b\x32\x0f.PlayerSetsNameH\x00\x12\x35\n\x14playerSetsTextStatus\x18\x12 \x01(\x0b\x32\x15.PlayerSetsTextStatusH\x00\x12\x37\n\x15playerSetsEmojiStatus\x18\x13 \x01(\x0b\x32\x16.PlayerSetsEmojiStatusH\x00\x12\x37\n\x15playerSetsAffiliation\x18\x14 \x01(\x0b\x32\x16.PlayerSetsAffiliationH\x00\x12#\n\x0bplayerExits\x18\x15 \x01(\x0b\x32\x0c.PlayerExitsH\x00\x12+\n\x0frespawnComplete\x18\' \x01(\x0b\x32\x10.RespawnCompleteH\x00\x12\x39\n\x16playerSetsOutfitString\x18( \x01(\x0b\x32\x17.PlayerSetsOutfitStringH\x00\x12\x35\n\x14playerSetsIsSignedIn\x18) \x01(\x0b\x32\x15.PlayerSetsIsSignedInH\x00\x12+\n\x0fspaceOverwrites\x18, \x01(\x0b\x32\x10.SpaceOverwritesH\x00\x12\'\n\rspaceIsClosed\x18- \x01(\x0b\x32\x0e.SpaceIsClosedH\x00\x12\x31\n\x12playerEntersPortal\x18. \x01(\x0b\x32\x13.PlayerEntersPortalH\x00\x12\x31\n\x12spaceSetsIdMapping\x18/ \x01(\x0b\x32\x13.SpaceSetsIdMappingH\x00\x12\x35\n\x14playerSetsLastActive\x18\x30 \x01(\x0b\x32\x15.PlayerSetsLastActiveH\x00\x12\x35\n\x14playerShootsConfetti\x18\x31 \x01(\x0b\x32\x15.PlayerShootsConfettiH\x00\x12\x37\n\x15playerSetsEventStatus\x18\x32 \x01(\x0b\x32\x16.PlayerSetsEventStatusH\x00\x12=\n\x18playerSetsInConversation\x18\x33 \x01(\x0b\x32\x19.PlayerSetsInConversationH\x00\x12\x37\n\x15playerSetsCurrentDesk\x18\x34 \x01(\x0b\x32\x16.PlayerSetsCurrentDeskH\x00\x12\x37\n\x15playerSetsCurrentArea\x18\x35 \x01(\x0b\x32\x16.PlayerSetsCurrentAreaH\x00\x12\x39\n\x16playerSetsImagePointer\x18\x36 \x01(\x0b\x32\x17.PlayerSetsImagePointerH\x00\x12#\n\x0b\x63ookieFound\x18\x37 \x01(\x0b\x32\x0c.CookieFoundH\x00\x12\x37\n\x15playerEntersWhisperV2\x18\x38 \x01(\x0b\x32\x16.PlayerEntersWhisperV2H\x00\x12\x31\n\x12playerSetsGoKartId\x18\x39 \x01(\x0b\x32\x13.PlayerSetsGoKartIdH\x00\x12-\n\x10mapSetDimensions\x18: \x01(\x0b\x32\x11.MapSetDimensionsH\x00\x12-\n\x10mapSetCollisions\x18; \x01(\x0b\x32\x11.MapSetCollisionsH\x00\x12?\n\x19mapSetBackgroundImagePath\x18< \x01(\x0b\x32\x1a.MapSetBackgroundImagePathH\x00\x12?\n\x19mapSetForegroundImagePath\x18= \x01(\x0b\x32\x1a.MapSetForegroundImagePathH\x00\x12\'\n\rmapSetSprites\x18> \x01(\x0b\x32\x0e.MapSetSpritesH\x00\x12%\n\x0cmapSetSpaces\x18? \x01(\x0b\x32\r.MapSetSpacesH\x00\x12%\n\x0cmapSetSpawns\x18@ \x01(\x0b\x32\r.MapSetSpawnsH\x00\x12\'\n\rmapSetPortals\x18\x41 \x01(\x0b\x32\x0e.MapSetPortalsH\x00\x12+\n\x0fmapSetAnnouncer\x18\x42 \x01(\x0b\x32\x10.MapSetAnnouncerH\x00\x12%\n\x0cmapSetAssets\x18\x45 \x01(\x0b\x32\r.MapSetAssetsH\x00\x12\'\n\rmapSetObjects\x18\x46 \x01(\x0b\x32\x0e.MapSetObjectsH\x00\x12!\n\nmapSetName\x18G \x01(\x0b\x32\x0b.MapSetNameH\x00\x12/\n\x11mapSetMuteOnEntry\x18I \x01(\x0b\x32\x12.MapSetMuteOnEntryH\x00\x12-\n\x10mapSetUseDrawnBG\x18J \x01(\x0b\x32\x11.MapSetUseDrawnBGH\x00\x12#\n\x0bmapSetWalls\x18K \x01(\x0b\x32\x0c.MapSetWallsH\x00\x12%\n\x0cmapSetFloors\x18L \x01(\x0b\x32\r.MapSetFloorsH\x00\x12#\n\x0bmapSetAreas\x18M \x01(\x0b\x32\x0c.MapSetAreasH\x00\x12+\n\x0fmapDeleteObject\x18N \x01(\x0b\x32\x10.MapDeleteObjectH\x00\x12#\n\x0bmapSetSpawn\x18O \x01(\x0b\x32\x0c.MapSetSpawnH\x00\x12/\n\x11playerSetsIsAlone\x18P \x01(\x0b\x32\x12.PlayerSetsIsAloneH\x00\x12#\n\x0bplayerJoins\x18Q \x01(\x0b\x32\x0c.PlayerJoinsH\x00\x12\x31\n\x12mapSetEnabledChats\x18R \x01(\x0b\x32\x13.MapSetEnabledChatsH\x00\x12/\n\x11mapSetDescription\x18S \x01(\x0b\x32\x12.MapSetDescriptionH\x00\x12-\n\x10mapSetDecoration\x18T \x01(\x0b\x32\x11.MapSetDecorationH\x00\x12\x33\n\x13mapSetTutorialTasks\x18U \x01(\x0b\x32\x14.MapSetTutorialTasksH\x00\x12\x39\n\x16mapSetMiniMapImagePath\x18V \x01(\x0b\x32\x17.MapSetMiniMapImagePathH\x00\x12+\n\x0fspacePlaysSound\x18W \x01(\x0b\x32\x10.SpacePlaysSoundH\x00\x12%\n\x0cmapSetScript\x18X \x01(\x0b\x32\r.MapSetScriptH\x00\x12\x31\n\x12playerSetsIsMobile\x18Z \x01(\x0b\x32\x13.PlayerSetsIsMobileH\x00\x12\x39\n\x16setScreenPointerServer\x18[ \x01(\x0b\x32\x17.SetScreenPointerServerH\x00\x12/\n\x11playerSetsEmoteV2\x18\\ \x01(\x0b\x32\x12.PlayerSetsEmoteV2H\x00\x12\x41\n\x1aplayerSetsFocusModeEndTime\x18] \x01(\x0b\x32\x1b.PlayerSetsFocusModeEndTimeH\x00\x12\x37\n\x15spaceSetsSpaceMembers\x18^ \x01(\x0b\x32\x16.SpaceSetsSpaceMembersH\x00\x12#\n\x0b\x63ustomEvent\x18_ \x01(\x0b\x32\x0c.CustomEventH\x00\x12%\n\x0cplayerBlocks\x18\x61 \x01(\x0b\x32\r.PlayerBlocksH\x00\x12\x45\n\x1cplayerUpdatesFocusModeStatus\x18\x62 \x01(\x0b\x32\x1d.PlayerUpdatesFocusModeStatusH\x00\x12)\n\x0eplayerNotifies\x18\x63 \x01(\x0b\x32\x0f.PlayerNotifiesH\x00\x12\x35\n\x14playerSetsItemString\x18l \x01(\x0b\x32\x15.PlayerSetsItemStringH\x00\x12\x31\n\x12playerTriggersItem\x18m \x01(\x0b\x32\x13.PlayerTriggersItemH\x00\x12\x39\n\x16playerSetsFollowTarget\x18n \x01(\x0b\x32\x17.PlayerSetsFollowTargetH\x00\x12\x35\n\x14playerRequestsToLead\x18o \x01(\x0b\x32\x15.PlayerRequestsToLeadH\x00\x12=\n\x18playerSetsManualVideoSrc\x18p \x01(\x0b\x32\x19.PlayerSetsManualVideoSrcH\x00\x12+\n\x0fplayerSetsIsNpc\x18q \x01(\x0b\x32\x10.PlayerSetsIsNpcH\x00\x12\x31\n\x12playerSetsSubtitle\x18r \x01(\x0b\x32\x13.PlayerSetsSubtitleH\x00\x12/\n\x11mapCommitsChanges\x18s \x01(\x0b\x32\x12.MapCommitsChangesH\x00\x12\x35\n\x14playerUpdatesSession\x18t \x01(\x0b\x32\x15.PlayerUpdatesSessionH\x00\x12\'\n\rmapMoveObject\x18u \x01(\x0b\x32\x0e.MapMoveObjectH\x00\x12\x39\n\x16playerEditsChatMessage\x18v \x01(\x0b\x32\x17.PlayerEditsChatMessageH\x00\x12\'\n\rfxShakeObject\x18w \x01(\x0b\x32\x0e.FXShakeObjectH\x00\x12\'\n\rfxShakeCamera\x18x \x01(\x0b\x32\x0e.FXShakeCameraH\x00\x12\x31\n\x12playerSendsCommand\x18y \x01(\x0b\x32\x13.PlayerSendsCommandH\x00\x12\x37\n\x15spaceRegistersCommand\x18z \x01(\x0b\x32\x16.SpaceRegistersCommandH\x00\x12\x37\n\x15speakerUpdatesSession\x18{ \x01(\x0b\x32\x16.SpeakerUpdatesSessionH\x00\x12\x39\n\x16playerUpdatesInventory\x18| \x01(\x0b\x32\x17.PlayerUpdatesInventoryH\x00\x12/\n\x11spaceUpdatesItems\x18} \x01(\x0b\x32\x12.SpaceUpdatesItemsH\x00\x12\x33\n\x13playerSetsVehicleId\x18~ \x01(\x0b\x32\x14.PlayerSetsVehicleIdH\x00\x12;\n\x17playerSetsSpeedModifier\x18\x7f \x01(\x0b\x32\x18.PlayerSetsSpeedModifierH\x00\x12,\n\x0fplayerHighFives\x18\x80\x01 \x01(\x0b\x32\x10.PlayerHighFivesH\x00\x12,\n\x0fspaceStopsSound\x18\x82\x01 \x01(\x0b\x32\x10.SpaceStopsSoundH\x00\x12(\n\rhipToBeSquare\x18\x83\x01 \x01(\x0b\x32\x0e.HipToBeSquareH\x00\x12&\n\x0cplayerCrafts\x18\x84\x01 \x01(\x0b\x32\r.PlayerCraftsH\x00\x12\x44\n\x1bplayerTriggersInventoryItem\x18\x85\x01 \x01(\x0b\x32\x1c.PlayerTriggersInventoryItemH\x00\x12\x46\n\x1cplayerSetsAllowScreenPointer\x18\x86\x01 \x01(\x0b\x32\x1d.PlayerSetsAllowScreenPointerH\x00\x12>\n\x18precomputedEnterLocation\x18\x87\x01 \x01(\x0b\x32\x19.PrecomputedEnterLocationH\x00\x12*\n\x0egotRequestMute\x18\x88\x01 \x01(\x0b\x32\x0f.GotRequestMuteH\x00\x12\x32\n\x12playerSetsDeskInfo\x18\x89\x01 \x01(\x0b\x32\x13.PlayerSetsDeskInfoH\x00\x12$\n\x0bmapSetNooks\x18\x8a\x01 \x01(\x0b\x32\x0c.MapSetNooksH\x00\x12&\n\x0c\x64ynamicGates\x18\x8b\x01 \x01(\x0b\x32\r.DynamicGatesH\x00\x12$\n\x0bplayerWaves\x18\x8c\x01 \x01(\x0b\x32\x0c.PlayerWavesH\x00\x12\x32\n\x12playerSetsPronouns\x18\x8d\x01 \x01(\x0b\x32\x13.PlayerSetsPronounsH\x00\x12,\n\x0fplayerSetsTitle\x18\x8e\x01 \x01(\x0b\x32\x10.PlayerSetsTitleH\x00\x12\x32\n\x12playerSetsTimezone\x18\x8f\x01 \x01(\x0b\x32\x13.PlayerSetsTimezoneH\x00\x12\x38\n\x15playerSetsDescription\x18\x90\x01 \x01(\x0b\x32\x16.PlayerSetsDescriptionH\x00\x12,\n\x0fplayerSetsPhone\x18\x91\x01 \x01(\x0b\x32\x10.PlayerSetsPhoneH\x00\x12\x42\n\x1aplayerSetsPersonalImageUrl\x18\x92\x01 \x01(\x0b\x32\x1b.PlayerSetsPersonalImageUrlH\x00\x12@\n\x19playerSetsProfileImageUrl\x18\x93\x01 \x01(\x0b\x32\x1a.PlayerSetsProfileImageUrlH\x00\x12\x30\n\x11spaceSetsCapacity\x18\x94\x01 \x01(\x0b\x32\x12.SpaceSetsCapacityH\x00\x12\x44\n\x1bspaceOverCapacityDeniesUser\x18\x95\x01 \x01(\x0b\x32\x1c.SpaceOverCapacityDeniesUserH\x00\x12*\n\x0eplayerSetsAway\x18\x96\x01 \x01(\x0b\x32\x0f.PlayerSetsAwayH\x00\x12\x36\n\x14mapSetCollisionsBits\x18\x97\x01 \x01(\x0b\x32\x15.MapSetCollisionsBitsH\x00\x12*\n\x0eplayerSetsCity\x18\x98\x01 \x01(\x0b\x32\x0f.PlayerSetsCityH\x00\x12\x30\n\x11playerSetsCountry\x18\x99\x01 \x01(\x0b\x32\x12.PlayerSetsCountryH\x00\x12\x34\n\x13playerSetsStartDate\x18\x9a\x01 \x01(\x0b\x32\x14.PlayerSetsStartDateH\x00\x12\x44\n\x1bplayerSetsIsRecordingClient\x18\x9b\x01 \x01(\x0b\x32\x1c.PlayerSetsIsRecordingClientH\x00\x12\x38\n\x15playerStartsRecording\x18\x9c\x01 \x01(\x0b\x32\x16.PlayerStartsRecordingH\x00\x42\x07\n\x05\x65vent\"\"\n\x0fServerHeartbeat\x12\x0f\n\x07lastRTT\x18\x01 \x01(\r\"\x17\n\x04Info\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x17\n\x04Warn\x12\x0f\n\x07message\x18\x01 \x01(\t\"+\n\nErrorEvent\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\r\"\x13\n\x05Ready\x12\n\n\x02id\x18\x01 \x01(\t\"U\n\x11TransactionStatus\x12\r\n\x05txnId\x18\x01 \x01(\r\x12\x11\n\tsucceeded\x18\x02 \x01(\x08\x12\x13\n\x06reason\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\t\n\x07_reason\"\x1c\n\x0bPlayerJoins\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\"0\n\x0eGotRequestMute\x12\x0f\n\x07muterId\x18\x01 \x01(\t\x12\r\n\x05video\x18\x02 \x01(\x08\"\xbc\x01\n\x0bPlayerMoves\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0e\n\x01x\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x0e\n\x01y\x18\x03 \x01(\rH\x01\x88\x01\x01\x12\x31\n\tdirection\x18\x04 \x01(\x0e\x32\x19.SpriteDirectionEnum.ENUMH\x02\x88\x01\x01\x12\x12\n\x05mapId\x18\x05 \x01(\tH\x03\x88\x01\x01\x12\x13\n\x0blastInputId\x18\x06 \x01(\rB\x04\n\x02_xB\x04\n\x02_yB\x0c\n\n_directionB\x08\n\x06_mapId\"/\n\x10PlayerSetsStatus\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0c\n\x04\x62usy\x18\x02 \x01(\x08\"M\n\x10PlayerSpotlights\x12\r\n\x05\x65ncId\x18\x02 \x01(\r\x12\x15\n\rspotlightedBy\x18\x01 \x01(\r\x12\x13\n\x0bspotlighted\x18\x03 \x01(\r\"\x1c\n\x0bPlayerRings\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\"O\n\x16PlayerSetsImagePointer\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08objectId\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\"^\n\x16SetScreenPointerServer\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08screenId\x18\x02 \x01(\t\x12\t\n\x01x\x18\x03 \x01(\x01\x12\t\n\x01y\x18\x04 \x01(\x01\x12\r\n\x05\x63olor\x18\x05 \x01(\t\"\xad\x02\n\x0bPlayerChats\x12\x10\n\x08senderId\x18\x01 \x01(\t\x12\x11\n\trecipient\x18\x02 \x01(\t\x12\x10\n\x08\x63ontents\x18\x03 \x01(\t\x12\x12\n\nsenderName\x18\x04 \x01(\t\x12\"\n\ttimestamp\x18\x05 \x01(\x0b\x32\n.TimestampH\x00\x88\x01\x01\x12\x13\n\x0bmessageType\x18\x06 \x01(\t\x12\x10\n\x08unixTime\x18\x07 \x01(\x01\x12\x0f\n\x02id\x18\x08 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06roomId\x18\t \x01(\tH\x02\x88\x01\x01\x12\x15\n\x08\x61pproved\x18\n \x01(\x08H\x03\x88\x01\x01\x12\x13\n\x06nookId\x18\x0b \x01(\tH\x04\x88\x01\x01\x42\x0c\n\n_timestampB\x05\n\x03_idB\t\n\x07_roomIdB\x0b\n\t_approvedB\t\n\x07_nookId\"?\n\x0bPlayerWaves\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08targetId\x18\x02 \x01(\t\x12\x0f\n\x07isReply\x18\x03 \x01(\x08\"1\n\tTimestamp\x12\x0f\n\x07seconds\x18\x01 \x01(\x02\x12\x13\n\x0bnanoseconds\x18\x02 \x01(\x02\"q\n\x0fPlayerInteracts\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\r\n\x05objId\x18\x02 \x01(\t\x12\x12\n\x05mapId\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x64\x61taJson\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_mapIdB\x0b\n\t_dataJson\",\n\x0cPlayerGhosts\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\r\n\x05ghost\x18\x02 \x01(\r\"Q\n\x13PlayerEntersWhisper\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x18\n\x10whisperRecipient\x18\x02 \x01(\t\x12\x11\n\twhisperId\x18\x03 \x01(\t\"N\n\x15PlayerEntersWhisperV2\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x65ncIdTarget\x18\x02 \x01(\r\x12\x11\n\twhisperId\x18\x03 \x01(\t\"$\n\x13PlayerLeavesWhisper\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\"?\n\x14PlayerActivelySpeaks\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x18\n\x10\x61\x63tivelySpeaking\x18\x02 \x01(\r\"^\n\x11PlayerSetsEmoteV2\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x12\n\x05\x65mote\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x01\x88\x01\x01\x42\x08\n\x06_emoteB\x08\n\x06_count\"?\n\x17PlayerSetsWorkCondition\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x15\n\rworkCondition\x18\x02 \x01(\r\"9\n\x14PlayerSetsLastActive\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x12\n\nlastActive\x18\x02 \x01(\t\"-\n\x0ePlayerSetsName\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\"9\n\x14PlayerSetsTextStatus\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x12\n\ntextStatus\x18\x02 \x01(\t\"5\n\x12PlayerSetsPronouns\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08pronouns\x18\x02 \x01(\t\"/\n\x0fPlayerSetsTitle\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\r\n\x05title\x18\x02 \x01(\t\"-\n\x0ePlayerSetsCity\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0c\n\x04\x63ity\x18\x02 \x01(\t\"3\n\x11PlayerSetsCountry\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0f\n\x07\x63ountry\x18\x02 \x01(\t\"7\n\x13PlayerSetsStartDate\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x11\n\tstartDate\x18\x02 \x01(\t\"5\n\x12PlayerSetsTimezone\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08timezone\x18\x02 \x01(\t\"/\n\x0fPlayerSetsPhone\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\r\n\x05phone\x18\x02 \x01(\t\";\n\x15PlayerSetsDescription\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"C\n\x19PlayerSetsProfileImageUrl\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x17\n\x0fprofileImageUrl\x18\x02 \x01(\t\"E\n\x1aPlayerSetsPersonalImageUrl\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x18\n\x10personalImageUrl\x18\x02 \x01(\t\"5\n\x12PlayerSetsIsMobile\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08isMobile\x18\x02 \x01(\x08\";\n\x15PlayerSetsEmojiStatus\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x65mojiStatus\x18\x02 \x01(\t\";\n\x15PlayerSetsAffiliation\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x61\x66\x66iliation\x18\x02 \x01(\t\"\x1c\n\x0bPlayerExits\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\"=\n\x16PlayerSetsOutfitString\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x14\n\x0coutfitString\x18\x02 \x01(\t\"9\n\x14PlayerSetsIsSignedIn\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x12\n\nisSignedIn\x18\x02 \x01(\x08\"\x11\n\x0fRespawnComplete\"$\n\x0fSpaceOverwrites\x12\x11\n\tspaceData\x18\x01 \x01(\t\"/\n\x0b\x44ynamicGate\x12\x10\n\x08\x65xposure\x18\x01 \x01(\x02\x12\x0e\n\x06spaces\x18\x02 \x03(\t\"4\n\x0c\x44ynamicGates\x12$\n\x0elivekitEnabled\x18\x01 \x01(\x0b\x32\x0c.DynamicGate\"\x8f\x01\n\x15SpaceSetsSpaceMembers\x12\x34\n\x07members\x18\x01 \x03(\x0b\x32#.SpaceSetsSpaceMembers.MembersEntry\x1a@\n\x0cMembersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1f\n\x05value\x18\x02 \x01(\x0b\x32\x10.SpaceMemberInfo:\x02\x38\x01\"\x0f\n\rSpaceIsClosed\"S\n\x12PlayerEntersPortal\x12\x11\n\ttargetUrl\x18\x01 \x01(\t\x12\x19\n\x0c\x62ypassPrompt\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\x0f\n\r_bypassPrompt\"\x1c\n\x0b\x43ookieFound\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\"0\n\x12SpaceSetsIdMapping\x12\x0b\n\x03uid\x18\x01 \x01(\t\x12\r\n\x05\x65ncId\x18\x02 \x01(\r\"%\n\x14PlayerShootsConfetti\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\";\n\x15PlayerSetsEventStatus\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x65ventStatus\x18\x02 \x01(\t\"A\n\x18PlayerSetsInConversation\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x16\n\x0einConversation\x18\x02 \x01(\x08\";\n\x15PlayerSetsCurrentDesk\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x63urrentDesk\x18\x02 \x01(\t\";\n\x15PlayerSetsCurrentArea\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x63urrentArea\x18\x02 \x01(\t\"5\n\x12PlayerSetsGoKartId\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08goKartId\x18\x02 \x01(\t\"b\n\x13PlayerSetsVehicleId\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x11\n\tvehicleId\x18\x02 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\t\x12\x19\n\x11previousVehicleId\x18\x04 \x01(\t\"?\n\x17PlayerSetsSpeedModifier\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x15\n\rspeedModifier\x18\x02 \x01(\x02\"3\n\x11PlayerSetsIsAlone\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0f\n\x07isAlone\x18\x02 \x01(\x08\".\n\x0fSpacePlaysSound\x12\x0b\n\x03src\x18\x02 \x01(\t\x12\x0e\n\x06volume\x18\x03 \x01(\x02\"\x1e\n\x0fSpaceStopsSound\x12\x0b\n\x03src\x18\x02 \x01(\t\"E\n\x1aPlayerSetsFocusModeEndTime\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x18\n\x10\x66ocusModeEndTime\x18\x02 \x01(\t\"2\n\x0cPlayerBlocks\x12\x11\n\tblockedBy\x18\x01 \x01(\t\x12\x0f\n\x07\x62locked\x18\x02 \x01(\x08\",\n\x0b\x43ustomEvent\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\t\"D\n\x1cPlayerUpdatesFocusModeStatus\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x15\n\risInFocusMode\x18\x02 \x01(\x08\"9\n\x14PlayerSetsItemString\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x12\n\nitemString\x18\x02 \x01(\t\"\x8f\x01\n\x12PlayerTriggersItem\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x1a\n\rclosestObject\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x63losestObjectTemplate\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_closestObjectB\x18\n\x16_closestObjectTemplate\"5\n\x0ePlayerNotifies\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x14\n\x0cnotification\x18\x02 \x01(\t\"=\n\x16PlayerSetsFollowTarget\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x14\n\x0c\x66ollowTarget\x18\x02 \x01(\t\"7\n\x14PlayerRequestsToLead\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08snapshot\x18\x02 \x01(\t\"A\n\x18PlayerSetsManualVideoSrc\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x16\n\x0emanualVideoSrc\x18\x02 \x01(\t\"/\n\x0fPlayerSetsIsNpc\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\r\n\x05isNpc\x18\x02 \x01(\x08\"5\n\x12PlayerSetsSubtitle\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x10\n\x08subtitle\x18\x02 \x01(\t\"w\n\x0cPlayerCrafts\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12)\n\x06inputs\x18\x02 \x03(\x0b\x32\x19.PlayerCrafts.InputsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r:\x02\x38\x01\"\xe0\x01\n\rMapMoveObject\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x10\n\x08objectId\x18\x02 \x01(\t\x12\x0f\n\x07targetX\x18\x03 \x01(\x02\x12\x0f\n\x07targetY\x18\x04 \x01(\x02\x12\x1a\n\rtargetXOffset\x18\x05 \x01(\x02H\x00\x88\x01\x01\x12\x1a\n\rtargetYOffset\x18\x06 \x01(\x02H\x01\x88\x01\x01\x12\x10\n\x08\x64uration\x18\x07 \x01(\x02\x12\x13\n\x06\x65\x61sing\x18\x08 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_targetXOffsetB\x10\n\x0e_targetYOffsetB\t\n\x07_easing\"\xb2\x01\n\x16PlayerEditsChatMessage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\x05likes\x18\x02 \x01(\rH\x00\x88\x01\x01\x12\x14\n\x07replied\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x1e\n\x05reply\x18\x04 \x01(\x0b\x32\n.ChatReplyH\x02\x88\x01\x01\x12\x15\n\x08\x61pproved\x18\x05 \x01(\x08H\x03\x88\x01\x01\x42\x08\n\x06_likesB\n\n\x08_repliedB\x08\n\x06_replyB\x0b\n\t_approved\"\x9a\x01\n\rFXShakeObject\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x10\n\x08targetId\x18\x02 \x01(\t\x12\x16\n\tintensity\x18\x03 \x01(\x02H\x00\x88\x01\x01\x12\x17\n\ndurationMs\x18\x04 \x01(\x02H\x01\x88\x01\x01\x12\x11\n\x04mode\x18\x05 \x01(\rH\x02\x88\x01\x01\x42\x0c\n\n_intensityB\r\n\x0b_durationMsB\x07\n\x05_mode\"\xa7\x01\n\rFXShakeCamera\x12\x16\n\tintensity\x18\x01 \x01(\x02H\x00\x88\x01\x01\x12\x17\n\ndurationMs\x18\x02 \x01(\x02H\x01\x88\x01\x01\x12\x12\n\x05mapId\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x19\n\x0ctargetUserId\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x0c\n\n_intensityB\r\n\x0b_durationMsB\x08\n\x06_mapIdB\x0f\n\r_targetUserId\"5\n\x0fPlayerHighFives\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x13\n\x0b\x65ncIdTarget\x18\x02 \x01(\r\"4\n\x12PlayerSendsCommand\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\"(\n\x15SpaceRegistersCommand\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\t\"\xf9\x01\n\x16PlayerUpdatesInventory\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x31\n\x05items\x18\x02 \x03(\x0b\x32\".PlayerUpdatesInventory.ItemsEntry\x12\x31\n\x05order\x18\x03 \x03(\x0b\x32\".PlayerUpdatesInventory.OrderEntry\x1a<\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.InventoryItem:\x02\x38\x01\x1a,\n\nOrderEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"{\n\x11SpaceUpdatesItems\x12,\n\x05items\x18\x01 \x03(\x0b\x32\x1d.SpaceUpdatesItems.ItemsEntry\x1a\x38\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x19\n\x05value\x18\x02 \x01(\x0b\x32\n.SpaceItem:\x02\x38\x01\"O\n\x1bPlayerTriggersInventoryItem\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0e\n\x06itemId\x18\x02 \x01(\t\x12\x11\n\tabilityId\x18\x03 \x01(\t\"I\n\x1cPlayerSetsAllowScreenPointer\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x1a\n\x12\x61llowScreenPointer\x18\x02 \x01(\x08\"?\n\x18PrecomputedEnterLocation\x12#\n\renterLocation\x18\x01 \x01(\x0b\x32\x0c.MapLocation\"B\n\x12PlayerSetsDeskInfo\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x1d\n\x08\x64\x65skInfo\x18\x02 \x01(\x0b\x32\x0b.DeskInfoV2\"%\n\x11SpaceSetsCapacity\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\r\"-\n\x1bSpaceOverCapacityDeniesUser\x12\x0e\n\x06userId\x18\x01 \x01(\t\"-\n\x0ePlayerSetsAway\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0c\n\x04\x61way\x18\x02 \x01(\x08\"G\n\x1bPlayerSetsIsRecordingClient\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x19\n\x11isRecordingClient\x18\x02 \x01(\x08\"V\n\x15PlayerStartsRecording\x12\r\n\x05\x65ncId\x18\x01 \x01(\r\x12\x0e\n\x06nookId\x18\x02 \x01(\t\x12\x13\n\x06\x63\x61ncel\x18\x03 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_cancel\"9\n\x11\x43lientServerBatch\x12$\n\x07\x61\x63tions\x18\x01 \x03(\x0b\x32\x13.ClientServerAction\"\x91%\n\x12\x43lientServerAction\x12\x12\n\x05txnId\x18\x64 \x01(\rH\x01\x88\x01\x01\x12+\n\x0f\x63lientHeartbeat\x18\x01 \x01(\x0b\x32\x10.ClientHeartbeatH\x00\x12\x37\n\x15\x63lientBackupHeartbeat\x18\x02 \x01(\x0b\x32\x16.ClientBackupHeartbeatH\x00\x12\x33\n\x13updateSubscriptions\x18\x03 \x01(\x0b\x32\x14.UpdateSubscriptionsH\x00\x12\x15\n\x04move\x18\x05 \x01(\x0b\x32\x05.MoveH\x00\x12)\n\x0esetAffiliation\x18\x07 \x01(\x0b\x32\x0f.SetAffiliationH\x00\x12\x1f\n\tsetStatus\x18\x08 \x01(\x0b\x32\n.SetStatusH\x00\x12\x1f\n\tspotlight\x18\t \x01(\x0b\x32\n.SpotlightH\x00\x12\x15\n\x04ring\x18\n \x01(\x0b\x32\x05.RingH\x00\x12\x13\n\x03\x62\x61n\x18\x0c \x01(\x0b\x32\x04.BanH\x00\x12\x15\n\x04kick\x18\r \x01(\x0b\x32\x05.KickH\x00\x12\'\n\rsetImpassable\x18\x0e \x01(\x0b\x32\x0e.SetImpassableH\x00\x12\x15\n\x04\x63hat\x18\x0f \x01(\x0b\x32\x05.ChatH\x00\x12\x1d\n\x08interact\x18\x12 \x01(\x0b\x32\t.InteractH\x00\x12%\n\x0c\x65nterWhisper\x18\x13 \x01(\x0b\x32\r.EnterWhisperH\x00\x12%\n\x0cleaveWhisper\x18\x14 \x01(\x0b\x32\r.LeaveWhisperH\x00\x12)\n\x0esetEmojiStatus\x18\x15 \x01(\x0b\x32\x0f.SetEmojiStatusH\x00\x12-\n\x10\x61\x63tivelySpeaking\x18\x16 \x01(\x0b\x32\x11.ActivelySpeakingH\x00\x12\x1b\n\x07setName\x18\x18 \x01(\x0b\x32\x08.SetNameH\x00\x12\'\n\rsetTextStatus\x18\x19 \x01(\x0b\x32\x0e.SetTextStatusH\x00\x12\x1d\n\x08teleport\x18\x1a \x01(\x0b\x32\t.TeleportH\x00\x12\x15\n\x04\x65xit\x18\x1b \x01(\x0b\x32\x05.ExitH\x00\x12\x17\n\x05\x65nter\x18\x1c \x01(\x0b\x32\x06.EnterH\x00\x12-\n\x10setWorkCondition\x18\x1d \x01(\x0b\x32\x11.SetWorkConditionH\x00\x12\x1b\n\x07respawn\x18\x1e \x01(\x0b\x32\x08.RespawnH\x00\x12\x17\n\x05spawn\x18\x1f \x01(\x0b\x32\x06.SpawnH\x00\x12\x17\n\x05ghost\x18  \x01(\x0b\x32\x06.GhostH\x00\x12\x15\n\x04init\x18! \x01(\x0b\x32\x05.InitH\x00\x12+\n\x0fsetOutfitString\x18\" \x01(\x0b\x32\x10.SetOutfitStringH\x00\x12\'\n\rshootConfetti\x18$ \x01(\x0b\x32\x0e.ShootConfettiH\x00\x12)\n\x0esetEventStatus\x18% \x01(\x0b\x32\x0f.SetEventStatusH\x00\x12/\n\x11setInConversation\x18& \x01(\x0b\x32\x12.SetInConversationH\x00\x12)\n\x0esetCurrentDesk\x18\' \x01(\x0b\x32\x0f.SetCurrentDeskH\x00\x12)\n\x0esetCurrentArea\x18( \x01(\x0b\x32\x0f.SetCurrentAreaH\x00\x12+\n\x0fsetImagePointer\x18) \x01(\x0b\x32\x10.SetImagePointerH\x00\x12#\n\x0bsetGoKartId\x18* \x01(\x0b\x32\x0c.SetGoKartIdH\x00\x12-\n\x10mapSetDimensions\x18+ \x01(\x0b\x32\x11.MapSetDimensionsH\x00\x12-\n\x10mapSetCollisions\x18, \x01(\x0b\x32\x11.MapSetCollisionsH\x00\x12?\n\x19mapSetBackgroundImagePath\x18- \x01(\x0b\x32\x1a.MapSetBackgroundImagePathH\x00\x12?\n\x19mapSetForegroundImagePath\x18. \x01(\x0b\x32\x1a.MapSetForegroundImagePathH\x00\x12\'\n\rmapSetSprites\x18/ \x01(\x0b\x32\x0e.MapSetSpritesH\x00\x12%\n\x0cmapSetSpawns\x18\x30 \x01(\x0b\x32\r.MapSetSpawnsH\x00\x12%\n\x0cmapSetSpaces\x18\x31 \x01(\x0b\x32\r.MapSetSpacesH\x00\x12\'\n\rmapSetPortals\x18\x32 \x01(\x0b\x32\x0e.MapSetPortalsH\x00\x12+\n\x0fmapSetAnnouncer\x18\x33 \x01(\x0b\x32\x10.MapSetAnnouncerH\x00\x12%\n\x0cmapSetAssets\x18\x36 \x01(\x0b\x32\r.MapSetAssetsH\x00\x12\'\n\rmapSetObjects\x18\x37 \x01(\x0b\x32\x0e.MapSetObjectsH\x00\x12!\n\nmapSetName\x18\x38 \x01(\x0b\x32\x0b.MapSetNameH\x00\x12/\n\x11mapSetMuteOnEntry\x18: \x01(\x0b\x32\x12.MapSetMuteOnEntryH\x00\x12-\n\x10mapSetUseDrawnBG\x18; \x01(\x0b\x32\x11.MapSetUseDrawnBGH\x00\x12#\n\x0bmapSetWalls\x18< \x01(\x0b\x32\x0c.MapSetWallsH\x00\x12%\n\x0cmapSetFloors\x18= \x01(\x0b\x32\r.MapSetFloorsH\x00\x12#\n\x0bmapSetAreas\x18> \x01(\x0b\x32\x0c.MapSetAreasH\x00\x12%\n\x0cmapAddObject\x18? \x01(\x0b\x32\r.MapAddObjectH\x00\x12+\n\x0fmapDeleteObject\x18@ \x01(\x0b\x32\x10.MapDeleteObjectH\x00\x12#\n\x0bmapSetSpawn\x18\x41 \x01(\x0b\x32\x0c.MapSetSpawnH\x00\x12!\n\nsetIsAlone\x18\x42 \x01(\x0b\x32\x0b.SetIsAloneH\x00\x12\x39\n\x16mapSetMiniMapImagePath\x18\x43 \x01(\x0b\x32\x17.MapSetMiniMapImagePathH\x00\x12\x31\n\x12mapSetEnabledChats\x18\x44 \x01(\x0b\x32\x13.MapSetEnabledChatsH\x00\x12/\n\x11mapSetDescription\x18\x45 \x01(\x0b\x32\x12.MapSetDescriptionH\x00\x12-\n\x10mapSetDecoration\x18\x46 \x01(\x0b\x32\x11.MapSetDecorationH\x00\x12\x33\n\x13mapSetTutorialTasks\x18G \x01(\x0b\x32\x14.MapSetTutorialTasksH\x00\x12\x1f\n\tplaySound\x18H \x01(\x0b\x32\n.PlaySoundH\x00\x12%\n\x0cmapSetScript\x18I \x01(\x0b\x32\r.MapSetScriptH\x00\x12#\n\x0bsetIsMobile\x18K \x01(\x0b\x32\x0c.SetIsMobileH\x00\x12-\n\x10setScreenPointer\x18L \x01(\x0b\x32\x11.SetScreenPointerH\x00\x12!\n\nsetEmoteV2\x18M \x01(\x0b\x32\x0b.SetEmoteV2H\x00\x12\x33\n\x13setFocusModeEndTime\x18N \x01(\x0b\x32\x14.SetFocusModeEndTimeH\x00\x12\x33\n\x13mapDeleteObjectById\x18O \x01(\x0b\x32\x14.MapDeleteObjectByIdH\x00\x12%\n\x0c\x63ustomAction\x18P \x01(\x0b\x32\r.CustomActionH\x00\x12\x17\n\x05\x62lock\x18R \x01(\x0b\x32\x06.BlockH\x00\x12\'\n\rsetItemString\x18S \x01(\x0b\x32\x0e.SetItemStringH\x00\x12#\n\x0btriggerItem\x18T \x01(\x0b\x32\x0c.TriggerItemH\x00\x12\x19\n\x06notify\x18U \x01(\x0b\x32\x07.NotifyH\x00\x12+\n\x0fsetFollowTarget\x18V \x01(\x0b\x32\x10.SetFollowTargetH\x00\x12\'\n\rrequestToLead\x18W \x01(\x0b\x32\x0e.RequestToLeadH\x00\x12#\n\x0b\x65nterPortal\x18X \x01(\x0b\x32\x0c.EnterPortalH\x00\x12/\n\x11setManualVideoSrc\x18Y \x01(\x0b\x32\x12.SetManualVideoSrcH\x00\x12#\n\x0bsetSubtitle\x18Z \x01(\x0b\x32\x0c.SetSubtitleH\x00\x12\x35\n\x14playerUpdatesSession\x18[ \x01(\x0b\x32\x15.PlayerUpdatesSessionH\x00\x12\'\n\rmapMoveObject\x18\\ \x01(\x0b\x32\x0e.MapMoveObjectH\x00\x12\x31\n\x12\x63hatMessageUpdated\x18] \x01(\x0b\x32\x13.ChatMessageUpdatedH\x00\x12\'\n\rfxShakeObject\x18^ \x01(\x0b\x32\x0e.FXShakeObjectH\x00\x12\'\n\rfxShakeCamera\x18_ \x01(\x0b\x32\x0e.FXShakeCameraH\x00\x12+\n\x0fregisterCommand\x18` \x01(\x0b\x32\x10.RegisterCommandH\x00\x12#\n\x0bsendCommand\x18\x61 \x01(\x0b\x32\x0c.SendCommandH\x00\x12\x37\n\x15speakerUpdatesSession\x18\x62 \x01(\x0b\x32\x16.SpeakerUpdatesSessionH\x00\x12-\n\x10\x61\x64\x64InventoryItem\x18\x65 \x01(\x0b\x32\x11.AddInventoryItemH\x00\x12\x33\n\x13removeInventoryItem\x18\x66 \x01(\x0b\x32\x14.RemoveInventoryItemH\x00\x12%\n\x0csetVehicleId\x18g \x01(\x0b\x32\r.SetVehicleIdH\x00\x12-\n\x10setSpeedModifier\x18h \x01(\x0b\x32\x11.SetSpeedModifierH\x00\x12\x1d\n\x08highFive\x18i \x01(\x0b\x32\t.HighFiveH\x00\x12.\n\x10updateSpaceItems\x18k \x01(\x0b\x32\x12.SpaceUpdatesItemsH\x00\x12\x1f\n\tstopSound\x18l \x01(\x0b\x32\n.StopSoundH\x00\x12\'\n\rhipToBeSquare\x18m \x01(\x0b\x32\x0e.HipToBeSquareH\x00\x12\x17\n\x05\x63raft\x18n \x01(\x0b\x32\x06.CraftH\x00\x12\x35\n\x14triggerInventoryItem\x18o \x01(\x0b\x32\x15.TriggerInventoryItemH\x00\x12\x37\n\x15setAllowScreenPointer\x18p \x01(\x0b\x32\x16.SetAllowScreenPointerH\x00\x12+\n\x0fprecomputeEnter\x18q \x01(\x0b\x32\x10.PrecomputeEnterH\x00\x12#\n\x0brequestMute\x18r \x01(\x0b\x32\x0c.RequestMuteH\x00\x12#\n\x0bsetDeskInfo\x18s \x01(\x0b\x32\x0c.SetDeskInfoH\x00\x12#\n\x0bmapSetNooks\x18t \x01(\x0b\x32\x0c.MapSetNooksH\x00\x12/\n\x11requestToJoinNook\x18u \x01(\x0b\x32\x12.RequestToJoinNookH\x00\x12\x35\n\x14updateNookPermission\x18v \x01(\x0b\x32\x15.UpdateNookPermissionH\x00\x12\x15\n\x04wave\x18w \x01(\x0b\x32\x05.WaveH\x00\x12#\n\x0bsetPronouns\x18x \x01(\x0b\x32\x0c.SetPronounsH\x00\x12\x1d\n\x08setTitle\x18y \x01(\x0b\x32\t.SetTitleH\x00\x12#\n\x0bsetTimezone\x18z \x01(\x0b\x32\x0c.SetTimezoneH\x00\x12\x1d\n\x08setPhone\x18{ \x01(\x0b\x32\t.SetPhoneH\x00\x12)\n\x0esetDescription\x18| \x01(\x0b\x32\x0f.SetDescriptionH\x00\x12\x31\n\x12setProfileImageUrl\x18} \x01(\x0b\x32\x13.SetProfileImageUrlH\x00\x12\x33\n\x13setPersonalImageUrl\x18~ \x01(\x0b\x32\x14.SetPersonalImageUrlH\x00\x12\x1b\n\x07setAway\x18\x7f \x01(\x0b\x32\x08.SetAwayH\x00\x12\x1c\n\x07setCity\x18\x80\x01 \x01(\x0b\x32\x08.SetCityH\x00\x12\"\n\nsetCountry\x18\x81\x01 \x01(\x0b\x32\x0b.SetCountryH\x00\x12&\n\x0csetStartDate\x18\x82\x01 \x01(\x0b\x32\r.SetStartDateH\x00\x12*\n\x0estartRecording\x18\x83\x01 \x01(\x0b\x32\x0f.StartRecordingH\x00\x42\x08\n\x06\x61\x63tionB\x08\n\x06_txnId\"\x11\n\x0f\x43lientHeartbeat\"\x17\n\x15\x43lientBackupHeartbeat\"\xfe\x01\n\x13UpdateSubscriptions\x12>\n\rsubscriptions\x18\x01 \x03(\x0b\x32\'.UpdateSubscriptions.SubscriptionsEntry\x12<\n\x0cmapUpdateIds\x18\x02 \x03(\x0b\x32&.UpdateSubscriptions.MapUpdateIdsEntry\x1a\x34\n\x12SubscriptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x08:\x02\x38\x01\x1a\x33\n\x11MapUpdateIdsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\"r\n\x04Move\x12$\n\x03\x64ir\x18\x01 \x01(\x0e\x32\x17.MoveDirectionEnum.ENUM\x12\x0f\n\x07stopped\x18\x02 \x01(\x08\x12\x0f\n\x07inputId\x18\x03 \x01(\r\x12\x15\n\x08targetId\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\",\n\x0bRequestMute\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\r\n\x05video\x18\x02 \x01(\x08\"I\n\x0eSetAffiliation\x12\x13\n\x0b\x61\x66\x66iliation\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"?\n\tSetStatus\x12\x0e\n\x06status\x18\x01 \x01(\x08\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"K\n\x0fSetOutfitString\x12\x14\n\x0coutfitString\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\";\n\tSpotlight\x12\x17\n\x0fspotlightedUser\x18\x01 \x01(\t\x12\x15\n\risSpotlighted\x18\x02 \x01(\x08\"\x14\n\x04Ring\x12\x0c\n\x04user\x18\x01 \x01(\t\"9\n\x0fSetImagePointer\x12\x10\n\x08objectId\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\":\n\x10SetScreenPointer\x12\x10\n\x08screenId\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\x01\x12\t\n\x01y\x18\x03 \x01(\x01\"\x13\n\x03\x42\x61n\x12\x0c\n\x04user\x18\x01 \x01(\t\"\x14\n\x04Kick\x12\x0c\n\x04user\x18\x01 \x01(\t\"/\n\x05\x42lock\x12\x15\n\rblockedUserId\x18\x01 \x01(\t\x12\x0f\n\x07\x62locked\x18\x02 \x01(\x08\"H\n\rSetImpassable\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\x12\x12\n\nimpassable\x18\x04 \x01(\x08\"\x8e\x01\n\x04\x43hat\x12\x15\n\rchatRecipient\x18\x01 \x01(\t\x12\x10\n\x08\x63ontents\x18\x02 \x01(\t\x12\x16\n\x0elocalPlayerIds\x18\x03 \x03(\t\x12\r\n\x05mapId\x18\x04 \x01(\t\x12\x0f\n\x02id\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06nookId\x18\x06 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_idB\t\n\x07_nookId\"\x1e\n\x06Notify\x12\x14\n\x0cnotification\x18\x01 \x01(\t\"[\n\x08Interact\x12\r\n\x05objId\x18\x01 \x01(\t\x12\x12\n\x05mapId\x18\x03 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08\x64\x61taJson\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x08\n\x06_mapIdB\x0b\n\t_dataJson\",\n\x10\x41\x63tivelySpeaking\x12\x18\n\x10\x61\x63tivelySpeaking\x18\x01 \x01(\x08\"I\n\x0c\x45nterWhisper\x12\x13\n\x0brecipientId\x18\x01 \x01(\t\x12$\n\x03\x64ir\x18\x02 \x01(\x0e\x32\x17.MoveDirectionEnum.ENUM\"\x0e\n\x0cLeaveWhisper\":\n\x05Ghost\x12\r\n\x05ghost\x18\x01 \x01(\r\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"l\n\nSetEmoteV2\x12\x12\n\x05\x65mote\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x12\n\x05\x63ount\x18\x03 \x01(\rH\x02\x88\x01\x01\x42\x08\n\x06_emoteB\x0b\n\t_targetIdB\x08\n\x06_count\";\n\x07SetName\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"G\n\rSetTextStatus\x12\x12\n\ntextStatus\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"C\n\x0bSetPronouns\x12\x10\n\x08pronouns\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"=\n\x08SetTitle\x12\r\n\x05title\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\";\n\x07SetCity\x12\x0c\n\x04\x63ity\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"A\n\nSetCountry\x12\x0f\n\x07\x63ountry\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"E\n\x0cSetStartDate\x12\x11\n\tstartDate\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"C\n\x0bSetTimezone\x12\x10\n\x08timezone\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"=\n\x08SetPhone\x12\r\n\x05phone\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"I\n\x0eSetDescription\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"Q\n\x12SetProfileImageUrl\x12\x17\n\x0fprofileImageUrl\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"S\n\x13SetPersonalImageUrl\x12\x18\n\x10personalImageUrl\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"\x06\n\x04\x45xit\"\x80\x01\n\x05\x45nter\x12\"\n\x04info\x18\x01 \x01(\x0b\x32\x0f.PlayerInitInfoH\x00\x88\x01\x01\x12\x17\n\nspawnToken\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x15\n\x08targetId\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_infoB\r\n\x0b_spawnTokenB\x0b\n\t_targetId\"u\n\x0fPrecomputeEnter\x12(\n\renterLocation\x18\x01 \x01(\x0b\x32\x0c.MapLocationH\x00\x88\x01\x01\x12\x17\n\nspawnToken\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_enterLocationB\r\n\x0b_spawnToken\"I\n\x0eSetEmojiStatus\x12\x13\n\x0b\x65mojiStatus\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"\x94\x01\n\x08Teleport\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\t\n\x01x\x18\x02 \x01(\r\x12\t\n\x01y\x18\x03 \x01(\r\x12\x15\n\x08targetId\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x31\n\tdirection\x18\x05 \x01(\x0e\x32\x19.SpriteDirectionEnum.ENUMH\x01\x88\x01\x01\x42\x0b\n\t_targetIdB\x0c\n\n_direction\"M\n\x10SetWorkCondition\x12\x15\n\rworkCondition\x18\x01 \x01(\x08\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"\x1b\n\x05Spawn\x12\x12\n\nspawnToken\x18\x01 \x01(\t\"\t\n\x07Respawn\"N\n\x11RequestToJoinNook\x12\x0e\n\x06nookId\x18\x01 \x01(\t\x12\r\n\x05mapId\x18\x02 \x01(\t\x12\x11\n\x04name\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x07\n\x05_name\"I\n\x14UpdateNookPermission\x12\x10\n\x08playerId\x18\x01 \x01(\t\x12\x0e\n\x06nookId\x18\x02 \x01(\t\x12\x0f\n\x07granted\x18\x03 \x01(\x08\"B\n\x04Init\x12\x0f\n\x07spaceId\x18\x01 \x01(\t\x12\x0f\n\x05token\x18\x02 \x01(\tH\x00\x12\x10\n\x06\x61piKey\x18\x03 \x01(\tH\x00\x42\x06\n\x04\x61uth\":\n\x0cMapAddObject\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x1b\n\x06object\x18\x02 \x01(\x0b\x32\x0b.WireObject\"3\n\rShootConfetti\x12\x15\n\x08targetId\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"I\n\x0eSetEventStatus\x12\x13\n\x0b\x65ventStatus\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"O\n\x11SetInConversation\x12\x16\n\x0einConversation\x18\x01 \x01(\x08\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"I\n\x0eSetCurrentDesk\x12\x13\n\x0b\x63urrentDesk\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"I\n\x0eSetCurrentArea\x12\x13\n\x0b\x63urrentArea\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"C\n\x0bSetGoKartId\x12\x10\n\x08goKartId\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"e\n\x0cSetVehicleId\x12\x11\n\tvehicleId\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x61\x63tion\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0b\n\t_targetIdB\t\n\x07_action\"M\n\x10SetSpeedModifier\x12\x15\n\rspeedModifier\x18\x01 \x01(\x02\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"A\n\nSetIsAlone\x12\x0f\n\x07isAlone\x18\x01 \x01(\x08\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"\x1f\n\x0bSetIsMobile\x12\x10\n\x08isMobile\x18\x01 \x01(\x08\"L\n\tPlaySound\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\x0e\n\x06volume\x18\x02 \x01(\x02\x12\x15\n\x08targetId\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"<\n\tStopSound\x12\x0b\n\x03src\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"S\n\x13SetFocusModeEndTime\x12\x18\n\x10\x66ocusModeEndTime\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"G\n\rSetItemString\x12\x12\n\nitemString\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"y\n\x0bTriggerItem\x12\x1a\n\rclosestObject\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15\x63losestObjectTemplate\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x10\n\x0e_closestObjectB\x18\n\x16_closestObjectTemplate\"g\n\x0c\x43ustomAction\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07payload\x18\x02 \x01(\t\x12\x12\n\nrecipients\x18\x03 \x03(\t\x12\x16\n\tsendToAll\x18\x04 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_sendToAll\"K\n\x0fSetFollowTarget\x12\x14\n\x0c\x66ollowTarget\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"1\n\rRequestToLead\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x10\n\x08snapshot\x18\x02 \x01(\t\"p\n\x0b\x45nterPortal\x12\x11\n\ttargetUrl\x18\x01 \x01(\t\x12\x19\n\x0c\x62ypassPrompt\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x15\n\x08targetId\x18\x03 \x01(\tH\x01\x88\x01\x01\x42\x0f\n\r_bypassPromptB\x0b\n\t_targetId\"O\n\x11SetManualVideoSrc\x12\x16\n\x0emanualVideoSrc\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"C\n\x0bSetSubtitle\x12\x10\n\x08subtitle\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"4\n\x11MapCommitsChanges\x12\r\n\x05mapId\x18\x01 \x01(\t\x12\x10\n\x08updateId\x18\x02 \x01(\x04\"\xe2\x01\n\x14PlayerUpdatesSession\x12\x18\n\x0broomChecked\x18\x01 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0b\x63hatChecked\x18\x02 \x01(\x08H\x01\x88\x01\x01\x12\x16\n\tqaChecked\x18\x03 \x01(\x08H\x02\x88\x01\x01\x12$\n\x17\x61pproveQuestionsChecked\x18\x04 \x01(\x08H\x03\x88\x01\x01\x12\x0e\n\x06roomId\x18\x05 \x01(\tB\x0e\n\x0c_roomCheckedB\x0e\n\x0c_chatCheckedB\x0c\n\n_qaCheckedB\x1a\n\x18_approveQuestionsChecked\"\xaa\x02\n\x15SpeakerUpdatesSession\x12\x11\n\tsessionId\x18\x01 \x01(\t\x12!\n\x14\x63ustomizeRoomEnabled\x18\x02 \x01(\x08H\x00\x88\x01\x01\x12\x18\n\x0b\x63hatEnabled\x18\x03 \x01(\x08H\x01\x88\x01\x01\x12\x16\n\tqaEnabled\x18\x04 \x01(\x08H\x02\x88\x01\x01\x12$\n\x17\x61pproveQuestionsEnabled\x18\x05 \x01(\x08H\x03\x88\x01\x01\x12\x1c\n\x0fmassMuteEnabled\x18\x06 \x01(\x08H\x04\x88\x01\x01\x42\x17\n\x15_customizeRoomEnabledB\x0e\n\x0c_chatEnabledB\x0c\n\n_qaEnabledB\x1a\n\x18_approveQuestionsEnabledB\x12\n\x10_massMuteEnabled\"C\n\tChatReply\x12\x10\n\x08senderId\x18\x01 \x01(\t\x12\x12\n\nsenderName\x18\x02 \x01(\t\x12\x10\n\x08\x63ontents\x18\x03 \x01(\t\" \n\x12\x43hatMessageUpdated\x12\n\n\x02id\x18\x01 \x01(\t\"B\n\x0bSendCommand\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"\"\n\x0fRegisterCommand\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"Z\n\x05\x43raft\x12\"\n\x06inputs\x18\x01 \x03(\x0b\x32\x12.Craft.InputsEntry\x1a-\n\x0bInputsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"\x1c\n\x08HighFive\x12\x10\n\x08targetId\x18\x01 \x01(\t\"C\n\x10\x41\x64\x64InventoryItem\x12\x0e\n\x06itemId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65lta\x18\x02 \x01(\x04\x12\x10\n\x08targetId\x18\x03 \x01(\t\"X\n\x13RemoveInventoryItem\x12\x0e\n\x06itemId\x18\x01 \x01(\t\x12\r\n\x05\x64\x65lta\x18\x02 \x01(\x04\x12\x15\n\x08targetId\x18\x03 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"\x1d\n\rHipToBeSquare\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"9\n\x14TriggerInventoryItem\x12\x0e\n\x06itemId\x18\x01 \x01(\t\x12\x11\n\tabilityId\x18\x02 \x01(\t\"3\n\x15SetAllowScreenPointer\x12\x1a\n\x12\x61llowScreenPointer\x18\x01 \x01(\x08\"P\n\x0bSetDeskInfo\x12\x1d\n\x08\x64\x65skInfo\x18\x01 \x01(\x0b\x32\x0b.DeskInfoV2\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"%\n\x04Wave\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x0f\n\x07isReply\x18\x02 \x01(\x08\";\n\x07SetAway\x12\x0c\n\x04\x61way\x18\x01 \x01(\x08\x12\x15\n\x08targetId\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x0b\n\t_targetId\"@\n\x0eStartRecording\x12\x0e\n\x06nookId\x18\x01 \x01(\t\x12\x13\n\x06\x63\x61ncel\x18\x02 \x01(\x08H\x00\x88\x01\x01\x42\t\n\x07_cancelb\x06proto3')



_SPRITEDIRECTIONENUM = DESCRIPTOR.message_types_by_name['SpriteDirectionEnum']
_MOVEDIRECTIONENUM = DESCRIPTOR.message_types_by_name['MoveDirectionEnum']
_INTERACTIONENUM = DESCRIPTOR.message_types_by_name['InteractionEnum']
_PLAYERINITINFO = DESCRIPTOR.message_types_by_name['PlayerInitInfo']
_DBOUTFIT = DESCRIPTOR.message_types_by_name['DBOutfit']
_WIREOBJECTSPRITESHEETFRAMING = DESCRIPTOR.message_types_by_name['WireObjectSpritesheetFraming']
_WIREOBJECTSPRITEANIMCONFIG = DESCRIPTOR.message_types_by_name['WireObjectSpriteAnimConfig']
_WIREOBJECTSPRITESHEET = DESCRIPTOR.message_types_by_name['WireObjectSpritesheet']
_WIREOBJECTSPRITESHEET_ANIMATIONSENTRY = _WIREOBJECTSPRITESHEET.nested_types_by_name['AnimationsEntry']
_WIREOBJECT = DESCRIPTOR.message_types_by_name['WireObject']
_SPACEMEMBERINFO = DESCRIPTOR.message_types_by_name['SpaceMemberInfo']
_SPACEMEMBERINFO_ROLESENTRY = _SPACEMEMBERINFO.nested_types_by_name['RolesEntry']
_BACKEDUPDESKOBJECT = DESCRIPTOR.message_types_by_name['BackedUpDeskObject']
_DESKOBJECTS = DESCRIPTOR.message_types_by_name['DeskObjects']
_DESKOBJECTS_OBJECTSENTRY = _DESKOBJECTS.nested_types_by_name['ObjectsEntry']
_DESKINFO = DESCRIPTOR.message_types_by_name['DeskInfo']
_DESKINFOV2 = DESCRIPTOR.message_types_by_name['DeskInfoV2']
_SOUND = DESCRIPTOR.message_types_by_name['Sound']
_OBJECTTIME = DESCRIPTOR.message_types_by_name['ObjectTime']
_SPACE = DESCRIPTOR.message_types_by_name['Space']
_NOOKCOORDS = DESCRIPTOR.message_types_by_name['NookCoords']
_ALLOWEDUSERS = DESCRIPTOR.message_types_by_name['AllowedUsers']
_REQUESTUSER = DESCRIPTOR.message_types_by_name['RequestUser']
_REQUESTEDUSERS = DESCRIPTOR.message_types_by_name['RequestedUsers']
_REQUESTEDUSERS_USERSENTRY = _REQUESTEDUSERS.nested_types_by_name['UsersEntry']
_RECORDINGINFO = DESCRIPTOR.message_types_by_name['RecordingInfo']
_NOOKDIFF = DESCRIPTOR.message_types_by_name['NookDiff']
_WIREPOINT = DESCRIPTOR.message_types_by_name['WirePoint']
_SPAWNPOINT = DESCRIPTOR.message_types_by_name['SpawnPoint']
_PORTAL = DESCRIPTOR.message_types_by_name['Portal']
_ANNOUNCER = DESCRIPTOR.message_types_by_name['Announcer']
_ASSET = DESCRIPTOR.message_types_by_name['Asset']
_AREAPOSITION = DESCRIPTOR.message_types_by_name['AreaPosition']
_WIREAREA = DESCRIPTOR.message_types_by_name['WireArea']
_DBDESK = DESCRIPTOR.message_types_by_name['DBDesk']
_MAPSETDIMENSIONS = DESCRIPTOR.message_types_by_name['MapSetDimensions']
_MAPSETCOLLISIONS = DESCRIPTOR.message_types_by_name['MapSetCollisions']
_MAPSETCOLLISIONSBITS = DESCRIPTOR.message_types_by_name['MapSetCollisionsBits']
_MAPSETBACKGROUNDIMAGEPATH = DESCRIPTOR.message_types_by_name['MapSetBackgroundImagePath']
_MAPSETFOREGROUNDIMAGEPATH = DESCRIPTOR.message_types_by_name['MapSetForegroundImagePath']
_MAPSETSPRITES = DESCRIPTOR.message_types_by_name['MapSetSprites']
_MAPSETSPACES = DESCRIPTOR.message_types_by_name['MapSetSpaces']
_MAPSETNOOKS = DESCRIPTOR.message_types_by_name['MapSetNooks']
_MAPSETNOOKS_NOOKSENTRY = _MAPSETNOOKS.nested_types_by_name['NooksEntry']
_MAPSETSPAWN = DESCRIPTOR.message_types_by_name['MapSetSpawn']
_MAPSETSPAWNS = DESCRIPTOR.message_types_by_name['MapSetSpawns']
_MAPSETPORTALS = DESCRIPTOR.message_types_by_name['MapSetPortals']
_MAPSETANNOUNCER = DESCRIPTOR.message_types_by_name['MapSetAnnouncer']
_MAPSETASSETS = DESCRIPTOR.message_types_by_name['MapSetAssets']
_MAPSETOBJECTS = DESCRIPTOR.message_types_by_name['MapSetObjects']
_MAPSETOBJECTS_OBJECTSENTRY = _MAPSETOBJECTS.nested_types_by_name['ObjectsEntry']
_MAPSETNAME = DESCRIPTOR.message_types_by_name['MapSetName']
_MAPSETMUTEONENTRY = DESCRIPTOR.message_types_by_name['MapSetMuteOnEntry']
_MAPSETUSEDRAWNBG = DESCRIPTOR.message_types_by_name['MapSetUseDrawnBG']
_MAPSETWALLS = DESCRIPTOR.message_types_by_name['MapSetWalls']
_MAPSETWALLS_WALLSENTRY = _MAPSETWALLS.nested_types_by_name['WallsEntry']
_MAPSETFLOORS = DESCRIPTOR.message_types_by_name['MapSetFloors']
_MAPSETFLOORS_FLOORSENTRY = _MAPSETFLOORS.nested_types_by_name['FloorsEntry']
_MAPSETAREAS = DESCRIPTOR.message_types_by_name['MapSetAreas']
_MAPSETAREAS_AREASENTRY = _MAPSETAREAS.nested_types_by_name['AreasEntry']
_MAPDELETEOBJECT = DESCRIPTOR.message_types_by_name['MapDeleteObject']
_MAPDELETEOBJECTBYID = DESCRIPTOR.message_types_by_name['MapDeleteObjectById']
_MAPSETMINIMAPIMAGEPATH = DESCRIPTOR.message_types_by_name['MapSetMiniMapImagePath']
_MAPSETENABLEDCHATS = DESCRIPTOR.message_types_by_name['MapSetEnabledChats']
_MAPSETDESCRIPTION = DESCRIPTOR.message_types_by_name['MapSetDescription']
_MAPSETDECORATION = DESCRIPTOR.message_types_by_name['MapSetDecoration']
_MAPSETTUTORIALTASKS = DESCRIPTOR.message_types_by_name['MapSetTutorialTasks']
_WIRETUTORIALTASKS = DESCRIPTOR.message_types_by_name['WireTutorialTasks']
_TUTORIALTASKMAPAREA = DESCRIPTOR.message_types_by_name['TutorialTaskMapArea']
_MAPSETSCRIPT = DESCRIPTOR.message_types_by_name['MapSetScript']
_INVENTORY = DESCRIPTOR.message_types_by_name['Inventory']
_INVENTORY_ITEMSENTRY = _INVENTORY.nested_types_by_name['ItemsEntry']
_INVENTORY_ORDERENTRY = _INVENTORY.nested_types_by_name['OrderEntry']
_INVENTORYITEM = DESCRIPTOR.message_types_by_name['InventoryItem']
_SPACEITEM = DESCRIPTOR.message_types_by_name['SpaceItem']
_SPACEITEM_METAENTRY = _SPACEITEM.nested_types_by_name['MetaEntry']
_SPACEITEM_ABILITIESENTRY = _SPACEITEM.nested_types_by_name['AbilitiesEntry']
_ITEMABILITY = DESCRIPTOR.message_types_by_name['ItemAbility']
_MAPLOCATION = DESCRIPTOR.message_types_by_name['MapLocation']
_SERVERCLIENTBATCH = DESCRIPTOR.message_types_by_name['ServerClientBatch']
_SERVERCLIENTEVENT = DESCRIPTOR.message_types_by_name['ServerClientEvent']
_SERVERHEARTBEAT = DESCRIPTOR.message_types_by_name['ServerHeartbeat']
_INFO = DESCRIPTOR.message_types_by_name['Info']
_WARN = DESCRIPTOR.message_types_by_name['Warn']
_ERROREVENT = DESCRIPTOR.message_types_by_name['ErrorEvent']
_READY = DESCRIPTOR.message_types_by_name['Ready']
_TRANSACTIONSTATUS = DESCRIPTOR.message_types_by_name['TransactionStatus']
_PLAYERJOINS = DESCRIPTOR.message_types_by_name['PlayerJoins']
_GOTREQUESTMUTE = DESCRIPTOR.message_types_by_name['GotRequestMute']
_PLAYERMOVES = DESCRIPTOR.message_types_by_name['PlayerMoves']
_PLAYERSETSSTATUS = DESCRIPTOR.message_types_by_name['PlayerSetsStatus']
_PLAYERSPOTLIGHTS = DESCRIPTOR.message_types_by_name['PlayerSpotlights']
_PLAYERRINGS = DESCRIPTOR.message_types_by_name['PlayerRings']
_PLAYERSETSIMAGEPOINTER = DESCRIPTOR.message_types_by_name['PlayerSetsImagePointer']
_SETSCREENPOINTERSERVER = DESCRIPTOR.message_types_by_name['SetScreenPointerServer']
_PLAYERCHATS = DESCRIPTOR.message_types_by_name['PlayerChats']
_PLAYERWAVES = DESCRIPTOR.message_types_by_name['PlayerWaves']
_TIMESTAMP = DESCRIPTOR.message_types_by_name['Timestamp']
_PLAYERINTERACTS = DESCRIPTOR.message_types_by_name['PlayerInteracts']
_PLAYERGHOSTS = DESCRIPTOR.message_types_by_name['PlayerGhosts']
_PLAYERENTERSWHISPER = DESCRIPTOR.message_types_by_name['PlayerEntersWhisper']
_PLAYERENTERSWHISPERV2 = DESCRIPTOR.message_types_by_name['PlayerEntersWhisperV2']
_PLAYERLEAVESWHISPER = DESCRIPTOR.message_types_by_name['PlayerLeavesWhisper']
_PLAYERACTIVELYSPEAKS = DESCRIPTOR.message_types_by_name['PlayerActivelySpeaks']
_PLAYERSETSEMOTEV2 = DESCRIPTOR.message_types_by_name['PlayerSetsEmoteV2']
_PLAYERSETSWORKCONDITION = DESCRIPTOR.message_types_by_name['PlayerSetsWorkCondition']
_PLAYERSETSLASTACTIVE = DESCRIPTOR.message_types_by_name['PlayerSetsLastActive']
_PLAYERSETSNAME = DESCRIPTOR.message_types_by_name['PlayerSetsName']
_PLAYERSETSTEXTSTATUS = DESCRIPTOR.message_types_by_name['PlayerSetsTextStatus']
_PLAYERSETSPRONOUNS = DESCRIPTOR.message_types_by_name['PlayerSetsPronouns']
_PLAYERSETSTITLE = DESCRIPTOR.message_types_by_name['PlayerSetsTitle']
_PLAYERSETSCITY = DESCRIPTOR.message_types_by_name['PlayerSetsCity']
_PLAYERSETSCOUNTRY = DESCRIPTOR.message_types_by_name['PlayerSetsCountry']
_PLAYERSETSSTARTDATE = DESCRIPTOR.message_types_by_name['PlayerSetsStartDate']
_PLAYERSETSTIMEZONE = DESCRIPTOR.message_types_by_name['PlayerSetsTimezone']
_PLAYERSETSPHONE = DESCRIPTOR.message_types_by_name['PlayerSetsPhone']
_PLAYERSETSDESCRIPTION = DESCRIPTOR.message_types_by_name['PlayerSetsDescription']
_PLAYERSETSPROFILEIMAGEURL = DESCRIPTOR.message_types_by_name['PlayerSetsProfileImageUrl']
_PLAYERSETSPERSONALIMAGEURL = DESCRIPTOR.message_types_by_name['PlayerSetsPersonalImageUrl']
_PLAYERSETSISMOBILE = DESCRIPTOR.message_types_by_name['PlayerSetsIsMobile']
_PLAYERSETSEMOJISTATUS = DESCRIPTOR.message_types_by_name['PlayerSetsEmojiStatus']
_PLAYERSETSAFFILIATION = DESCRIPTOR.message_types_by_name['PlayerSetsAffiliation']
_PLAYEREXITS = DESCRIPTOR.message_types_by_name['PlayerExits']
_PLAYERSETSOUTFITSTRING = DESCRIPTOR.message_types_by_name['PlayerSetsOutfitString']
_PLAYERSETSISSIGNEDIN = DESCRIPTOR.message_types_by_name['PlayerSetsIsSignedIn']
_RESPAWNCOMPLETE = DESCRIPTOR.message_types_by_name['RespawnComplete']
_SPACEOVERWRITES = DESCRIPTOR.message_types_by_name['SpaceOverwrites']
_DYNAMICGATE = DESCRIPTOR.message_types_by_name['DynamicGate']
_DYNAMICGATES = DESCRIPTOR.message_types_by_name['DynamicGates']
_SPACESETSSPACEMEMBERS = DESCRIPTOR.message_types_by_name['SpaceSetsSpaceMembers']
_SPACESETSSPACEMEMBERS_MEMBERSENTRY = _SPACESETSSPACEMEMBERS.nested_types_by_name['MembersEntry']
_SPACEISCLOSED = DESCRIPTOR.message_types_by_name['SpaceIsClosed']
_PLAYERENTERSPORTAL = DESCRIPTOR.message_types_by_name['PlayerEntersPortal']
_COOKIEFOUND = DESCRIPTOR.message_types_by_name['CookieFound']
_SPACESETSIDMAPPING = DESCRIPTOR.message_types_by_name['SpaceSetsIdMapping']
_PLAYERSHOOTSCONFETTI = DESCRIPTOR.message_types_by_name['PlayerShootsConfetti']
_PLAYERSETSEVENTSTATUS = DESCRIPTOR.message_types_by_name['PlayerSetsEventStatus']
_PLAYERSETSINCONVERSATION = DESCRIPTOR.message_types_by_name['PlayerSetsInConversation']
_PLAYERSETSCURRENTDESK = DESCRIPTOR.message_types_by_name['PlayerSetsCurrentDesk']
_PLAYERSETSCURRENTAREA = DESCRIPTOR.message_types_by_name['PlayerSetsCurrentArea']
_PLAYERSETSGOKARTID = DESCRIPTOR.message_types_by_name['PlayerSetsGoKartId']
_PLAYERSETSVEHICLEID = DESCRIPTOR.message_types_by_name['PlayerSetsVehicleId']
_PLAYERSETSSPEEDMODIFIER = DESCRIPTOR.message_types_by_name['PlayerSetsSpeedModifier']
_PLAYERSETSISALONE = DESCRIPTOR.message_types_by_name['PlayerSetsIsAlone']
_SPACEPLAYSSOUND = DESCRIPTOR.message_types_by_name['SpacePlaysSound']
_SPACESTOPSSOUND = DESCRIPTOR.message_types_by_name['SpaceStopsSound']
_PLAYERSETSFOCUSMODEENDTIME = DESCRIPTOR.message_types_by_name['PlayerSetsFocusModeEndTime']
_PLAYERBLOCKS = DESCRIPTOR.message_types_by_name['PlayerBlocks']
_CUSTOMEVENT = DESCRIPTOR.message_types_by_name['CustomEvent']
_PLAYERUPDATESFOCUSMODESTATUS = DESCRIPTOR.message_types_by_name['PlayerUpdatesFocusModeStatus']
_PLAYERSETSITEMSTRING = DESCRIPTOR.message_types_by_name['PlayerSetsItemString']
_PLAYERTRIGGERSITEM = DESCRIPTOR.message_types_by_name['PlayerTriggersItem']
_PLAYERNOTIFIES = DESCRIPTOR.message_types_by_name['PlayerNotifies']
_PLAYERSETSFOLLOWTARGET = DESCRIPTOR.message_types_by_name['PlayerSetsFollowTarget']
_PLAYERREQUESTSTOLEAD = DESCRIPTOR.message_types_by_name['PlayerRequestsToLead']
_PLAYERSETSMANUALVIDEOSRC = DESCRIPTOR.message_types_by_name['PlayerSetsManualVideoSrc']
_PLAYERSETSISNPC = DESCRIPTOR.message_types_by_name['PlayerSetsIsNpc']
_PLAYERSETSSUBTITLE = DESCRIPTOR.message_types_by_name['PlayerSetsSubtitle']
_PLAYERCRAFTS = DESCRIPTOR.message_types_by_name['PlayerCrafts']
_PLAYERCRAFTS_INPUTSENTRY = _PLAYERCRAFTS.nested_types_by_name['InputsEntry']
_MAPMOVEOBJECT = DESCRIPTOR.message_types_by_name['MapMoveObject']
_PLAYEREDITSCHATMESSAGE = DESCRIPTOR.message_types_by_name['PlayerEditsChatMessage']
_FXSHAKEOBJECT = DESCRIPTOR.message_types_by_name['FXShakeObject']
_FXSHAKECAMERA = DESCRIPTOR.message_types_by_name['FXShakeCamera']
_PLAYERHIGHFIVES = DESCRIPTOR.message_types_by_name['PlayerHighFives']
_PLAYERSENDSCOMMAND = DESCRIPTOR.message_types_by_name['PlayerSendsCommand']
_SPACEREGISTERSCOMMAND = DESCRIPTOR.message_types_by_name['SpaceRegistersCommand']
_PLAYERUPDATESINVENTORY = DESCRIPTOR.message_types_by_name['PlayerUpdatesInventory']
_PLAYERUPDATESINVENTORY_ITEMSENTRY = _PLAYERUPDATESINVENTORY.nested_types_by_name['ItemsEntry']
_PLAYERUPDATESINVENTORY_ORDERENTRY = _PLAYERUPDATESINVENTORY.nested_types_by_name['OrderEntry']
_SPACEUPDATESITEMS = DESCRIPTOR.message_types_by_name['SpaceUpdatesItems']
_SPACEUPDATESITEMS_ITEMSENTRY = _SPACEUPDATESITEMS.nested_types_by_name['ItemsEntry']
_PLAYERTRIGGERSINVENTORYITEM = DESCRIPTOR.message_types_by_name['PlayerTriggersInventoryItem']
_PLAYERSETSALLOWSCREENPOINTER = DESCRIPTOR.message_types_by_name['PlayerSetsAllowScreenPointer']
_PRECOMPUTEDENTERLOCATION = DESCRIPTOR.message_types_by_name['PrecomputedEnterLocation']
_PLAYERSETSDESKINFO = DESCRIPTOR.message_types_by_name['PlayerSetsDeskInfo']
_SPACESETSCAPACITY = DESCRIPTOR.message_types_by_name['SpaceSetsCapacity']
_SPACEOVERCAPACITYDENIESUSER = DESCRIPTOR.message_types_by_name['SpaceOverCapacityDeniesUser']
_PLAYERSETSAWAY = DESCRIPTOR.message_types_by_name['PlayerSetsAway']
_PLAYERSETSISRECORDINGCLIENT = DESCRIPTOR.message_types_by_name['PlayerSetsIsRecordingClient']
_PLAYERSTARTSRECORDING = DESCRIPTOR.message_types_by_name['PlayerStartsRecording']
_CLIENTSERVERBATCH = DESCRIPTOR.message_types_by_name['ClientServerBatch']
_CLIENTSERVERACTION = DESCRIPTOR.message_types_by_name['ClientServerAction']
_CLIENTHEARTBEAT = DESCRIPTOR.message_types_by_name['ClientHeartbeat']
_CLIENTBACKUPHEARTBEAT = DESCRIPTOR.message_types_by_name['ClientBackupHeartbeat']
_UPDATESUBSCRIPTIONS = DESCRIPTOR.message_types_by_name['UpdateSubscriptions']
_UPDATESUBSCRIPTIONS_SUBSCRIPTIONSENTRY = _UPDATESUBSCRIPTIONS.nested_types_by_name['SubscriptionsEntry']
_UPDATESUBSCRIPTIONS_MAPUPDATEIDSENTRY = _UPDATESUBSCRIPTIONS.nested_types_by_name['MapUpdateIdsEntry']
_MOVE = DESCRIPTOR.message_types_by_name['Move']
_REQUESTMUTE = DESCRIPTOR.message_types_by_name['RequestMute']
_SETAFFILIATION = DESCRIPTOR.message_types_by_name['SetAffiliation']
_SETSTATUS = DESCRIPTOR.message_types_by_name['SetStatus']
_SETOUTFITSTRING = DESCRIPTOR.message_types_by_name['SetOutfitString']
_SPOTLIGHT = DESCRIPTOR.message_types_by_name['Spotlight']
_RING = DESCRIPTOR.message_types_by_name['Ring']
_SETIMAGEPOINTER = DESCRIPTOR.message_types_by_name['SetImagePointer']
_SETSCREENPOINTER = DESCRIPTOR.message_types_by_name['SetScreenPointer']
_BAN = DESCRIPTOR.message_types_by_name['Ban']
_KICK = DESCRIPTOR.message_types_by_name['Kick']
_BLOCK = DESCRIPTOR.message_types_by_name['Block']
_SETIMPASSABLE = DESCRIPTOR.message_types_by_name['SetImpassable']
_CHAT = DESCRIPTOR.message_types_by_name['Chat']
_NOTIFY = DESCRIPTOR.message_types_by_name['Notify']
_INTERACT = DESCRIPTOR.message_types_by_name['Interact']
_ACTIVELYSPEAKING = DESCRIPTOR.message_types_by_name['ActivelySpeaking']
_ENTERWHISPER = DESCRIPTOR.message_types_by_name['EnterWhisper']
_LEAVEWHISPER = DESCRIPTOR.message_types_by_name['LeaveWhisper']
_GHOST = DESCRIPTOR.message_types_by_name['Ghost']
_SETEMOTEV2 = DESCRIPTOR.message_types_by_name['SetEmoteV2']
_SETNAME = DESCRIPTOR.message_types_by_name['SetName']
_SETTEXTSTATUS = DESCRIPTOR.message_types_by_name['SetTextStatus']
_SETPRONOUNS = DESCRIPTOR.message_types_by_name['SetPronouns']
_SETTITLE = DESCRIPTOR.message_types_by_name['SetTitle']
_SETCITY = DESCRIPTOR.message_types_by_name['SetCity']
_SETCOUNTRY = DESCRIPTOR.message_types_by_name['SetCountry']
_SETSTARTDATE = DESCRIPTOR.message_types_by_name['SetStartDate']
_SETTIMEZONE = DESCRIPTOR.message_types_by_name['SetTimezone']
_SETPHONE = DESCRIPTOR.message_types_by_name['SetPhone']
_SETDESCRIPTION = DESCRIPTOR.message_types_by_name['SetDescription']
_SETPROFILEIMAGEURL = DESCRIPTOR.message_types_by_name['SetProfileImageUrl']
_SETPERSONALIMAGEURL = DESCRIPTOR.message_types_by_name['SetPersonalImageUrl']
_EXIT = DESCRIPTOR.message_types_by_name['Exit']
_ENTER = DESCRIPTOR.message_types_by_name['Enter']
_PRECOMPUTEENTER = DESCRIPTOR.message_types_by_name['PrecomputeEnter']
_SETEMOJISTATUS = DESCRIPTOR.message_types_by_name['SetEmojiStatus']
_TELEPORT = DESCRIPTOR.message_types_by_name['Teleport']
_SETWORKCONDITION = DESCRIPTOR.message_types_by_name['SetWorkCondition']
_SPAWN = DESCRIPTOR.message_types_by_name['Spawn']
_RESPAWN = DESCRIPTOR.message_types_by_name['Respawn']
_REQUESTTOJOINNOOK = DESCRIPTOR.message_types_by_name['RequestToJoinNook']
_UPDATENOOKPERMISSION = DESCRIPTOR.message_types_by_name['UpdateNookPermission']
_INIT = DESCRIPTOR.message_types_by_name['Init']
_MAPADDOBJECT = DESCRIPTOR.message_types_by_name['MapAddObject']
_SHOOTCONFETTI = DESCRIPTOR.message_types_by_name['ShootConfetti']
_SETEVENTSTATUS = DESCRIPTOR.message_types_by_name['SetEventStatus']
_SETINCONVERSATION = DESCRIPTOR.message_types_by_name['SetInConversation']
_SETCURRENTDESK = DESCRIPTOR.message_types_by_name['SetCurrentDesk']
_SETCURRENTAREA = DESCRIPTOR.message_types_by_name['SetCurrentArea']
_SETGOKARTID = DESCRIPTOR.message_types_by_name['SetGoKartId']
_SETVEHICLEID = DESCRIPTOR.message_types_by_name['SetVehicleId']
_SETSPEEDMODIFIER = DESCRIPTOR.message_types_by_name['SetSpeedModifier']
_SETISALONE = DESCRIPTOR.message_types_by_name['SetIsAlone']
_SETISMOBILE = DESCRIPTOR.message_types_by_name['SetIsMobile']
_PLAYSOUND = DESCRIPTOR.message_types_by_name['PlaySound']
_STOPSOUND = DESCRIPTOR.message_types_by_name['StopSound']
_SETFOCUSMODEENDTIME = DESCRIPTOR.message_types_by_name['SetFocusModeEndTime']
_SETITEMSTRING = DESCRIPTOR.message_types_by_name['SetItemString']
_TRIGGERITEM = DESCRIPTOR.message_types_by_name['TriggerItem']
_CUSTOMACTION = DESCRIPTOR.message_types_by_name['CustomAction']
_SETFOLLOWTARGET = DESCRIPTOR.message_types_by_name['SetFollowTarget']
_REQUESTTOLEAD = DESCRIPTOR.message_types_by_name['RequestToLead']
_ENTERPORTAL = DESCRIPTOR.message_types_by_name['EnterPortal']
_SETMANUALVIDEOSRC = DESCRIPTOR.message_types_by_name['SetManualVideoSrc']
_SETSUBTITLE = DESCRIPTOR.message_types_by_name['SetSubtitle']
_MAPCOMMITSCHANGES = DESCRIPTOR.message_types_by_name['MapCommitsChanges']
_PLAYERUPDATESSESSION = DESCRIPTOR.message_types_by_name['PlayerUpdatesSession']
_SPEAKERUPDATESSESSION = DESCRIPTOR.message_types_by_name['SpeakerUpdatesSession']
_CHATREPLY = DESCRIPTOR.message_types_by_name['ChatReply']
_CHATMESSAGEUPDATED = DESCRIPTOR.message_types_by_name['ChatMessageUpdated']
_SENDCOMMAND = DESCRIPTOR.message_types_by_name['SendCommand']
_REGISTERCOMMAND = DESCRIPTOR.message_types_by_name['RegisterCommand']
_CRAFT = DESCRIPTOR.message_types_by_name['Craft']
_CRAFT_INPUTSENTRY = _CRAFT.nested_types_by_name['InputsEntry']
_HIGHFIVE = DESCRIPTOR.message_types_by_name['HighFive']
_ADDINVENTORYITEM = DESCRIPTOR.message_types_by_name['AddInventoryItem']
_REMOVEINVENTORYITEM = DESCRIPTOR.message_types_by_name['RemoveInventoryItem']
_HIPTOBESQUARE = DESCRIPTOR.message_types_by_name['HipToBeSquare']
_TRIGGERINVENTORYITEM = DESCRIPTOR.message_types_by_name['TriggerInventoryItem']
_SETALLOWSCREENPOINTER = DESCRIPTOR.message_types_by_name['SetAllowScreenPointer']
_SETDESKINFO = DESCRIPTOR.message_types_by_name['SetDeskInfo']
_WAVE = DESCRIPTOR.message_types_by_name['Wave']
_SETAWAY = DESCRIPTOR.message_types_by_name['SetAway']
_STARTRECORDING = DESCRIPTOR.message_types_by_name['StartRecording']
_SPRITEDIRECTIONENUM_ENUM = _SPRITEDIRECTIONENUM.enum_types_by_name['ENUM']
_MOVEDIRECTIONENUM_ENUM = _MOVEDIRECTIONENUM.enum_types_by_name['ENUM']
_INTERACTIONENUM_ENUM = _INTERACTIONENUM.enum_types_by_name['ENUM']
SpriteDirectionEnum = _reflection.GeneratedProtocolMessageType('SpriteDirectionEnum', (_message.Message,), {
  'DESCRIPTOR' : _SPRITEDIRECTIONENUM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpriteDirectionEnum)
  })
_sym_db.RegisterMessage(SpriteDirectionEnum)

MoveDirectionEnum = _reflection.GeneratedProtocolMessageType('MoveDirectionEnum', (_message.Message,), {
  'DESCRIPTOR' : _MOVEDIRECTIONENUM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MoveDirectionEnum)
  })
_sym_db.RegisterMessage(MoveDirectionEnum)

InteractionEnum = _reflection.GeneratedProtocolMessageType('InteractionEnum', (_message.Message,), {
  'DESCRIPTOR' : _INTERACTIONENUM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:InteractionEnum)
  })
_sym_db.RegisterMessage(InteractionEnum)

PlayerInitInfo = _reflection.GeneratedProtocolMessageType('PlayerInitInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERINITINFO,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerInitInfo)
  })
_sym_db.RegisterMessage(PlayerInitInfo)

DBOutfit = _reflection.GeneratedProtocolMessageType('DBOutfit', (_message.Message,), {
  'DESCRIPTOR' : _DBOUTFIT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:DBOutfit)
  })
_sym_db.RegisterMessage(DBOutfit)

WireObjectSpritesheetFraming = _reflection.GeneratedProtocolMessageType('WireObjectSpritesheetFraming', (_message.Message,), {
  'DESCRIPTOR' : _WIREOBJECTSPRITESHEETFRAMING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:WireObjectSpritesheetFraming)
  })
_sym_db.RegisterMessage(WireObjectSpritesheetFraming)

WireObjectSpriteAnimConfig = _reflection.GeneratedProtocolMessageType('WireObjectSpriteAnimConfig', (_message.Message,), {
  'DESCRIPTOR' : _WIREOBJECTSPRITEANIMCONFIG,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:WireObjectSpriteAnimConfig)
  })
_sym_db.RegisterMessage(WireObjectSpriteAnimConfig)

WireObjectSpritesheet = _reflection.GeneratedProtocolMessageType('WireObjectSpritesheet', (_message.Message,), {

  'AnimationsEntry' : _reflection.GeneratedProtocolMessageType('AnimationsEntry', (_message.Message,), {
    'DESCRIPTOR' : _WIREOBJECTSPRITESHEET_ANIMATIONSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:WireObjectSpritesheet.AnimationsEntry)
    })
  ,
  'DESCRIPTOR' : _WIREOBJECTSPRITESHEET,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:WireObjectSpritesheet)
  })
_sym_db.RegisterMessage(WireObjectSpritesheet)
_sym_db.RegisterMessage(WireObjectSpritesheet.AnimationsEntry)

WireObject = _reflection.GeneratedProtocolMessageType('WireObject', (_message.Message,), {
  'DESCRIPTOR' : _WIREOBJECT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:WireObject)
  })
_sym_db.RegisterMessage(WireObject)

SpaceMemberInfo = _reflection.GeneratedProtocolMessageType('SpaceMemberInfo', (_message.Message,), {

  'RolesEntry' : _reflection.GeneratedProtocolMessageType('RolesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPACEMEMBERINFO_ROLESENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:SpaceMemberInfo.RolesEntry)
    })
  ,
  'DESCRIPTOR' : _SPACEMEMBERINFO,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceMemberInfo)
  })
_sym_db.RegisterMessage(SpaceMemberInfo)
_sym_db.RegisterMessage(SpaceMemberInfo.RolesEntry)

BackedUpDeskObject = _reflection.GeneratedProtocolMessageType('BackedUpDeskObject', (_message.Message,), {
  'DESCRIPTOR' : _BACKEDUPDESKOBJECT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:BackedUpDeskObject)
  })
_sym_db.RegisterMessage(BackedUpDeskObject)

DeskObjects = _reflection.GeneratedProtocolMessageType('DeskObjects', (_message.Message,), {

  'ObjectsEntry' : _reflection.GeneratedProtocolMessageType('ObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DESKOBJECTS_OBJECTSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:DeskObjects.ObjectsEntry)
    })
  ,
  'DESCRIPTOR' : _DESKOBJECTS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:DeskObjects)
  })
_sym_db.RegisterMessage(DeskObjects)
_sym_db.RegisterMessage(DeskObjects.ObjectsEntry)

DeskInfo = _reflection.GeneratedProtocolMessageType('DeskInfo', (_message.Message,), {
  'DESCRIPTOR' : _DESKINFO,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:DeskInfo)
  })
_sym_db.RegisterMessage(DeskInfo)

DeskInfoV2 = _reflection.GeneratedProtocolMessageType('DeskInfoV2', (_message.Message,), {
  'DESCRIPTOR' : _DESKINFOV2,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:DeskInfoV2)
  })
_sym_db.RegisterMessage(DeskInfoV2)

Sound = _reflection.GeneratedProtocolMessageType('Sound', (_message.Message,), {
  'DESCRIPTOR' : _SOUND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Sound)
  })
_sym_db.RegisterMessage(Sound)

ObjectTime = _reflection.GeneratedProtocolMessageType('ObjectTime', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTTIME,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ObjectTime)
  })
_sym_db.RegisterMessage(ObjectTime)

Space = _reflection.GeneratedProtocolMessageType('Space', (_message.Message,), {
  'DESCRIPTOR' : _SPACE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Space)
  })
_sym_db.RegisterMessage(Space)

NookCoords = _reflection.GeneratedProtocolMessageType('NookCoords', (_message.Message,), {
  'DESCRIPTOR' : _NOOKCOORDS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:NookCoords)
  })
_sym_db.RegisterMessage(NookCoords)

AllowedUsers = _reflection.GeneratedProtocolMessageType('AllowedUsers', (_message.Message,), {
  'DESCRIPTOR' : _ALLOWEDUSERS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:AllowedUsers)
  })
_sym_db.RegisterMessage(AllowedUsers)

RequestUser = _reflection.GeneratedProtocolMessageType('RequestUser', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTUSER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RequestUser)
  })
_sym_db.RegisterMessage(RequestUser)

RequestedUsers = _reflection.GeneratedProtocolMessageType('RequestedUsers', (_message.Message,), {

  'UsersEntry' : _reflection.GeneratedProtocolMessageType('UsersEntry', (_message.Message,), {
    'DESCRIPTOR' : _REQUESTEDUSERS_USERSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:RequestedUsers.UsersEntry)
    })
  ,
  'DESCRIPTOR' : _REQUESTEDUSERS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RequestedUsers)
  })
_sym_db.RegisterMessage(RequestedUsers)
_sym_db.RegisterMessage(RequestedUsers.UsersEntry)

RecordingInfo = _reflection.GeneratedProtocolMessageType('RecordingInfo', (_message.Message,), {
  'DESCRIPTOR' : _RECORDINGINFO,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RecordingInfo)
  })
_sym_db.RegisterMessage(RecordingInfo)

NookDiff = _reflection.GeneratedProtocolMessageType('NookDiff', (_message.Message,), {
  'DESCRIPTOR' : _NOOKDIFF,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:NookDiff)
  })
_sym_db.RegisterMessage(NookDiff)

WirePoint = _reflection.GeneratedProtocolMessageType('WirePoint', (_message.Message,), {
  'DESCRIPTOR' : _WIREPOINT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:WirePoint)
  })
_sym_db.RegisterMessage(WirePoint)

SpawnPoint = _reflection.GeneratedProtocolMessageType('SpawnPoint', (_message.Message,), {
  'DESCRIPTOR' : _SPAWNPOINT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpawnPoint)
  })
_sym_db.RegisterMessage(SpawnPoint)

Portal = _reflection.GeneratedProtocolMessageType('Portal', (_message.Message,), {
  'DESCRIPTOR' : _PORTAL,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Portal)
  })
_sym_db.RegisterMessage(Portal)

Announcer = _reflection.GeneratedProtocolMessageType('Announcer', (_message.Message,), {
  'DESCRIPTOR' : _ANNOUNCER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Announcer)
  })
_sym_db.RegisterMessage(Announcer)

Asset = _reflection.GeneratedProtocolMessageType('Asset', (_message.Message,), {
  'DESCRIPTOR' : _ASSET,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Asset)
  })
_sym_db.RegisterMessage(Asset)

AreaPosition = _reflection.GeneratedProtocolMessageType('AreaPosition', (_message.Message,), {
  'DESCRIPTOR' : _AREAPOSITION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:AreaPosition)
  })
_sym_db.RegisterMessage(AreaPosition)

WireArea = _reflection.GeneratedProtocolMessageType('WireArea', (_message.Message,), {
  'DESCRIPTOR' : _WIREAREA,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:WireArea)
  })
_sym_db.RegisterMessage(WireArea)

DBDesk = _reflection.GeneratedProtocolMessageType('DBDesk', (_message.Message,), {
  'DESCRIPTOR' : _DBDESK,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:DBDesk)
  })
_sym_db.RegisterMessage(DBDesk)

MapSetDimensions = _reflection.GeneratedProtocolMessageType('MapSetDimensions', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETDIMENSIONS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetDimensions)
  })
_sym_db.RegisterMessage(MapSetDimensions)

MapSetCollisions = _reflection.GeneratedProtocolMessageType('MapSetCollisions', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETCOLLISIONS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetCollisions)
  })
_sym_db.RegisterMessage(MapSetCollisions)

MapSetCollisionsBits = _reflection.GeneratedProtocolMessageType('MapSetCollisionsBits', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETCOLLISIONSBITS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetCollisionsBits)
  })
_sym_db.RegisterMessage(MapSetCollisionsBits)

MapSetBackgroundImagePath = _reflection.GeneratedProtocolMessageType('MapSetBackgroundImagePath', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETBACKGROUNDIMAGEPATH,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetBackgroundImagePath)
  })
_sym_db.RegisterMessage(MapSetBackgroundImagePath)

MapSetForegroundImagePath = _reflection.GeneratedProtocolMessageType('MapSetForegroundImagePath', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETFOREGROUNDIMAGEPATH,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetForegroundImagePath)
  })
_sym_db.RegisterMessage(MapSetForegroundImagePath)

MapSetSprites = _reflection.GeneratedProtocolMessageType('MapSetSprites', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETSPRITES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetSprites)
  })
_sym_db.RegisterMessage(MapSetSprites)

MapSetSpaces = _reflection.GeneratedProtocolMessageType('MapSetSpaces', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETSPACES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetSpaces)
  })
_sym_db.RegisterMessage(MapSetSpaces)

MapSetNooks = _reflection.GeneratedProtocolMessageType('MapSetNooks', (_message.Message,), {

  'NooksEntry' : _reflection.GeneratedProtocolMessageType('NooksEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPSETNOOKS_NOOKSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:MapSetNooks.NooksEntry)
    })
  ,
  'DESCRIPTOR' : _MAPSETNOOKS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetNooks)
  })
_sym_db.RegisterMessage(MapSetNooks)
_sym_db.RegisterMessage(MapSetNooks.NooksEntry)

MapSetSpawn = _reflection.GeneratedProtocolMessageType('MapSetSpawn', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETSPAWN,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetSpawn)
  })
_sym_db.RegisterMessage(MapSetSpawn)

MapSetSpawns = _reflection.GeneratedProtocolMessageType('MapSetSpawns', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETSPAWNS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetSpawns)
  })
_sym_db.RegisterMessage(MapSetSpawns)

MapSetPortals = _reflection.GeneratedProtocolMessageType('MapSetPortals', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETPORTALS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetPortals)
  })
_sym_db.RegisterMessage(MapSetPortals)

MapSetAnnouncer = _reflection.GeneratedProtocolMessageType('MapSetAnnouncer', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETANNOUNCER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetAnnouncer)
  })
_sym_db.RegisterMessage(MapSetAnnouncer)

MapSetAssets = _reflection.GeneratedProtocolMessageType('MapSetAssets', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETASSETS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetAssets)
  })
_sym_db.RegisterMessage(MapSetAssets)

MapSetObjects = _reflection.GeneratedProtocolMessageType('MapSetObjects', (_message.Message,), {

  'ObjectsEntry' : _reflection.GeneratedProtocolMessageType('ObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPSETOBJECTS_OBJECTSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:MapSetObjects.ObjectsEntry)
    })
  ,
  'DESCRIPTOR' : _MAPSETOBJECTS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetObjects)
  })
_sym_db.RegisterMessage(MapSetObjects)
_sym_db.RegisterMessage(MapSetObjects.ObjectsEntry)

MapSetName = _reflection.GeneratedProtocolMessageType('MapSetName', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETNAME,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetName)
  })
_sym_db.RegisterMessage(MapSetName)

MapSetMuteOnEntry = _reflection.GeneratedProtocolMessageType('MapSetMuteOnEntry', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETMUTEONENTRY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetMuteOnEntry)
  })
_sym_db.RegisterMessage(MapSetMuteOnEntry)

MapSetUseDrawnBG = _reflection.GeneratedProtocolMessageType('MapSetUseDrawnBG', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETUSEDRAWNBG,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetUseDrawnBG)
  })
_sym_db.RegisterMessage(MapSetUseDrawnBG)

MapSetWalls = _reflection.GeneratedProtocolMessageType('MapSetWalls', (_message.Message,), {

  'WallsEntry' : _reflection.GeneratedProtocolMessageType('WallsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPSETWALLS_WALLSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:MapSetWalls.WallsEntry)
    })
  ,
  'DESCRIPTOR' : _MAPSETWALLS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetWalls)
  })
_sym_db.RegisterMessage(MapSetWalls)
_sym_db.RegisterMessage(MapSetWalls.WallsEntry)

MapSetFloors = _reflection.GeneratedProtocolMessageType('MapSetFloors', (_message.Message,), {

  'FloorsEntry' : _reflection.GeneratedProtocolMessageType('FloorsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPSETFLOORS_FLOORSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:MapSetFloors.FloorsEntry)
    })
  ,
  'DESCRIPTOR' : _MAPSETFLOORS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetFloors)
  })
_sym_db.RegisterMessage(MapSetFloors)
_sym_db.RegisterMessage(MapSetFloors.FloorsEntry)

MapSetAreas = _reflection.GeneratedProtocolMessageType('MapSetAreas', (_message.Message,), {

  'AreasEntry' : _reflection.GeneratedProtocolMessageType('AreasEntry', (_message.Message,), {
    'DESCRIPTOR' : _MAPSETAREAS_AREASENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:MapSetAreas.AreasEntry)
    })
  ,
  'DESCRIPTOR' : _MAPSETAREAS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetAreas)
  })
_sym_db.RegisterMessage(MapSetAreas)
_sym_db.RegisterMessage(MapSetAreas.AreasEntry)

MapDeleteObject = _reflection.GeneratedProtocolMessageType('MapDeleteObject', (_message.Message,), {
  'DESCRIPTOR' : _MAPDELETEOBJECT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapDeleteObject)
  })
_sym_db.RegisterMessage(MapDeleteObject)

MapDeleteObjectById = _reflection.GeneratedProtocolMessageType('MapDeleteObjectById', (_message.Message,), {
  'DESCRIPTOR' : _MAPDELETEOBJECTBYID,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapDeleteObjectById)
  })
_sym_db.RegisterMessage(MapDeleteObjectById)

MapSetMiniMapImagePath = _reflection.GeneratedProtocolMessageType('MapSetMiniMapImagePath', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETMINIMAPIMAGEPATH,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetMiniMapImagePath)
  })
_sym_db.RegisterMessage(MapSetMiniMapImagePath)

MapSetEnabledChats = _reflection.GeneratedProtocolMessageType('MapSetEnabledChats', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETENABLEDCHATS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetEnabledChats)
  })
_sym_db.RegisterMessage(MapSetEnabledChats)

MapSetDescription = _reflection.GeneratedProtocolMessageType('MapSetDescription', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETDESCRIPTION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetDescription)
  })
_sym_db.RegisterMessage(MapSetDescription)

MapSetDecoration = _reflection.GeneratedProtocolMessageType('MapSetDecoration', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETDECORATION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetDecoration)
  })
_sym_db.RegisterMessage(MapSetDecoration)

MapSetTutorialTasks = _reflection.GeneratedProtocolMessageType('MapSetTutorialTasks', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETTUTORIALTASKS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetTutorialTasks)
  })
_sym_db.RegisterMessage(MapSetTutorialTasks)

WireTutorialTasks = _reflection.GeneratedProtocolMessageType('WireTutorialTasks', (_message.Message,), {
  'DESCRIPTOR' : _WIRETUTORIALTASKS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:WireTutorialTasks)
  })
_sym_db.RegisterMessage(WireTutorialTasks)

TutorialTaskMapArea = _reflection.GeneratedProtocolMessageType('TutorialTaskMapArea', (_message.Message,), {
  'DESCRIPTOR' : _TUTORIALTASKMAPAREA,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:TutorialTaskMapArea)
  })
_sym_db.RegisterMessage(TutorialTaskMapArea)

MapSetScript = _reflection.GeneratedProtocolMessageType('MapSetScript', (_message.Message,), {
  'DESCRIPTOR' : _MAPSETSCRIPT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapSetScript)
  })
_sym_db.RegisterMessage(MapSetScript)

Inventory = _reflection.GeneratedProtocolMessageType('Inventory', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVENTORY_ITEMSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:Inventory.ItemsEntry)
    })
  ,

  'OrderEntry' : _reflection.GeneratedProtocolMessageType('OrderEntry', (_message.Message,), {
    'DESCRIPTOR' : _INVENTORY_ORDERENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:Inventory.OrderEntry)
    })
  ,
  'DESCRIPTOR' : _INVENTORY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Inventory)
  })
_sym_db.RegisterMessage(Inventory)
_sym_db.RegisterMessage(Inventory.ItemsEntry)
_sym_db.RegisterMessage(Inventory.OrderEntry)

InventoryItem = _reflection.GeneratedProtocolMessageType('InventoryItem', (_message.Message,), {
  'DESCRIPTOR' : _INVENTORYITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:InventoryItem)
  })
_sym_db.RegisterMessage(InventoryItem)

SpaceItem = _reflection.GeneratedProtocolMessageType('SpaceItem', (_message.Message,), {

  'MetaEntry' : _reflection.GeneratedProtocolMessageType('MetaEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPACEITEM_METAENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:SpaceItem.MetaEntry)
    })
  ,

  'AbilitiesEntry' : _reflection.GeneratedProtocolMessageType('AbilitiesEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPACEITEM_ABILITIESENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:SpaceItem.AbilitiesEntry)
    })
  ,
  'DESCRIPTOR' : _SPACEITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceItem)
  })
_sym_db.RegisterMessage(SpaceItem)
_sym_db.RegisterMessage(SpaceItem.MetaEntry)
_sym_db.RegisterMessage(SpaceItem.AbilitiesEntry)

ItemAbility = _reflection.GeneratedProtocolMessageType('ItemAbility', (_message.Message,), {
  'DESCRIPTOR' : _ITEMABILITY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ItemAbility)
  })
_sym_db.RegisterMessage(ItemAbility)

MapLocation = _reflection.GeneratedProtocolMessageType('MapLocation', (_message.Message,), {
  'DESCRIPTOR' : _MAPLOCATION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapLocation)
  })
_sym_db.RegisterMessage(MapLocation)

ServerClientBatch = _reflection.GeneratedProtocolMessageType('ServerClientBatch', (_message.Message,), {
  'DESCRIPTOR' : _SERVERCLIENTBATCH,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ServerClientBatch)
  })
_sym_db.RegisterMessage(ServerClientBatch)

ServerClientEvent = _reflection.GeneratedProtocolMessageType('ServerClientEvent', (_message.Message,), {
  'DESCRIPTOR' : _SERVERCLIENTEVENT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ServerClientEvent)
  })
_sym_db.RegisterMessage(ServerClientEvent)

ServerHeartbeat = _reflection.GeneratedProtocolMessageType('ServerHeartbeat', (_message.Message,), {
  'DESCRIPTOR' : _SERVERHEARTBEAT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ServerHeartbeat)
  })
_sym_db.RegisterMessage(ServerHeartbeat)

Info = _reflection.GeneratedProtocolMessageType('Info', (_message.Message,), {
  'DESCRIPTOR' : _INFO,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Info)
  })
_sym_db.RegisterMessage(Info)

Warn = _reflection.GeneratedProtocolMessageType('Warn', (_message.Message,), {
  'DESCRIPTOR' : _WARN,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Warn)
  })
_sym_db.RegisterMessage(Warn)

ErrorEvent = _reflection.GeneratedProtocolMessageType('ErrorEvent', (_message.Message,), {
  'DESCRIPTOR' : _ERROREVENT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ErrorEvent)
  })
_sym_db.RegisterMessage(ErrorEvent)

Ready = _reflection.GeneratedProtocolMessageType('Ready', (_message.Message,), {
  'DESCRIPTOR' : _READY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Ready)
  })
_sym_db.RegisterMessage(Ready)

TransactionStatus = _reflection.GeneratedProtocolMessageType('TransactionStatus', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:TransactionStatus)
  })
_sym_db.RegisterMessage(TransactionStatus)

PlayerJoins = _reflection.GeneratedProtocolMessageType('PlayerJoins', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERJOINS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerJoins)
  })
_sym_db.RegisterMessage(PlayerJoins)

GotRequestMute = _reflection.GeneratedProtocolMessageType('GotRequestMute', (_message.Message,), {
  'DESCRIPTOR' : _GOTREQUESTMUTE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:GotRequestMute)
  })
_sym_db.RegisterMessage(GotRequestMute)

PlayerMoves = _reflection.GeneratedProtocolMessageType('PlayerMoves', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERMOVES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerMoves)
  })
_sym_db.RegisterMessage(PlayerMoves)

PlayerSetsStatus = _reflection.GeneratedProtocolMessageType('PlayerSetsStatus', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSSTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsStatus)
  })
_sym_db.RegisterMessage(PlayerSetsStatus)

PlayerSpotlights = _reflection.GeneratedProtocolMessageType('PlayerSpotlights', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSPOTLIGHTS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSpotlights)
  })
_sym_db.RegisterMessage(PlayerSpotlights)

PlayerRings = _reflection.GeneratedProtocolMessageType('PlayerRings', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERRINGS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerRings)
  })
_sym_db.RegisterMessage(PlayerRings)

PlayerSetsImagePointer = _reflection.GeneratedProtocolMessageType('PlayerSetsImagePointer', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSIMAGEPOINTER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsImagePointer)
  })
_sym_db.RegisterMessage(PlayerSetsImagePointer)

SetScreenPointerServer = _reflection.GeneratedProtocolMessageType('SetScreenPointerServer', (_message.Message,), {
  'DESCRIPTOR' : _SETSCREENPOINTERSERVER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetScreenPointerServer)
  })
_sym_db.RegisterMessage(SetScreenPointerServer)

PlayerChats = _reflection.GeneratedProtocolMessageType('PlayerChats', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERCHATS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerChats)
  })
_sym_db.RegisterMessage(PlayerChats)

PlayerWaves = _reflection.GeneratedProtocolMessageType('PlayerWaves', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERWAVES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerWaves)
  })
_sym_db.RegisterMessage(PlayerWaves)

Timestamp = _reflection.GeneratedProtocolMessageType('Timestamp', (_message.Message,), {
  'DESCRIPTOR' : _TIMESTAMP,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Timestamp)
  })
_sym_db.RegisterMessage(Timestamp)

PlayerInteracts = _reflection.GeneratedProtocolMessageType('PlayerInteracts', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERINTERACTS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerInteracts)
  })
_sym_db.RegisterMessage(PlayerInteracts)

PlayerGhosts = _reflection.GeneratedProtocolMessageType('PlayerGhosts', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERGHOSTS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerGhosts)
  })
_sym_db.RegisterMessage(PlayerGhosts)

PlayerEntersWhisper = _reflection.GeneratedProtocolMessageType('PlayerEntersWhisper', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERENTERSWHISPER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerEntersWhisper)
  })
_sym_db.RegisterMessage(PlayerEntersWhisper)

PlayerEntersWhisperV2 = _reflection.GeneratedProtocolMessageType('PlayerEntersWhisperV2', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERENTERSWHISPERV2,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerEntersWhisperV2)
  })
_sym_db.RegisterMessage(PlayerEntersWhisperV2)

PlayerLeavesWhisper = _reflection.GeneratedProtocolMessageType('PlayerLeavesWhisper', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERLEAVESWHISPER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerLeavesWhisper)
  })
_sym_db.RegisterMessage(PlayerLeavesWhisper)

PlayerActivelySpeaks = _reflection.GeneratedProtocolMessageType('PlayerActivelySpeaks', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERACTIVELYSPEAKS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerActivelySpeaks)
  })
_sym_db.RegisterMessage(PlayerActivelySpeaks)

PlayerSetsEmoteV2 = _reflection.GeneratedProtocolMessageType('PlayerSetsEmoteV2', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSEMOTEV2,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsEmoteV2)
  })
_sym_db.RegisterMessage(PlayerSetsEmoteV2)

PlayerSetsWorkCondition = _reflection.GeneratedProtocolMessageType('PlayerSetsWorkCondition', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSWORKCONDITION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsWorkCondition)
  })
_sym_db.RegisterMessage(PlayerSetsWorkCondition)

PlayerSetsLastActive = _reflection.GeneratedProtocolMessageType('PlayerSetsLastActive', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSLASTACTIVE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsLastActive)
  })
_sym_db.RegisterMessage(PlayerSetsLastActive)

PlayerSetsName = _reflection.GeneratedProtocolMessageType('PlayerSetsName', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSNAME,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsName)
  })
_sym_db.RegisterMessage(PlayerSetsName)

PlayerSetsTextStatus = _reflection.GeneratedProtocolMessageType('PlayerSetsTextStatus', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSTEXTSTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsTextStatus)
  })
_sym_db.RegisterMessage(PlayerSetsTextStatus)

PlayerSetsPronouns = _reflection.GeneratedProtocolMessageType('PlayerSetsPronouns', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSPRONOUNS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsPronouns)
  })
_sym_db.RegisterMessage(PlayerSetsPronouns)

PlayerSetsTitle = _reflection.GeneratedProtocolMessageType('PlayerSetsTitle', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSTITLE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsTitle)
  })
_sym_db.RegisterMessage(PlayerSetsTitle)

PlayerSetsCity = _reflection.GeneratedProtocolMessageType('PlayerSetsCity', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSCITY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsCity)
  })
_sym_db.RegisterMessage(PlayerSetsCity)

PlayerSetsCountry = _reflection.GeneratedProtocolMessageType('PlayerSetsCountry', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSCOUNTRY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsCountry)
  })
_sym_db.RegisterMessage(PlayerSetsCountry)

PlayerSetsStartDate = _reflection.GeneratedProtocolMessageType('PlayerSetsStartDate', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSSTARTDATE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsStartDate)
  })
_sym_db.RegisterMessage(PlayerSetsStartDate)

PlayerSetsTimezone = _reflection.GeneratedProtocolMessageType('PlayerSetsTimezone', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSTIMEZONE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsTimezone)
  })
_sym_db.RegisterMessage(PlayerSetsTimezone)

PlayerSetsPhone = _reflection.GeneratedProtocolMessageType('PlayerSetsPhone', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSPHONE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsPhone)
  })
_sym_db.RegisterMessage(PlayerSetsPhone)

PlayerSetsDescription = _reflection.GeneratedProtocolMessageType('PlayerSetsDescription', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSDESCRIPTION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsDescription)
  })
_sym_db.RegisterMessage(PlayerSetsDescription)

PlayerSetsProfileImageUrl = _reflection.GeneratedProtocolMessageType('PlayerSetsProfileImageUrl', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSPROFILEIMAGEURL,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsProfileImageUrl)
  })
_sym_db.RegisterMessage(PlayerSetsProfileImageUrl)

PlayerSetsPersonalImageUrl = _reflection.GeneratedProtocolMessageType('PlayerSetsPersonalImageUrl', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSPERSONALIMAGEURL,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsPersonalImageUrl)
  })
_sym_db.RegisterMessage(PlayerSetsPersonalImageUrl)

PlayerSetsIsMobile = _reflection.GeneratedProtocolMessageType('PlayerSetsIsMobile', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSISMOBILE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsIsMobile)
  })
_sym_db.RegisterMessage(PlayerSetsIsMobile)

PlayerSetsEmojiStatus = _reflection.GeneratedProtocolMessageType('PlayerSetsEmojiStatus', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSEMOJISTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsEmojiStatus)
  })
_sym_db.RegisterMessage(PlayerSetsEmojiStatus)

PlayerSetsAffiliation = _reflection.GeneratedProtocolMessageType('PlayerSetsAffiliation', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSAFFILIATION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsAffiliation)
  })
_sym_db.RegisterMessage(PlayerSetsAffiliation)

PlayerExits = _reflection.GeneratedProtocolMessageType('PlayerExits', (_message.Message,), {
  'DESCRIPTOR' : _PLAYEREXITS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerExits)
  })
_sym_db.RegisterMessage(PlayerExits)

PlayerSetsOutfitString = _reflection.GeneratedProtocolMessageType('PlayerSetsOutfitString', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSOUTFITSTRING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsOutfitString)
  })
_sym_db.RegisterMessage(PlayerSetsOutfitString)

PlayerSetsIsSignedIn = _reflection.GeneratedProtocolMessageType('PlayerSetsIsSignedIn', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSISSIGNEDIN,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsIsSignedIn)
  })
_sym_db.RegisterMessage(PlayerSetsIsSignedIn)

RespawnComplete = _reflection.GeneratedProtocolMessageType('RespawnComplete', (_message.Message,), {
  'DESCRIPTOR' : _RESPAWNCOMPLETE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RespawnComplete)
  })
_sym_db.RegisterMessage(RespawnComplete)

SpaceOverwrites = _reflection.GeneratedProtocolMessageType('SpaceOverwrites', (_message.Message,), {
  'DESCRIPTOR' : _SPACEOVERWRITES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceOverwrites)
  })
_sym_db.RegisterMessage(SpaceOverwrites)

DynamicGate = _reflection.GeneratedProtocolMessageType('DynamicGate', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICGATE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:DynamicGate)
  })
_sym_db.RegisterMessage(DynamicGate)

DynamicGates = _reflection.GeneratedProtocolMessageType('DynamicGates', (_message.Message,), {
  'DESCRIPTOR' : _DYNAMICGATES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:DynamicGates)
  })
_sym_db.RegisterMessage(DynamicGates)

SpaceSetsSpaceMembers = _reflection.GeneratedProtocolMessageType('SpaceSetsSpaceMembers', (_message.Message,), {

  'MembersEntry' : _reflection.GeneratedProtocolMessageType('MembersEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPACESETSSPACEMEMBERS_MEMBERSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:SpaceSetsSpaceMembers.MembersEntry)
    })
  ,
  'DESCRIPTOR' : _SPACESETSSPACEMEMBERS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceSetsSpaceMembers)
  })
_sym_db.RegisterMessage(SpaceSetsSpaceMembers)
_sym_db.RegisterMessage(SpaceSetsSpaceMembers.MembersEntry)

SpaceIsClosed = _reflection.GeneratedProtocolMessageType('SpaceIsClosed', (_message.Message,), {
  'DESCRIPTOR' : _SPACEISCLOSED,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceIsClosed)
  })
_sym_db.RegisterMessage(SpaceIsClosed)

PlayerEntersPortal = _reflection.GeneratedProtocolMessageType('PlayerEntersPortal', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERENTERSPORTAL,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerEntersPortal)
  })
_sym_db.RegisterMessage(PlayerEntersPortal)

CookieFound = _reflection.GeneratedProtocolMessageType('CookieFound', (_message.Message,), {
  'DESCRIPTOR' : _COOKIEFOUND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:CookieFound)
  })
_sym_db.RegisterMessage(CookieFound)

SpaceSetsIdMapping = _reflection.GeneratedProtocolMessageType('SpaceSetsIdMapping', (_message.Message,), {
  'DESCRIPTOR' : _SPACESETSIDMAPPING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceSetsIdMapping)
  })
_sym_db.RegisterMessage(SpaceSetsIdMapping)

PlayerShootsConfetti = _reflection.GeneratedProtocolMessageType('PlayerShootsConfetti', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSHOOTSCONFETTI,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerShootsConfetti)
  })
_sym_db.RegisterMessage(PlayerShootsConfetti)

PlayerSetsEventStatus = _reflection.GeneratedProtocolMessageType('PlayerSetsEventStatus', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSEVENTSTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsEventStatus)
  })
_sym_db.RegisterMessage(PlayerSetsEventStatus)

PlayerSetsInConversation = _reflection.GeneratedProtocolMessageType('PlayerSetsInConversation', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSINCONVERSATION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsInConversation)
  })
_sym_db.RegisterMessage(PlayerSetsInConversation)

PlayerSetsCurrentDesk = _reflection.GeneratedProtocolMessageType('PlayerSetsCurrentDesk', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSCURRENTDESK,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsCurrentDesk)
  })
_sym_db.RegisterMessage(PlayerSetsCurrentDesk)

PlayerSetsCurrentArea = _reflection.GeneratedProtocolMessageType('PlayerSetsCurrentArea', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSCURRENTAREA,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsCurrentArea)
  })
_sym_db.RegisterMessage(PlayerSetsCurrentArea)

PlayerSetsGoKartId = _reflection.GeneratedProtocolMessageType('PlayerSetsGoKartId', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSGOKARTID,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsGoKartId)
  })
_sym_db.RegisterMessage(PlayerSetsGoKartId)

PlayerSetsVehicleId = _reflection.GeneratedProtocolMessageType('PlayerSetsVehicleId', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSVEHICLEID,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsVehicleId)
  })
_sym_db.RegisterMessage(PlayerSetsVehicleId)

PlayerSetsSpeedModifier = _reflection.GeneratedProtocolMessageType('PlayerSetsSpeedModifier', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSSPEEDMODIFIER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsSpeedModifier)
  })
_sym_db.RegisterMessage(PlayerSetsSpeedModifier)

PlayerSetsIsAlone = _reflection.GeneratedProtocolMessageType('PlayerSetsIsAlone', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSISALONE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsIsAlone)
  })
_sym_db.RegisterMessage(PlayerSetsIsAlone)

SpacePlaysSound = _reflection.GeneratedProtocolMessageType('SpacePlaysSound', (_message.Message,), {
  'DESCRIPTOR' : _SPACEPLAYSSOUND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpacePlaysSound)
  })
_sym_db.RegisterMessage(SpacePlaysSound)

SpaceStopsSound = _reflection.GeneratedProtocolMessageType('SpaceStopsSound', (_message.Message,), {
  'DESCRIPTOR' : _SPACESTOPSSOUND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceStopsSound)
  })
_sym_db.RegisterMessage(SpaceStopsSound)

PlayerSetsFocusModeEndTime = _reflection.GeneratedProtocolMessageType('PlayerSetsFocusModeEndTime', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSFOCUSMODEENDTIME,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsFocusModeEndTime)
  })
_sym_db.RegisterMessage(PlayerSetsFocusModeEndTime)

PlayerBlocks = _reflection.GeneratedProtocolMessageType('PlayerBlocks', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERBLOCKS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerBlocks)
  })
_sym_db.RegisterMessage(PlayerBlocks)

CustomEvent = _reflection.GeneratedProtocolMessageType('CustomEvent', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMEVENT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:CustomEvent)
  })
_sym_db.RegisterMessage(CustomEvent)

PlayerUpdatesFocusModeStatus = _reflection.GeneratedProtocolMessageType('PlayerUpdatesFocusModeStatus', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERUPDATESFOCUSMODESTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerUpdatesFocusModeStatus)
  })
_sym_db.RegisterMessage(PlayerUpdatesFocusModeStatus)

PlayerSetsItemString = _reflection.GeneratedProtocolMessageType('PlayerSetsItemString', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSITEMSTRING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsItemString)
  })
_sym_db.RegisterMessage(PlayerSetsItemString)

PlayerTriggersItem = _reflection.GeneratedProtocolMessageType('PlayerTriggersItem', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERTRIGGERSITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerTriggersItem)
  })
_sym_db.RegisterMessage(PlayerTriggersItem)

PlayerNotifies = _reflection.GeneratedProtocolMessageType('PlayerNotifies', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERNOTIFIES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerNotifies)
  })
_sym_db.RegisterMessage(PlayerNotifies)

PlayerSetsFollowTarget = _reflection.GeneratedProtocolMessageType('PlayerSetsFollowTarget', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSFOLLOWTARGET,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsFollowTarget)
  })
_sym_db.RegisterMessage(PlayerSetsFollowTarget)

PlayerRequestsToLead = _reflection.GeneratedProtocolMessageType('PlayerRequestsToLead', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERREQUESTSTOLEAD,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerRequestsToLead)
  })
_sym_db.RegisterMessage(PlayerRequestsToLead)

PlayerSetsManualVideoSrc = _reflection.GeneratedProtocolMessageType('PlayerSetsManualVideoSrc', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSMANUALVIDEOSRC,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsManualVideoSrc)
  })
_sym_db.RegisterMessage(PlayerSetsManualVideoSrc)

PlayerSetsIsNpc = _reflection.GeneratedProtocolMessageType('PlayerSetsIsNpc', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSISNPC,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsIsNpc)
  })
_sym_db.RegisterMessage(PlayerSetsIsNpc)

PlayerSetsSubtitle = _reflection.GeneratedProtocolMessageType('PlayerSetsSubtitle', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSSUBTITLE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsSubtitle)
  })
_sym_db.RegisterMessage(PlayerSetsSubtitle)

PlayerCrafts = _reflection.GeneratedProtocolMessageType('PlayerCrafts', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLAYERCRAFTS_INPUTSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:PlayerCrafts.InputsEntry)
    })
  ,
  'DESCRIPTOR' : _PLAYERCRAFTS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerCrafts)
  })
_sym_db.RegisterMessage(PlayerCrafts)
_sym_db.RegisterMessage(PlayerCrafts.InputsEntry)

MapMoveObject = _reflection.GeneratedProtocolMessageType('MapMoveObject', (_message.Message,), {
  'DESCRIPTOR' : _MAPMOVEOBJECT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapMoveObject)
  })
_sym_db.RegisterMessage(MapMoveObject)

PlayerEditsChatMessage = _reflection.GeneratedProtocolMessageType('PlayerEditsChatMessage', (_message.Message,), {
  'DESCRIPTOR' : _PLAYEREDITSCHATMESSAGE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerEditsChatMessage)
  })
_sym_db.RegisterMessage(PlayerEditsChatMessage)

FXShakeObject = _reflection.GeneratedProtocolMessageType('FXShakeObject', (_message.Message,), {
  'DESCRIPTOR' : _FXSHAKEOBJECT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:FXShakeObject)
  })
_sym_db.RegisterMessage(FXShakeObject)

FXShakeCamera = _reflection.GeneratedProtocolMessageType('FXShakeCamera', (_message.Message,), {
  'DESCRIPTOR' : _FXSHAKECAMERA,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:FXShakeCamera)
  })
_sym_db.RegisterMessage(FXShakeCamera)

PlayerHighFives = _reflection.GeneratedProtocolMessageType('PlayerHighFives', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERHIGHFIVES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerHighFives)
  })
_sym_db.RegisterMessage(PlayerHighFives)

PlayerSendsCommand = _reflection.GeneratedProtocolMessageType('PlayerSendsCommand', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSENDSCOMMAND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSendsCommand)
  })
_sym_db.RegisterMessage(PlayerSendsCommand)

SpaceRegistersCommand = _reflection.GeneratedProtocolMessageType('SpaceRegistersCommand', (_message.Message,), {
  'DESCRIPTOR' : _SPACEREGISTERSCOMMAND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceRegistersCommand)
  })
_sym_db.RegisterMessage(SpaceRegistersCommand)

PlayerUpdatesInventory = _reflection.GeneratedProtocolMessageType('PlayerUpdatesInventory', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLAYERUPDATESINVENTORY_ITEMSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:PlayerUpdatesInventory.ItemsEntry)
    })
  ,

  'OrderEntry' : _reflection.GeneratedProtocolMessageType('OrderEntry', (_message.Message,), {
    'DESCRIPTOR' : _PLAYERUPDATESINVENTORY_ORDERENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:PlayerUpdatesInventory.OrderEntry)
    })
  ,
  'DESCRIPTOR' : _PLAYERUPDATESINVENTORY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerUpdatesInventory)
  })
_sym_db.RegisterMessage(PlayerUpdatesInventory)
_sym_db.RegisterMessage(PlayerUpdatesInventory.ItemsEntry)
_sym_db.RegisterMessage(PlayerUpdatesInventory.OrderEntry)

SpaceUpdatesItems = _reflection.GeneratedProtocolMessageType('SpaceUpdatesItems', (_message.Message,), {

  'ItemsEntry' : _reflection.GeneratedProtocolMessageType('ItemsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SPACEUPDATESITEMS_ITEMSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:SpaceUpdatesItems.ItemsEntry)
    })
  ,
  'DESCRIPTOR' : _SPACEUPDATESITEMS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceUpdatesItems)
  })
_sym_db.RegisterMessage(SpaceUpdatesItems)
_sym_db.RegisterMessage(SpaceUpdatesItems.ItemsEntry)

PlayerTriggersInventoryItem = _reflection.GeneratedProtocolMessageType('PlayerTriggersInventoryItem', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERTRIGGERSINVENTORYITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerTriggersInventoryItem)
  })
_sym_db.RegisterMessage(PlayerTriggersInventoryItem)

PlayerSetsAllowScreenPointer = _reflection.GeneratedProtocolMessageType('PlayerSetsAllowScreenPointer', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSALLOWSCREENPOINTER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsAllowScreenPointer)
  })
_sym_db.RegisterMessage(PlayerSetsAllowScreenPointer)

PrecomputedEnterLocation = _reflection.GeneratedProtocolMessageType('PrecomputedEnterLocation', (_message.Message,), {
  'DESCRIPTOR' : _PRECOMPUTEDENTERLOCATION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PrecomputedEnterLocation)
  })
_sym_db.RegisterMessage(PrecomputedEnterLocation)

PlayerSetsDeskInfo = _reflection.GeneratedProtocolMessageType('PlayerSetsDeskInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSDESKINFO,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsDeskInfo)
  })
_sym_db.RegisterMessage(PlayerSetsDeskInfo)

SpaceSetsCapacity = _reflection.GeneratedProtocolMessageType('SpaceSetsCapacity', (_message.Message,), {
  'DESCRIPTOR' : _SPACESETSCAPACITY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceSetsCapacity)
  })
_sym_db.RegisterMessage(SpaceSetsCapacity)

SpaceOverCapacityDeniesUser = _reflection.GeneratedProtocolMessageType('SpaceOverCapacityDeniesUser', (_message.Message,), {
  'DESCRIPTOR' : _SPACEOVERCAPACITYDENIESUSER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpaceOverCapacityDeniesUser)
  })
_sym_db.RegisterMessage(SpaceOverCapacityDeniesUser)

PlayerSetsAway = _reflection.GeneratedProtocolMessageType('PlayerSetsAway', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSAWAY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsAway)
  })
_sym_db.RegisterMessage(PlayerSetsAway)

PlayerSetsIsRecordingClient = _reflection.GeneratedProtocolMessageType('PlayerSetsIsRecordingClient', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSETSISRECORDINGCLIENT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerSetsIsRecordingClient)
  })
_sym_db.RegisterMessage(PlayerSetsIsRecordingClient)

PlayerStartsRecording = _reflection.GeneratedProtocolMessageType('PlayerStartsRecording', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERSTARTSRECORDING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerStartsRecording)
  })
_sym_db.RegisterMessage(PlayerStartsRecording)

ClientServerBatch = _reflection.GeneratedProtocolMessageType('ClientServerBatch', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSERVERBATCH,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ClientServerBatch)
  })
_sym_db.RegisterMessage(ClientServerBatch)

ClientServerAction = _reflection.GeneratedProtocolMessageType('ClientServerAction', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTSERVERACTION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ClientServerAction)
  })
_sym_db.RegisterMessage(ClientServerAction)

ClientHeartbeat = _reflection.GeneratedProtocolMessageType('ClientHeartbeat', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTHEARTBEAT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ClientHeartbeat)
  })
_sym_db.RegisterMessage(ClientHeartbeat)

ClientBackupHeartbeat = _reflection.GeneratedProtocolMessageType('ClientBackupHeartbeat', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTBACKUPHEARTBEAT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ClientBackupHeartbeat)
  })
_sym_db.RegisterMessage(ClientBackupHeartbeat)

UpdateSubscriptions = _reflection.GeneratedProtocolMessageType('UpdateSubscriptions', (_message.Message,), {

  'SubscriptionsEntry' : _reflection.GeneratedProtocolMessageType('SubscriptionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESUBSCRIPTIONS_SUBSCRIPTIONSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:UpdateSubscriptions.SubscriptionsEntry)
    })
  ,

  'MapUpdateIdsEntry' : _reflection.GeneratedProtocolMessageType('MapUpdateIdsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATESUBSCRIPTIONS_MAPUPDATEIDSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:UpdateSubscriptions.MapUpdateIdsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATESUBSCRIPTIONS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:UpdateSubscriptions)
  })
_sym_db.RegisterMessage(UpdateSubscriptions)
_sym_db.RegisterMessage(UpdateSubscriptions.SubscriptionsEntry)
_sym_db.RegisterMessage(UpdateSubscriptions.MapUpdateIdsEntry)

Move = _reflection.GeneratedProtocolMessageType('Move', (_message.Message,), {
  'DESCRIPTOR' : _MOVE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Move)
  })
_sym_db.RegisterMessage(Move)

RequestMute = _reflection.GeneratedProtocolMessageType('RequestMute', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTMUTE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RequestMute)
  })
_sym_db.RegisterMessage(RequestMute)

SetAffiliation = _reflection.GeneratedProtocolMessageType('SetAffiliation', (_message.Message,), {
  'DESCRIPTOR' : _SETAFFILIATION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetAffiliation)
  })
_sym_db.RegisterMessage(SetAffiliation)

SetStatus = _reflection.GeneratedProtocolMessageType('SetStatus', (_message.Message,), {
  'DESCRIPTOR' : _SETSTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetStatus)
  })
_sym_db.RegisterMessage(SetStatus)

SetOutfitString = _reflection.GeneratedProtocolMessageType('SetOutfitString', (_message.Message,), {
  'DESCRIPTOR' : _SETOUTFITSTRING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetOutfitString)
  })
_sym_db.RegisterMessage(SetOutfitString)

Spotlight = _reflection.GeneratedProtocolMessageType('Spotlight', (_message.Message,), {
  'DESCRIPTOR' : _SPOTLIGHT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Spotlight)
  })
_sym_db.RegisterMessage(Spotlight)

Ring = _reflection.GeneratedProtocolMessageType('Ring', (_message.Message,), {
  'DESCRIPTOR' : _RING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Ring)
  })
_sym_db.RegisterMessage(Ring)

SetImagePointer = _reflection.GeneratedProtocolMessageType('SetImagePointer', (_message.Message,), {
  'DESCRIPTOR' : _SETIMAGEPOINTER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetImagePointer)
  })
_sym_db.RegisterMessage(SetImagePointer)

SetScreenPointer = _reflection.GeneratedProtocolMessageType('SetScreenPointer', (_message.Message,), {
  'DESCRIPTOR' : _SETSCREENPOINTER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetScreenPointer)
  })
_sym_db.RegisterMessage(SetScreenPointer)

Ban = _reflection.GeneratedProtocolMessageType('Ban', (_message.Message,), {
  'DESCRIPTOR' : _BAN,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Ban)
  })
_sym_db.RegisterMessage(Ban)

Kick = _reflection.GeneratedProtocolMessageType('Kick', (_message.Message,), {
  'DESCRIPTOR' : _KICK,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Kick)
  })
_sym_db.RegisterMessage(Kick)

Block = _reflection.GeneratedProtocolMessageType('Block', (_message.Message,), {
  'DESCRIPTOR' : _BLOCK,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Block)
  })
_sym_db.RegisterMessage(Block)

SetImpassable = _reflection.GeneratedProtocolMessageType('SetImpassable', (_message.Message,), {
  'DESCRIPTOR' : _SETIMPASSABLE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetImpassable)
  })
_sym_db.RegisterMessage(SetImpassable)

Chat = _reflection.GeneratedProtocolMessageType('Chat', (_message.Message,), {
  'DESCRIPTOR' : _CHAT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Chat)
  })
_sym_db.RegisterMessage(Chat)

Notify = _reflection.GeneratedProtocolMessageType('Notify', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Notify)
  })
_sym_db.RegisterMessage(Notify)

Interact = _reflection.GeneratedProtocolMessageType('Interact', (_message.Message,), {
  'DESCRIPTOR' : _INTERACT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Interact)
  })
_sym_db.RegisterMessage(Interact)

ActivelySpeaking = _reflection.GeneratedProtocolMessageType('ActivelySpeaking', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVELYSPEAKING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ActivelySpeaking)
  })
_sym_db.RegisterMessage(ActivelySpeaking)

EnterWhisper = _reflection.GeneratedProtocolMessageType('EnterWhisper', (_message.Message,), {
  'DESCRIPTOR' : _ENTERWHISPER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:EnterWhisper)
  })
_sym_db.RegisterMessage(EnterWhisper)

LeaveWhisper = _reflection.GeneratedProtocolMessageType('LeaveWhisper', (_message.Message,), {
  'DESCRIPTOR' : _LEAVEWHISPER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:LeaveWhisper)
  })
_sym_db.RegisterMessage(LeaveWhisper)

Ghost = _reflection.GeneratedProtocolMessageType('Ghost', (_message.Message,), {
  'DESCRIPTOR' : _GHOST,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Ghost)
  })
_sym_db.RegisterMessage(Ghost)

SetEmoteV2 = _reflection.GeneratedProtocolMessageType('SetEmoteV2', (_message.Message,), {
  'DESCRIPTOR' : _SETEMOTEV2,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetEmoteV2)
  })
_sym_db.RegisterMessage(SetEmoteV2)

SetName = _reflection.GeneratedProtocolMessageType('SetName', (_message.Message,), {
  'DESCRIPTOR' : _SETNAME,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetName)
  })
_sym_db.RegisterMessage(SetName)

SetTextStatus = _reflection.GeneratedProtocolMessageType('SetTextStatus', (_message.Message,), {
  'DESCRIPTOR' : _SETTEXTSTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetTextStatus)
  })
_sym_db.RegisterMessage(SetTextStatus)

SetPronouns = _reflection.GeneratedProtocolMessageType('SetPronouns', (_message.Message,), {
  'DESCRIPTOR' : _SETPRONOUNS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetPronouns)
  })
_sym_db.RegisterMessage(SetPronouns)

SetTitle = _reflection.GeneratedProtocolMessageType('SetTitle', (_message.Message,), {
  'DESCRIPTOR' : _SETTITLE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetTitle)
  })
_sym_db.RegisterMessage(SetTitle)

SetCity = _reflection.GeneratedProtocolMessageType('SetCity', (_message.Message,), {
  'DESCRIPTOR' : _SETCITY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetCity)
  })
_sym_db.RegisterMessage(SetCity)

SetCountry = _reflection.GeneratedProtocolMessageType('SetCountry', (_message.Message,), {
  'DESCRIPTOR' : _SETCOUNTRY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetCountry)
  })
_sym_db.RegisterMessage(SetCountry)

SetStartDate = _reflection.GeneratedProtocolMessageType('SetStartDate', (_message.Message,), {
  'DESCRIPTOR' : _SETSTARTDATE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetStartDate)
  })
_sym_db.RegisterMessage(SetStartDate)

SetTimezone = _reflection.GeneratedProtocolMessageType('SetTimezone', (_message.Message,), {
  'DESCRIPTOR' : _SETTIMEZONE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetTimezone)
  })
_sym_db.RegisterMessage(SetTimezone)

SetPhone = _reflection.GeneratedProtocolMessageType('SetPhone', (_message.Message,), {
  'DESCRIPTOR' : _SETPHONE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetPhone)
  })
_sym_db.RegisterMessage(SetPhone)

SetDescription = _reflection.GeneratedProtocolMessageType('SetDescription', (_message.Message,), {
  'DESCRIPTOR' : _SETDESCRIPTION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetDescription)
  })
_sym_db.RegisterMessage(SetDescription)

SetProfileImageUrl = _reflection.GeneratedProtocolMessageType('SetProfileImageUrl', (_message.Message,), {
  'DESCRIPTOR' : _SETPROFILEIMAGEURL,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetProfileImageUrl)
  })
_sym_db.RegisterMessage(SetProfileImageUrl)

SetPersonalImageUrl = _reflection.GeneratedProtocolMessageType('SetPersonalImageUrl', (_message.Message,), {
  'DESCRIPTOR' : _SETPERSONALIMAGEURL,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetPersonalImageUrl)
  })
_sym_db.RegisterMessage(SetPersonalImageUrl)

Exit = _reflection.GeneratedProtocolMessageType('Exit', (_message.Message,), {
  'DESCRIPTOR' : _EXIT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Exit)
  })
_sym_db.RegisterMessage(Exit)

Enter = _reflection.GeneratedProtocolMessageType('Enter', (_message.Message,), {
  'DESCRIPTOR' : _ENTER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Enter)
  })
_sym_db.RegisterMessage(Enter)

PrecomputeEnter = _reflection.GeneratedProtocolMessageType('PrecomputeEnter', (_message.Message,), {
  'DESCRIPTOR' : _PRECOMPUTEENTER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PrecomputeEnter)
  })
_sym_db.RegisterMessage(PrecomputeEnter)

SetEmojiStatus = _reflection.GeneratedProtocolMessageType('SetEmojiStatus', (_message.Message,), {
  'DESCRIPTOR' : _SETEMOJISTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetEmojiStatus)
  })
_sym_db.RegisterMessage(SetEmojiStatus)

Teleport = _reflection.GeneratedProtocolMessageType('Teleport', (_message.Message,), {
  'DESCRIPTOR' : _TELEPORT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Teleport)
  })
_sym_db.RegisterMessage(Teleport)

SetWorkCondition = _reflection.GeneratedProtocolMessageType('SetWorkCondition', (_message.Message,), {
  'DESCRIPTOR' : _SETWORKCONDITION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetWorkCondition)
  })
_sym_db.RegisterMessage(SetWorkCondition)

Spawn = _reflection.GeneratedProtocolMessageType('Spawn', (_message.Message,), {
  'DESCRIPTOR' : _SPAWN,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Spawn)
  })
_sym_db.RegisterMessage(Spawn)

Respawn = _reflection.GeneratedProtocolMessageType('Respawn', (_message.Message,), {
  'DESCRIPTOR' : _RESPAWN,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Respawn)
  })
_sym_db.RegisterMessage(Respawn)

RequestToJoinNook = _reflection.GeneratedProtocolMessageType('RequestToJoinNook', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTTOJOINNOOK,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RequestToJoinNook)
  })
_sym_db.RegisterMessage(RequestToJoinNook)

UpdateNookPermission = _reflection.GeneratedProtocolMessageType('UpdateNookPermission', (_message.Message,), {
  'DESCRIPTOR' : _UPDATENOOKPERMISSION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:UpdateNookPermission)
  })
_sym_db.RegisterMessage(UpdateNookPermission)

Init = _reflection.GeneratedProtocolMessageType('Init', (_message.Message,), {
  'DESCRIPTOR' : _INIT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Init)
  })
_sym_db.RegisterMessage(Init)

MapAddObject = _reflection.GeneratedProtocolMessageType('MapAddObject', (_message.Message,), {
  'DESCRIPTOR' : _MAPADDOBJECT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapAddObject)
  })
_sym_db.RegisterMessage(MapAddObject)

ShootConfetti = _reflection.GeneratedProtocolMessageType('ShootConfetti', (_message.Message,), {
  'DESCRIPTOR' : _SHOOTCONFETTI,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ShootConfetti)
  })
_sym_db.RegisterMessage(ShootConfetti)

SetEventStatus = _reflection.GeneratedProtocolMessageType('SetEventStatus', (_message.Message,), {
  'DESCRIPTOR' : _SETEVENTSTATUS,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetEventStatus)
  })
_sym_db.RegisterMessage(SetEventStatus)

SetInConversation = _reflection.GeneratedProtocolMessageType('SetInConversation', (_message.Message,), {
  'DESCRIPTOR' : _SETINCONVERSATION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetInConversation)
  })
_sym_db.RegisterMessage(SetInConversation)

SetCurrentDesk = _reflection.GeneratedProtocolMessageType('SetCurrentDesk', (_message.Message,), {
  'DESCRIPTOR' : _SETCURRENTDESK,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetCurrentDesk)
  })
_sym_db.RegisterMessage(SetCurrentDesk)

SetCurrentArea = _reflection.GeneratedProtocolMessageType('SetCurrentArea', (_message.Message,), {
  'DESCRIPTOR' : _SETCURRENTAREA,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetCurrentArea)
  })
_sym_db.RegisterMessage(SetCurrentArea)

SetGoKartId = _reflection.GeneratedProtocolMessageType('SetGoKartId', (_message.Message,), {
  'DESCRIPTOR' : _SETGOKARTID,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetGoKartId)
  })
_sym_db.RegisterMessage(SetGoKartId)

SetVehicleId = _reflection.GeneratedProtocolMessageType('SetVehicleId', (_message.Message,), {
  'DESCRIPTOR' : _SETVEHICLEID,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetVehicleId)
  })
_sym_db.RegisterMessage(SetVehicleId)

SetSpeedModifier = _reflection.GeneratedProtocolMessageType('SetSpeedModifier', (_message.Message,), {
  'DESCRIPTOR' : _SETSPEEDMODIFIER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetSpeedModifier)
  })
_sym_db.RegisterMessage(SetSpeedModifier)

SetIsAlone = _reflection.GeneratedProtocolMessageType('SetIsAlone', (_message.Message,), {
  'DESCRIPTOR' : _SETISALONE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetIsAlone)
  })
_sym_db.RegisterMessage(SetIsAlone)

SetIsMobile = _reflection.GeneratedProtocolMessageType('SetIsMobile', (_message.Message,), {
  'DESCRIPTOR' : _SETISMOBILE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetIsMobile)
  })
_sym_db.RegisterMessage(SetIsMobile)

PlaySound = _reflection.GeneratedProtocolMessageType('PlaySound', (_message.Message,), {
  'DESCRIPTOR' : _PLAYSOUND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlaySound)
  })
_sym_db.RegisterMessage(PlaySound)

StopSound = _reflection.GeneratedProtocolMessageType('StopSound', (_message.Message,), {
  'DESCRIPTOR' : _STOPSOUND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:StopSound)
  })
_sym_db.RegisterMessage(StopSound)

SetFocusModeEndTime = _reflection.GeneratedProtocolMessageType('SetFocusModeEndTime', (_message.Message,), {
  'DESCRIPTOR' : _SETFOCUSMODEENDTIME,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetFocusModeEndTime)
  })
_sym_db.RegisterMessage(SetFocusModeEndTime)

SetItemString = _reflection.GeneratedProtocolMessageType('SetItemString', (_message.Message,), {
  'DESCRIPTOR' : _SETITEMSTRING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetItemString)
  })
_sym_db.RegisterMessage(SetItemString)

TriggerItem = _reflection.GeneratedProtocolMessageType('TriggerItem', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:TriggerItem)
  })
_sym_db.RegisterMessage(TriggerItem)

CustomAction = _reflection.GeneratedProtocolMessageType('CustomAction', (_message.Message,), {
  'DESCRIPTOR' : _CUSTOMACTION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:CustomAction)
  })
_sym_db.RegisterMessage(CustomAction)

SetFollowTarget = _reflection.GeneratedProtocolMessageType('SetFollowTarget', (_message.Message,), {
  'DESCRIPTOR' : _SETFOLLOWTARGET,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetFollowTarget)
  })
_sym_db.RegisterMessage(SetFollowTarget)

RequestToLead = _reflection.GeneratedProtocolMessageType('RequestToLead', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTTOLEAD,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RequestToLead)
  })
_sym_db.RegisterMessage(RequestToLead)

EnterPortal = _reflection.GeneratedProtocolMessageType('EnterPortal', (_message.Message,), {
  'DESCRIPTOR' : _ENTERPORTAL,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:EnterPortal)
  })
_sym_db.RegisterMessage(EnterPortal)

SetManualVideoSrc = _reflection.GeneratedProtocolMessageType('SetManualVideoSrc', (_message.Message,), {
  'DESCRIPTOR' : _SETMANUALVIDEOSRC,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetManualVideoSrc)
  })
_sym_db.RegisterMessage(SetManualVideoSrc)

SetSubtitle = _reflection.GeneratedProtocolMessageType('SetSubtitle', (_message.Message,), {
  'DESCRIPTOR' : _SETSUBTITLE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetSubtitle)
  })
_sym_db.RegisterMessage(SetSubtitle)

MapCommitsChanges = _reflection.GeneratedProtocolMessageType('MapCommitsChanges', (_message.Message,), {
  'DESCRIPTOR' : _MAPCOMMITSCHANGES,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:MapCommitsChanges)
  })
_sym_db.RegisterMessage(MapCommitsChanges)

PlayerUpdatesSession = _reflection.GeneratedProtocolMessageType('PlayerUpdatesSession', (_message.Message,), {
  'DESCRIPTOR' : _PLAYERUPDATESSESSION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:PlayerUpdatesSession)
  })
_sym_db.RegisterMessage(PlayerUpdatesSession)

SpeakerUpdatesSession = _reflection.GeneratedProtocolMessageType('SpeakerUpdatesSession', (_message.Message,), {
  'DESCRIPTOR' : _SPEAKERUPDATESSESSION,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SpeakerUpdatesSession)
  })
_sym_db.RegisterMessage(SpeakerUpdatesSession)

ChatReply = _reflection.GeneratedProtocolMessageType('ChatReply', (_message.Message,), {
  'DESCRIPTOR' : _CHATREPLY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ChatReply)
  })
_sym_db.RegisterMessage(ChatReply)

ChatMessageUpdated = _reflection.GeneratedProtocolMessageType('ChatMessageUpdated', (_message.Message,), {
  'DESCRIPTOR' : _CHATMESSAGEUPDATED,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:ChatMessageUpdated)
  })
_sym_db.RegisterMessage(ChatMessageUpdated)

SendCommand = _reflection.GeneratedProtocolMessageType('SendCommand', (_message.Message,), {
  'DESCRIPTOR' : _SENDCOMMAND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SendCommand)
  })
_sym_db.RegisterMessage(SendCommand)

RegisterCommand = _reflection.GeneratedProtocolMessageType('RegisterCommand', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERCOMMAND,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RegisterCommand)
  })
_sym_db.RegisterMessage(RegisterCommand)

Craft = _reflection.GeneratedProtocolMessageType('Craft', (_message.Message,), {

  'InputsEntry' : _reflection.GeneratedProtocolMessageType('InputsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CRAFT_INPUTSENTRY,
    '__module__' : 'gather_client_ws.events_pb2'
    # @@protoc_insertion_point(class_scope:Craft.InputsEntry)
    })
  ,
  'DESCRIPTOR' : _CRAFT,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Craft)
  })
_sym_db.RegisterMessage(Craft)
_sym_db.RegisterMessage(Craft.InputsEntry)

HighFive = _reflection.GeneratedProtocolMessageType('HighFive', (_message.Message,), {
  'DESCRIPTOR' : _HIGHFIVE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:HighFive)
  })
_sym_db.RegisterMessage(HighFive)

AddInventoryItem = _reflection.GeneratedProtocolMessageType('AddInventoryItem', (_message.Message,), {
  'DESCRIPTOR' : _ADDINVENTORYITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:AddInventoryItem)
  })
_sym_db.RegisterMessage(AddInventoryItem)

RemoveInventoryItem = _reflection.GeneratedProtocolMessageType('RemoveInventoryItem', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEINVENTORYITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:RemoveInventoryItem)
  })
_sym_db.RegisterMessage(RemoveInventoryItem)

HipToBeSquare = _reflection.GeneratedProtocolMessageType('HipToBeSquare', (_message.Message,), {
  'DESCRIPTOR' : _HIPTOBESQUARE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:HipToBeSquare)
  })
_sym_db.RegisterMessage(HipToBeSquare)

TriggerInventoryItem = _reflection.GeneratedProtocolMessageType('TriggerInventoryItem', (_message.Message,), {
  'DESCRIPTOR' : _TRIGGERINVENTORYITEM,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:TriggerInventoryItem)
  })
_sym_db.RegisterMessage(TriggerInventoryItem)

SetAllowScreenPointer = _reflection.GeneratedProtocolMessageType('SetAllowScreenPointer', (_message.Message,), {
  'DESCRIPTOR' : _SETALLOWSCREENPOINTER,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetAllowScreenPointer)
  })
_sym_db.RegisterMessage(SetAllowScreenPointer)

SetDeskInfo = _reflection.GeneratedProtocolMessageType('SetDeskInfo', (_message.Message,), {
  'DESCRIPTOR' : _SETDESKINFO,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetDeskInfo)
  })
_sym_db.RegisterMessage(SetDeskInfo)

Wave = _reflection.GeneratedProtocolMessageType('Wave', (_message.Message,), {
  'DESCRIPTOR' : _WAVE,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:Wave)
  })
_sym_db.RegisterMessage(Wave)

SetAway = _reflection.GeneratedProtocolMessageType('SetAway', (_message.Message,), {
  'DESCRIPTOR' : _SETAWAY,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:SetAway)
  })
_sym_db.RegisterMessage(SetAway)

StartRecording = _reflection.GeneratedProtocolMessageType('StartRecording', (_message.Message,), {
  'DESCRIPTOR' : _STARTRECORDING,
  '__module__' : 'gather_client_ws.events_pb2'
  # @@protoc_insertion_point(class_scope:StartRecording)
  })
_sym_db.RegisterMessage(StartRecording)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WIREOBJECTSPRITESHEET_ANIMATIONSENTRY._options = None
  _WIREOBJECTSPRITESHEET_ANIMATIONSENTRY._serialized_options = b'8\001'
  _SPACEMEMBERINFO_ROLESENTRY._options = None
  _SPACEMEMBERINFO_ROLESENTRY._serialized_options = b'8\001'
  _DESKOBJECTS_OBJECTSENTRY._options = None
  _DESKOBJECTS_OBJECTSENTRY._serialized_options = b'8\001'
  _REQUESTEDUSERS_USERSENTRY._options = None
  _REQUESTEDUSERS_USERSENTRY._serialized_options = b'8\001'
  _MAPSETNOOKS_NOOKSENTRY._options = None
  _MAPSETNOOKS_NOOKSENTRY._serialized_options = b'8\001'
  _MAPSETOBJECTS_OBJECTSENTRY._options = None
  _MAPSETOBJECTS_OBJECTSENTRY._serialized_options = b'8\001'
  _MAPSETWALLS_WALLSENTRY._options = None
  _MAPSETWALLS_WALLSENTRY._serialized_options = b'8\001'
  _MAPSETFLOORS_FLOORSENTRY._options = None
  _MAPSETFLOORS_FLOORSENTRY._serialized_options = b'8\001'
  _MAPSETAREAS_AREASENTRY._options = None
  _MAPSETAREAS_AREASENTRY._serialized_options = b'8\001'
  _INVENTORY_ITEMSENTRY._options = None
  _INVENTORY_ITEMSENTRY._serialized_options = b'8\001'
  _INVENTORY_ORDERENTRY._options = None
  _INVENTORY_ORDERENTRY._serialized_options = b'8\001'
  _SPACEITEM_METAENTRY._options = None
  _SPACEITEM_METAENTRY._serialized_options = b'8\001'
  _SPACEITEM_ABILITIESENTRY._options = None
  _SPACEITEM_ABILITIESENTRY._serialized_options = b'8\001'
  _SPACESETSSPACEMEMBERS_MEMBERSENTRY._options = None
  _SPACESETSSPACEMEMBERS_MEMBERSENTRY._serialized_options = b'8\001'
  _PLAYERCRAFTS_INPUTSENTRY._options = None
  _PLAYERCRAFTS_INPUTSENTRY._serialized_options = b'8\001'
  _PLAYERUPDATESINVENTORY_ITEMSENTRY._options = None
  _PLAYERUPDATESINVENTORY_ITEMSENTRY._serialized_options = b'8\001'
  _PLAYERUPDATESINVENTORY_ORDERENTRY._options = None
  _PLAYERUPDATESINVENTORY_ORDERENTRY._serialized_options = b'8\001'
  _SPACEUPDATESITEMS_ITEMSENTRY._options = None
  _SPACEUPDATESITEMS_ITEMSENTRY._serialized_options = b'8\001'
  _UPDATESUBSCRIPTIONS_SUBSCRIPTIONSENTRY._options = None
  _UPDATESUBSCRIPTIONS_SUBSCRIPTIONSENTRY._serialized_options = b'8\001'
  _UPDATESUBSCRIPTIONS_MAPUPDATEIDSENTRY._options = None
  _UPDATESUBSCRIPTIONS_MAPUPDATEIDSENTRY._serialized_options = b'8\001'
  _CRAFT_INPUTSENTRY._options = None
  _CRAFT_INPUTSENTRY._serialized_options = b'8\001'
  _SPRITEDIRECTIONENUM._serialized_start=34
  _SPRITEDIRECTIONENUM._serialized_end=213
  _SPRITEDIRECTIONENUM_ENUM._serialized_start=58
  _SPRITEDIRECTIONENUM_ENUM._serialized_end=213
  _MOVEDIRECTIONENUM._serialized_start=215
  _MOVEDIRECTIONENUM._serialized_end=292
  _MOVEDIRECTIONENUM_ENUM._serialized_start=236
  _MOVEDIRECTIONENUM_ENUM._serialized_end=292
  _INTERACTIONENUM._serialized_start=295
  _INTERACTIONENUM._serialized_end=486
  _INTERACTIONENUM_ENUM._serialized_start=315
  _INTERACTIONENUM_ENUM._serialized_end=486
  _PLAYERINITINFO._serialized_start=489
  _PLAYERINITINFO._serialized_end=1056
  _DBOUTFIT._serialized_start=1059
  _DBOUTFIT._serialized_end=1309
  _WIREOBJECTSPRITESHEETFRAMING._serialized_start=1311
  _WIREOBJECTSPRITESHEETFRAMING._serialized_end=1382
  _WIREOBJECTSPRITEANIMCONFIG._serialized_start=1385
  _WIREOBJECTSPRITEANIMCONFIG._serialized_end=1534
  _WIREOBJECTSPRITESHEET._serialized_start=1537
  _WIREOBJECTSPRITESHEET._serialized_end=1814
  _WIREOBJECTSPRITESHEET_ANIMATIONSENTRY._serialized_start=1720
  _WIREOBJECTSPRITESHEET_ANIMATIONSENTRY._serialized_end=1798
  _WIREOBJECT._serialized_start=1817
  _WIREOBJECT._serialized_end=2861
  _SPACEMEMBERINFO._serialized_start=2864
  _SPACEMEMBERINFO._serialized_end=3185
  _SPACEMEMBERINFO_ROLESENTRY._serialized_start=3065
  _SPACEMEMBERINFO_ROLESENTRY._serialized_end=3109
  _BACKEDUPDESKOBJECT._serialized_start=3187
  _BACKEDUPDESKOBJECT._serialized_end=3267
  _DESKOBJECTS._serialized_start=3269
  _DESKOBJECTS._serialized_end=3395
  _DESKOBJECTS_OBJECTSENTRY._serialized_start=3328
  _DESKOBJECTS_OBJECTSENTRY._serialized_end=3395
  _DESKINFO._serialized_start=3397
  _DESKINFO._serialized_end=3497
  _DESKINFOV2._serialized_start=3500
  _DESKINFOV2._serialized_end=3712
  _SOUND._serialized_start=3714
  _SOUND._serialized_end=3829
  _OBJECTTIME._serialized_start=3831
  _OBJECTTIME._serialized_end=3899
  _SPACE._serialized_start=3901
  _SPACE._serialized_end=3981
  _NOOKCOORDS._serialized_start=3983
  _NOOKCOORDS._serialized_end=4023
  _ALLOWEDUSERS._serialized_start=4025
  _ALLOWEDUSERS._serialized_end=4054
  _REQUESTUSER._serialized_start=4056
  _REQUESTUSER._serialized_end=4097
  _REQUESTEDUSERS._serialized_start=4099
  _REQUESTEDUSERS._serialized_end=4218
  _REQUESTEDUSERS_USERSENTRY._serialized_start=4160
  _REQUESTEDUSERS_USERSENTRY._serialized_end=4218
  _RECORDINGINFO._serialized_start=4220
  _RECORDINGINFO._serialized_end=4339
  _NOOKDIFF._serialized_start=4342
  _NOOKDIFF._serialized_end=4839
  _WIREPOINT._serialized_start=4841
  _WIREPOINT._serialized_end=4874
  _SPAWNPOINT._serialized_start=4876
  _SPAWNPOINT._serialized_end=4944
  _PORTAL._serialized_start=4947
  _PORTAL._serialized_end=5121
  _ANNOUNCER._serialized_start=5123
  _ANNOUNCER._serialized_end=5156
  _ASSET._serialized_start=5159
  _ASSET._serialized_end=5297
  _AREAPOSITION._serialized_start=5299
  _AREAPOSITION._serialized_end=5361
  _WIREAREA._serialized_start=5363
  _WIREAREA._serialized_end=5440
  _DBDESK._serialized_start=5442
  _DBDESK._serialized_end=5481
  _MAPSETDIMENSIONS._serialized_start=5483
  _MAPSETDIMENSIONS._serialized_end=5547
  _MAPSETCOLLISIONS._serialized_start=5549
  _MAPSETCOLLISIONS._serialized_end=5640
  _MAPSETCOLLISIONSBITS._serialized_start=5642
  _MAPSETCOLLISIONSBITS._serialized_end=5756
  _MAPSETBACKGROUNDIMAGEPATH._serialized_start=5758
  _MAPSETBACKGROUNDIMAGEPATH._serialized_end=5829
  _MAPSETFOREGROUNDIMAGEPATH._serialized_start=5831
  _MAPSETFOREGROUNDIMAGEPATH._serialized_end=5934
  _MAPSETSPRITES._serialized_start=5936
  _MAPSETSPRITES._serialized_end=6015
  _MAPSETSPACES._serialized_start=6017
  _MAPSETSPACES._serialized_end=6070
  _MAPSETNOOKS._serialized_start=6073
  _MAPSETNOOKS._serialized_end=6236
  _MAPSETNOOKS_NOOKSENTRY._serialized_start=6167
  _MAPSETNOOKS_NOOKSENTRY._serialized_end=6222
  _MAPSETSPAWN._serialized_start=6238
  _MAPSETSPAWN._serialized_end=6325
  _MAPSETSPAWNS._serialized_start=6327
  _MAPSETSPAWNS._serialized_end=6385
  _MAPSETPORTALS._serialized_start=6387
  _MAPSETPORTALS._serialized_end=6443
  _MAPSETANNOUNCER._serialized_start=6445
  _MAPSETANNOUNCER._serialized_end=6508
  _MAPSETASSETS._serialized_start=6510
  _MAPSETASSETS._serialized_end=6595
  _MAPSETOBJECTS._serialized_start=6598
  _MAPSETOBJECTS._serialized_end=6795
  _MAPSETOBJECTS_OBJECTSENTRY._serialized_start=6711
  _MAPSETOBJECTS_OBJECTSENTRY._serialized_end=6770
  _MAPSETNAME._serialized_start=6797
  _MAPSETNAME._serialized_end=6870
  _MAPSETMUTEONENTRY._serialized_start=6872
  _MAPSETMUTEONENTRY._serialized_end=6959
  _MAPSETUSEDRAWNBG._serialized_start=6961
  _MAPSETUSEDRAWNBG._serialized_end=7046
  _MAPSETWALLS._serialized_start=7049
  _MAPSETWALLS._serialized_end=7195
  _MAPSETWALLS_WALLSENTRY._serialized_start=7140
  _MAPSETWALLS_WALLSENTRY._serialized_end=7184
  _MAPSETFLOORS._serialized_start=7198
  _MAPSETFLOORS._serialized_end=7349
  _MAPSETFLOORS_FLOORSENTRY._serialized_start=7293
  _MAPSETFLOORS_FLOORSENTRY._serialized_end=7338
  _MAPSETAREAS._serialized_start=7352
  _MAPSETAREAS._serialized_end=7509
  _MAPSETAREAS_AREASENTRY._serialized_start=7443
  _MAPSETAREAS_AREASENTRY._serialized_end=7498
  _MAPDELETEOBJECT._serialized_start=7511
  _MAPDELETEOBJECT._serialized_end=7556
  _MAPDELETEOBJECTBYID._serialized_start=7558
  _MAPDELETEOBJECTBYID._serialized_end=7606
  _MAPSETMINIMAPIMAGEPATH._serialized_start=7608
  _MAPSETMINIMAPIMAGEPATH._serialized_end=7705
  _MAPSETENABLEDCHATS._serialized_start=7707
  _MAPSETENABLEDCHATS._serialized_end=7796
  _MAPSETDESCRIPTION._serialized_start=7798
  _MAPSETDESCRIPTION._serialized_end=7885
  _MAPSETDECORATION._serialized_start=7887
  _MAPSETDECORATION._serialized_end=7972
  _MAPSETTUTORIALTASKS._serialized_start=7974
  _MAPSETTUTORIALTASKS._serialized_end=8085
  _WIRETUTORIALTASKS._serialized_start=8087
  _WIRETUTORIALTASKS._serialized_end=8201
  _TUTORIALTASKMAPAREA._serialized_start=8203
  _TUTORIALTASKMAPAREA._serialized_end=8293
  _MAPSETSCRIPT._serialized_start=8295
  _MAPSETSCRIPT._serialized_end=8372
  _INVENTORY._serialized_start=8375
  _INVENTORY._serialized_end=8570
  _INVENTORY_ITEMSENTRY._serialized_start=8464
  _INVENTORY_ITEMSENTRY._serialized_end=8524
  _INVENTORY_ORDERENTRY._serialized_start=8526
  _INVENTORY_ORDERENTRY._serialized_end=8570
  _INVENTORYITEM._serialized_start=8572
  _INVENTORYITEM._serialized_end=8602
  _SPACEITEM._serialized_start=8605
  _SPACEITEM._serialized_end=8919
  _SPACEITEM_METAENTRY._serialized_start=8783
  _SPACEITEM_METAENTRY._serialized_end=8826
  _SPACEITEM_ABILITIESENTRY._serialized_start=8828
  _SPACEITEM_ABILITIESENTRY._serialized_end=8890
  _ITEMABILITY._serialized_start=8921
  _ITEMABILITY._serialized_end=8948
  _MAPLOCATION._serialized_start=8950
  _MAPLOCATION._serialized_end=8998
  _SERVERCLIENTBATCH._serialized_start=9000
  _SERVERCLIENTBATCH._serialized_end=9055
  _SERVERCLIENTEVENT._serialized_start=9058
  _SERVERCLIENTEVENT._serialized_end=15201
  _SERVERHEARTBEAT._serialized_start=15203
  _SERVERHEARTBEAT._serialized_end=15237
  _INFO._serialized_start=15239
  _INFO._serialized_end=15262
  _WARN._serialized_start=15264
  _WARN._serialized_end=15287
  _ERROREVENT._serialized_start=15289
  _ERROREVENT._serialized_end=15332
  _READY._serialized_start=15334
  _READY._serialized_end=15353
  _TRANSACTIONSTATUS._serialized_start=15355
  _TRANSACTIONSTATUS._serialized_end=15440
  _PLAYERJOINS._serialized_start=15442
  _PLAYERJOINS._serialized_end=15470
  _GOTREQUESTMUTE._serialized_start=15472
  _GOTREQUESTMUTE._serialized_end=15520
  _PLAYERMOVES._serialized_start=15523
  _PLAYERMOVES._serialized_end=15711
  _PLAYERSETSSTATUS._serialized_start=15713
  _PLAYERSETSSTATUS._serialized_end=15760
  _PLAYERSPOTLIGHTS._serialized_start=15762
  _PLAYERSPOTLIGHTS._serialized_end=15839
  _PLAYERRINGS._serialized_start=15841
  _PLAYERRINGS._serialized_end=15869
  _PLAYERSETSIMAGEPOINTER._serialized_start=15871
  _PLAYERSETSIMAGEPOINTER._serialized_end=15950
  _SETSCREENPOINTERSERVER._serialized_start=15952
  _SETSCREENPOINTERSERVER._serialized_end=16046
  _PLAYERCHATS._serialized_start=16049
  _PLAYERCHATS._serialized_end=16350
  _PLAYERWAVES._serialized_start=16352
  _PLAYERWAVES._serialized_end=16415
  _TIMESTAMP._serialized_start=16417
  _TIMESTAMP._serialized_end=16466
  _PLAYERINTERACTS._serialized_start=16468
  _PLAYERINTERACTS._serialized_end=16581
  _PLAYERGHOSTS._serialized_start=16583
  _PLAYERGHOSTS._serialized_end=16627
  _PLAYERENTERSWHISPER._serialized_start=16629
  _PLAYERENTERSWHISPER._serialized_end=16710
  _PLAYERENTERSWHISPERV2._serialized_start=16712
  _PLAYERENTERSWHISPERV2._serialized_end=16790
  _PLAYERLEAVESWHISPER._serialized_start=16792
  _PLAYERLEAVESWHISPER._serialized_end=16828
  _PLAYERACTIVELYSPEAKS._serialized_start=16830
  _PLAYERACTIVELYSPEAKS._serialized_end=16893
  _PLAYERSETSEMOTEV2._serialized_start=16895
  _PLAYERSETSEMOTEV2._serialized_end=16989
  _PLAYERSETSWORKCONDITION._serialized_start=16991
  _PLAYERSETSWORKCONDITION._serialized_end=17054
  _PLAYERSETSLASTACTIVE._serialized_start=17056
  _PLAYERSETSLASTACTIVE._serialized_end=17113
  _PLAYERSETSNAME._serialized_start=17115
  _PLAYERSETSNAME._serialized_end=17160
  _PLAYERSETSTEXTSTATUS._serialized_start=17162
  _PLAYERSETSTEXTSTATUS._serialized_end=17219
  _PLAYERSETSPRONOUNS._serialized_start=17221
  _PLAYERSETSPRONOUNS._serialized_end=17274
  _PLAYERSETSTITLE._serialized_start=17276
  _PLAYERSETSTITLE._serialized_end=17323
  _PLAYERSETSCITY._serialized_start=17325
  _PLAYERSETSCITY._serialized_end=17370
  _PLAYERSETSCOUNTRY._serialized_start=17372
  _PLAYERSETSCOUNTRY._serialized_end=17423
  _PLAYERSETSSTARTDATE._serialized_start=17425
  _PLAYERSETSSTARTDATE._serialized_end=17480
  _PLAYERSETSTIMEZONE._serialized_start=17482
  _PLAYERSETSTIMEZONE._serialized_end=17535
  _PLAYERSETSPHONE._serialized_start=17537
  _PLAYERSETSPHONE._serialized_end=17584
  _PLAYERSETSDESCRIPTION._serialized_start=17586
  _PLAYERSETSDESCRIPTION._serialized_end=17645
  _PLAYERSETSPROFILEIMAGEURL._serialized_start=17647
  _PLAYERSETSPROFILEIMAGEURL._serialized_end=17714
  _PLAYERSETSPERSONALIMAGEURL._serialized_start=17716
  _PLAYERSETSPERSONALIMAGEURL._serialized_end=17785
  _PLAYERSETSISMOBILE._serialized_start=17787
  _PLAYERSETSISMOBILE._serialized_end=17840
  _PLAYERSETSEMOJISTATUS._serialized_start=17842
  _PLAYERSETSEMOJISTATUS._serialized_end=17901
  _PLAYERSETSAFFILIATION._serialized_start=17903
  _PLAYERSETSAFFILIATION._serialized_end=17962
  _PLAYEREXITS._serialized_start=17964
  _PLAYEREXITS._serialized_end=17992
  _PLAYERSETSOUTFITSTRING._serialized_start=17994
  _PLAYERSETSOUTFITSTRING._serialized_end=18055
  _PLAYERSETSISSIGNEDIN._serialized_start=18057
  _PLAYERSETSISSIGNEDIN._serialized_end=18114
  _RESPAWNCOMPLETE._serialized_start=18116
  _RESPAWNCOMPLETE._serialized_end=18133
  _SPACEOVERWRITES._serialized_start=18135
  _SPACEOVERWRITES._serialized_end=18171
  _DYNAMICGATE._serialized_start=18173
  _DYNAMICGATE._serialized_end=18220
  _DYNAMICGATES._serialized_start=18222
  _DYNAMICGATES._serialized_end=18274
  _SPACESETSSPACEMEMBERS._serialized_start=18277
  _SPACESETSSPACEMEMBERS._serialized_end=18420
  _SPACESETSSPACEMEMBERS_MEMBERSENTRY._serialized_start=18356
  _SPACESETSSPACEMEMBERS_MEMBERSENTRY._serialized_end=18420
  _SPACEISCLOSED._serialized_start=18422
  _SPACEISCLOSED._serialized_end=18437
  _PLAYERENTERSPORTAL._serialized_start=18439
  _PLAYERENTERSPORTAL._serialized_end=18522
  _COOKIEFOUND._serialized_start=18524
  _COOKIEFOUND._serialized_end=18552
  _SPACESETSIDMAPPING._serialized_start=18554
  _SPACESETSIDMAPPING._serialized_end=18602
  _PLAYERSHOOTSCONFETTI._serialized_start=18604
  _PLAYERSHOOTSCONFETTI._serialized_end=18641
  _PLAYERSETSEVENTSTATUS._serialized_start=18643
  _PLAYERSETSEVENTSTATUS._serialized_end=18702
  _PLAYERSETSINCONVERSATION._serialized_start=18704
  _PLAYERSETSINCONVERSATION._serialized_end=18769
  _PLAYERSETSCURRENTDESK._serialized_start=18771
  _PLAYERSETSCURRENTDESK._serialized_end=18830
  _PLAYERSETSCURRENTAREA._serialized_start=18832
  _PLAYERSETSCURRENTAREA._serialized_end=18891
  _PLAYERSETSGOKARTID._serialized_start=18893
  _PLAYERSETSGOKARTID._serialized_end=18946
  _PLAYERSETSVEHICLEID._serialized_start=18948
  _PLAYERSETSVEHICLEID._serialized_end=19046
  _PLAYERSETSSPEEDMODIFIER._serialized_start=19048
  _PLAYERSETSSPEEDMODIFIER._serialized_end=19111
  _PLAYERSETSISALONE._serialized_start=19113
  _PLAYERSETSISALONE._serialized_end=19164
  _SPACEPLAYSSOUND._serialized_start=19166
  _SPACEPLAYSSOUND._serialized_end=19212
  _SPACESTOPSSOUND._serialized_start=19214
  _SPACESTOPSSOUND._serialized_end=19244
  _PLAYERSETSFOCUSMODEENDTIME._serialized_start=19246
  _PLAYERSETSFOCUSMODEENDTIME._serialized_end=19315
  _PLAYERBLOCKS._serialized_start=19317
  _PLAYERBLOCKS._serialized_end=19367
  _CUSTOMEVENT._serialized_start=19369
  _CUSTOMEVENT._serialized_end=19413
  _PLAYERUPDATESFOCUSMODESTATUS._serialized_start=19415
  _PLAYERUPDATESFOCUSMODESTATUS._serialized_end=19483
  _PLAYERSETSITEMSTRING._serialized_start=19485
  _PLAYERSETSITEMSTRING._serialized_end=19542
  _PLAYERTRIGGERSITEM._serialized_start=19545
  _PLAYERTRIGGERSITEM._serialized_end=19688
  _PLAYERNOTIFIES._serialized_start=19690
  _PLAYERNOTIFIES._serialized_end=19743
  _PLAYERSETSFOLLOWTARGET._serialized_start=19745
  _PLAYERSETSFOLLOWTARGET._serialized_end=19806
  _PLAYERREQUESTSTOLEAD._serialized_start=19808
  _PLAYERREQUESTSTOLEAD._serialized_end=19863
  _PLAYERSETSMANUALVIDEOSRC._serialized_start=19865
  _PLAYERSETSMANUALVIDEOSRC._serialized_end=19930
  _PLAYERSETSISNPC._serialized_start=19932
  _PLAYERSETSISNPC._serialized_end=19979
  _PLAYERSETSSUBTITLE._serialized_start=19981
  _PLAYERSETSSUBTITLE._serialized_end=20034
  _PLAYERCRAFTS._serialized_start=20036
  _PLAYERCRAFTS._serialized_end=20155
  _PLAYERCRAFTS_INPUTSENTRY._serialized_start=20110
  _PLAYERCRAFTS_INPUTSENTRY._serialized_end=20155
  _MAPMOVEOBJECT._serialized_start=20158
  _MAPMOVEOBJECT._serialized_end=20382
  _PLAYEREDITSCHATMESSAGE._serialized_start=20385
  _PLAYEREDITSCHATMESSAGE._serialized_end=20563
  _FXSHAKEOBJECT._serialized_start=20566
  _FXSHAKEOBJECT._serialized_end=20720
  _FXSHAKECAMERA._serialized_start=20723
  _FXSHAKECAMERA._serialized_end=20890
  _PLAYERHIGHFIVES._serialized_start=20892
  _PLAYERHIGHFIVES._serialized_end=20945
  _PLAYERSENDSCOMMAND._serialized_start=20947
  _PLAYERSENDSCOMMAND._serialized_end=20999
  _SPACEREGISTERSCOMMAND._serialized_start=21001
  _SPACEREGISTERSCOMMAND._serialized_end=21041
  _PLAYERUPDATESINVENTORY._serialized_start=21044
  _PLAYERUPDATESINVENTORY._serialized_end=21293
  _PLAYERUPDATESINVENTORY_ITEMSENTRY._serialized_start=8464
  _PLAYERUPDATESINVENTORY_ITEMSENTRY._serialized_end=8524
  _PLAYERUPDATESINVENTORY_ORDERENTRY._serialized_start=8526
  _PLAYERUPDATESINVENTORY_ORDERENTRY._serialized_end=8570
  _SPACEUPDATESITEMS._serialized_start=21295
  _SPACEUPDATESITEMS._serialized_end=21418
  _SPACEUPDATESITEMS_ITEMSENTRY._serialized_start=21362
  _SPACEUPDATESITEMS_ITEMSENTRY._serialized_end=21418
  _PLAYERTRIGGERSINVENTORYITEM._serialized_start=21420
  _PLAYERTRIGGERSINVENTORYITEM._serialized_end=21499
  _PLAYERSETSALLOWSCREENPOINTER._serialized_start=21501
  _PLAYERSETSALLOWSCREENPOINTER._serialized_end=21574
  _PRECOMPUTEDENTERLOCATION._serialized_start=21576
  _PRECOMPUTEDENTERLOCATION._serialized_end=21639
  _PLAYERSETSDESKINFO._serialized_start=21641
  _PLAYERSETSDESKINFO._serialized_end=21707
  _SPACESETSCAPACITY._serialized_start=21709
  _SPACESETSCAPACITY._serialized_end=21746
  _SPACEOVERCAPACITYDENIESUSER._serialized_start=21748
  _SPACEOVERCAPACITYDENIESUSER._serialized_end=21793
  _PLAYERSETSAWAY._serialized_start=21795
  _PLAYERSETSAWAY._serialized_end=21840
  _PLAYERSETSISRECORDINGCLIENT._serialized_start=21842
  _PLAYERSETSISRECORDINGCLIENT._serialized_end=21913
  _PLAYERSTARTSRECORDING._serialized_start=21915
  _PLAYERSTARTSRECORDING._serialized_end=22001
  _CLIENTSERVERBATCH._serialized_start=22003
  _CLIENTSERVERBATCH._serialized_end=22060
  _CLIENTSERVERACTION._serialized_start=22063
  _CLIENTSERVERACTION._serialized_end=26816
  _CLIENTHEARTBEAT._serialized_start=26818
  _CLIENTHEARTBEAT._serialized_end=26835
  _CLIENTBACKUPHEARTBEAT._serialized_start=26837
  _CLIENTBACKUPHEARTBEAT._serialized_end=26860
  _UPDATESUBSCRIPTIONS._serialized_start=26863
  _UPDATESUBSCRIPTIONS._serialized_end=27117
  _UPDATESUBSCRIPTIONS_SUBSCRIPTIONSENTRY._serialized_start=27012
  _UPDATESUBSCRIPTIONS_SUBSCRIPTIONSENTRY._serialized_end=27064
  _UPDATESUBSCRIPTIONS_MAPUPDATEIDSENTRY._serialized_start=27066
  _UPDATESUBSCRIPTIONS_MAPUPDATEIDSENTRY._serialized_end=27117
  _MOVE._serialized_start=27119
  _MOVE._serialized_end=27233
  _REQUESTMUTE._serialized_start=27235
  _REQUESTMUTE._serialized_end=27279
  _SETAFFILIATION._serialized_start=27281
  _SETAFFILIATION._serialized_end=27354
  _SETSTATUS._serialized_start=27356
  _SETSTATUS._serialized_end=27419
  _SETOUTFITSTRING._serialized_start=27421
  _SETOUTFITSTRING._serialized_end=27496
  _SPOTLIGHT._serialized_start=27498
  _SPOTLIGHT._serialized_end=27557
  _RING._serialized_start=27559
  _RING._serialized_end=27579
  _SETIMAGEPOINTER._serialized_start=27581
  _SETIMAGEPOINTER._serialized_end=27638
  _SETSCREENPOINTER._serialized_start=27640
  _SETSCREENPOINTER._serialized_end=27698
  _BAN._serialized_start=27700
  _BAN._serialized_end=27719
  _KICK._serialized_start=27721
  _KICK._serialized_end=27741
  _BLOCK._serialized_start=27743
  _BLOCK._serialized_end=27790
  _SETIMPASSABLE._serialized_start=27792
  _SETIMPASSABLE._serialized_end=27864
  _CHAT._serialized_start=27867
  _CHAT._serialized_end=28009
  _NOTIFY._serialized_start=28011
  _NOTIFY._serialized_end=28041
  _INTERACT._serialized_start=28043
  _INTERACT._serialized_end=28134
  _ACTIVELYSPEAKING._serialized_start=28136
  _ACTIVELYSPEAKING._serialized_end=28180
  _ENTERWHISPER._serialized_start=28182
  _ENTERWHISPER._serialized_end=28255
  _LEAVEWHISPER._serialized_start=28257
  _LEAVEWHISPER._serialized_end=28271
  _GHOST._serialized_start=28273
  _GHOST._serialized_end=28331
  _SETEMOTEV2._serialized_start=28333
  _SETEMOTEV2._serialized_end=28441
  _SETNAME._serialized_start=28443
  _SETNAME._serialized_end=28502
  _SETTEXTSTATUS._serialized_start=28504
  _SETTEXTSTATUS._serialized_end=28575
  _SETPRONOUNS._serialized_start=28577
  _SETPRONOUNS._serialized_end=28644
  _SETTITLE._serialized_start=28646
  _SETTITLE._serialized_end=28707
  _SETCITY._serialized_start=28709
  _SETCITY._serialized_end=28768
  _SETCOUNTRY._serialized_start=28770
  _SETCOUNTRY._serialized_end=28835
  _SETSTARTDATE._serialized_start=28837
  _SETSTARTDATE._serialized_end=28906
  _SETTIMEZONE._serialized_start=28908
  _SETTIMEZONE._serialized_end=28975
  _SETPHONE._serialized_start=28977
  _SETPHONE._serialized_end=29038
  _SETDESCRIPTION._serialized_start=29040
  _SETDESCRIPTION._serialized_end=29113
  _SETPROFILEIMAGEURL._serialized_start=29115
  _SETPROFILEIMAGEURL._serialized_end=29196
  _SETPERSONALIMAGEURL._serialized_start=29198
  _SETPERSONALIMAGEURL._serialized_end=29281
  _EXIT._serialized_start=29283
  _EXIT._serialized_end=29289
  _ENTER._serialized_start=29292
  _ENTER._serialized_end=29420
  _PRECOMPUTEENTER._serialized_start=29422
  _PRECOMPUTEENTER._serialized_end=29539
  _SETEMOJISTATUS._serialized_start=29541
  _SETEMOJISTATUS._serialized_end=29614
  _TELEPORT._serialized_start=29617
  _TELEPORT._serialized_end=29765
  _SETWORKCONDITION._serialized_start=29767
  _SETWORKCONDITION._serialized_end=29844
  _SPAWN._serialized_start=29846
  _SPAWN._serialized_end=29873
  _RESPAWN._serialized_start=29875
  _RESPAWN._serialized_end=29884
  _REQUESTTOJOINNOOK._serialized_start=29886
  _REQUESTTOJOINNOOK._serialized_end=29964
  _UPDATENOOKPERMISSION._serialized_start=29966
  _UPDATENOOKPERMISSION._serialized_end=30039
  _INIT._serialized_start=30041
  _INIT._serialized_end=30107
  _MAPADDOBJECT._serialized_start=30109
  _MAPADDOBJECT._serialized_end=30167
  _SHOOTCONFETTI._serialized_start=30169
  _SHOOTCONFETTI._serialized_end=30220
  _SETEVENTSTATUS._serialized_start=30222
  _SETEVENTSTATUS._serialized_end=30295
  _SETINCONVERSATION._serialized_start=30297
  _SETINCONVERSATION._serialized_end=30376
  _SETCURRENTDESK._serialized_start=30378
  _SETCURRENTDESK._serialized_end=30451
  _SETCURRENTAREA._serialized_start=30453
  _SETCURRENTAREA._serialized_end=30526
  _SETGOKARTID._serialized_start=30528
  _SETGOKARTID._serialized_end=30595
  _SETVEHICLEID._serialized_start=30597
  _SETVEHICLEID._serialized_end=30698
  _SETSPEEDMODIFIER._serialized_start=30700
  _SETSPEEDMODIFIER._serialized_end=30777
  _SETISALONE._serialized_start=30779
  _SETISALONE._serialized_end=30844
  _SETISMOBILE._serialized_start=30846
  _SETISMOBILE._serialized_end=30877
  _PLAYSOUND._serialized_start=30879
  _PLAYSOUND._serialized_end=30955
  _STOPSOUND._serialized_start=30957
  _STOPSOUND._serialized_end=31017
  _SETFOCUSMODEENDTIME._serialized_start=31019
  _SETFOCUSMODEENDTIME._serialized_end=31102
  _SETITEMSTRING._serialized_start=31104
  _SETITEMSTRING._serialized_end=31175
  _TRIGGERITEM._serialized_start=31177
  _TRIGGERITEM._serialized_end=31298
  _CUSTOMACTION._serialized_start=31300
  _CUSTOMACTION._serialized_end=31403
  _SETFOLLOWTARGET._serialized_start=31405
  _SETFOLLOWTARGET._serialized_end=31480
  _REQUESTTOLEAD._serialized_start=31482
  _REQUESTTOLEAD._serialized_end=31531
  _ENTERPORTAL._serialized_start=31533
  _ENTERPORTAL._serialized_end=31645
  _SETMANUALVIDEOSRC._serialized_start=31647
  _SETMANUALVIDEOSRC._serialized_end=31726
  _SETSUBTITLE._serialized_start=31728
  _SETSUBTITLE._serialized_end=31795
  _MAPCOMMITSCHANGES._serialized_start=31797
  _MAPCOMMITSCHANGES._serialized_end=31849
  _PLAYERUPDATESSESSION._serialized_start=31852
  _PLAYERUPDATESSESSION._serialized_end=32078
  _SPEAKERUPDATESSESSION._serialized_start=32081
  _SPEAKERUPDATESSESSION._serialized_end=32379
  _CHATREPLY._serialized_start=32381
  _CHATREPLY._serialized_end=32448
  _CHATMESSAGEUPDATED._serialized_start=32450
  _CHATMESSAGEUPDATED._serialized_end=32482
  _SENDCOMMAND._serialized_start=32484
  _SENDCOMMAND._serialized_end=32550
  _REGISTERCOMMAND._serialized_start=32552
  _REGISTERCOMMAND._serialized_end=32586
  _CRAFT._serialized_start=32588
  _CRAFT._serialized_end=32678
  _CRAFT_INPUTSENTRY._serialized_start=32633
  _CRAFT_INPUTSENTRY._serialized_end=32678
  _HIGHFIVE._serialized_start=32680
  _HIGHFIVE._serialized_end=32708
  _ADDINVENTORYITEM._serialized_start=32710
  _ADDINVENTORYITEM._serialized_end=32777
  _REMOVEINVENTORYITEM._serialized_start=32779
  _REMOVEINVENTORYITEM._serialized_end=32867
  _HIPTOBESQUARE._serialized_start=32869
  _HIPTOBESQUARE._serialized_end=32898
  _TRIGGERINVENTORYITEM._serialized_start=32900
  _TRIGGERINVENTORYITEM._serialized_end=32957
  _SETALLOWSCREENPOINTER._serialized_start=32959
  _SETALLOWSCREENPOINTER._serialized_end=33010
  _SETDESKINFO._serialized_start=33012
  _SETDESKINFO._serialized_end=33092
  _WAVE._serialized_start=33094
  _WAVE._serialized_end=33131
  _SETAWAY._serialized_start=33133
  _SETAWAY._serialized_end=33192
  _STARTRECORDING._serialized_start=33194
  _STARTRECORDING._serialized_end=33258
# @@protoc_insertion_point(module_scope)
